@@ -3,12 +3,13 @@
 // Purpose:     About dialog
 // Author:      Alex Thuering
 // Created:     6.11.2003
-// RCS-ID:      $Id: About.cpp,v 1.77 2011/12/04 13:10:34 ntalex Exp $
+// RCS-ID:      $Id: About.cpp,v 1.80 2012/05/20 10:19:32 ntalex Exp $
 // Copyright:  (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
 
 #include "About.h"
+#include "Authors.h"
 #include <wxVillaLib/utils.h>
 #include <wx/statline.h>
 #include <wx/notebook.h>
@@ -104,54 +105,24 @@ About::About(wxWindow* parent): wxDialog(parent, -1, wxEmptyString,
 	
 	page += _T("<tr><td colspan='3'><b>") + wxString(_("Author and Maintainer")) + _T("</b></td></tr>");
 	page += _T("<tr><td>&nbsp;</td><td colspan='2'>");
-	page += FixEmail(_T("Alex Th&uuml;ring <alex at thuering.biz>"));
+	page += FixEmail(s_author);
 	page += _T("</td></tr>");
 	
 	page += _T("<tr><td colspan='3'><b>") + wxString(_("Doc Writer")) + _T("</b></td></tr>");
 	page += _T("<tr><td>&nbsp;</td><td colspan='2'>");
-	page += FixEmail(_T("Don Brett <dlbrett at zoominternet.net>"));
+	page += FixEmail(s_docWriter);
 	page += _T("</td></tr>");
 	
 	page += _T("<tr><td colspan='3'><b>") + wxString(_("Packager (.deb)")) + _T("</b></td></tr>");
 	page += _T("<tr><td>&nbsp;</td><td colspan='2'>");
-	page += FixEmail(_T("Fabrice Coutadeur <coutadeurf at gmail.com>"));
+	page += FixEmail(s_packager);
 	page += _T("</td></tr>");
 	
 	page += _T("<tr><td colspan='3'><b>") + wxString(_("Translations")) + _T("</b></td></tr>");
 	
-	const wxString translations[][2] = {
-		{ wxT("Armenian"), wxT("Hrant Ohanyan <hrantohanyan at mail.am>") },
-		{ wxT("Chinese (Simplified)"), wxString(wxT("程序民工 <lyj8063 at sohu.com>, 郁晓旭 <yuxiaoxu at msn.com>"), wxConvUTF8) },
-		{ wxT("Chinese (Traditional)"), wxString(wxT("紀明村 <tw.chi.ming at gmail.com>, Sophina Liu <Sophina-liu at hotmail.com>"), wxConvUTF8) },
-		{ wxT("Basque"), wxT("Piarres Beobide <pi at beobide.net>") },
-		{ wxT("Czech"), wxString(wxT("Vlastimil Skácel <vlastiks at gmail.com>"), wxConvUTF8) },
-		{ wxT("Danish"), wxT("Jørgen Rasmussen <l10n at joergenr.dk>") },
-		{ wxT("Dutch"), wxT("Frank Meijer <fajmmeijer at hotmail.com>, Maikel Egberink <maikel.egberink at gmail.com>") },
-		{ wxT("French"), wxT("Pierre Buard <pierre.buard at gmail.com>, R. Berzolla <rberzolla at free.fr>") },
-		{ wxT("German"), wxT("Alex Th&uuml;ring <alex at thuering.biz>") },
-		{ wxT("Greek"), wxT("Aristotelis Pitaridis <pitaridis at gmail.com>") },
-		{ wxT("Hungarian"), wxString(wxT("Fáczán László <faczan at freemail.hu>"), wxConvUTF8) },
-		{ wxT("Italian"), wxT("Marco Ciampa <ciampix at libero.it>, Alessio Leonarduzzi <alessio.leonarduzzi at gmail.com>") },
-		{ wxT("Japanese"), wxT("OKANO Takayoshi <kano at na.rim.or.jp>") },
-		{ wxT("Korean"), wxString(wxT("김프사랑 <yongdoria at gmail.com>"), wxConvUTF8) },
-		{ wxT("Macedonian"), wxT("Damjan Dimitrioski <damjandimitrioski at gmail.com>") },
-		{ wxT("Norwegian"), wxString(wxT("Olav Inge Frøynes <olavinge at gmail.com>"), wxConvUTF8) },
-		{ wxT("Polish"), wxString(wxT("Michał Trzebiatowski <hippie_1968 at hotmail.com>"), wxConvUTF8) },
-		{ wxT("Portuguese"), wxString(wxT("João Frade / / 100 NOME PT <100nome.portugal at gmail.com>"), wxConvUTF8) },
-		{ wxT("Portuguese (Brazilian)"), wxT("Henrique Lopes Barone <henrique.blender at gmail.com>, Igor Ruckert <igorruckert at yahoo.com.br>") },
-		{ wxT("Russian"), wxT("Alex Th&uuml;ring <alex at thuering.biz>") },
-		{ wxT("Slovenian"), wxT("Martin Srebotnjak <miles at filmsi.net>") },
-		{ wxT("Serbian"), wxT("CICIC Ivana <ozzii23 at gmail.com>") },
-		{ wxT("Slovak"), wxT("Michal Kovac <deadsock at deadsock.co.uk>") },
-		{ wxT("Spanish"), wxT("Redy Rodriguez <redy at telefonica.net>, Fabrice Coutadeur <coutadeurf at gmail.com>") },
-		{ wxT("Swedish"), wxT("Daniel Nylander <po at danielnylander.se>, Tobias Holm <dvdstyler at eftprod.com>") },
-		{ wxT("Ukrainian"), wxT("Федір Зінчук <getthesite at gmail.com>") },
-		{ wxT("Vietnamese"), wxT("Phan Anh <ppanhh at gmail.com>") },
-	};
-	
-	for (unsigned int i = 0; i < sizeof(translations)/sizeof(translations[0]); i++)
-		page += wxT("<tr><td>&nbsp;</td><td>") + translations[i][0] + wxT("</td><td width='100%'>")
-				+ FixEmail(translations[i][1]) + wxT("</td></tr>");
+	for (unsigned int i = 0; i < sizeof(s_translations)/sizeof(s_translations[0]); i++)
+		page += wxT("<tr><td>&nbsp;</td><td>") + s_translations[i][0] + wxT("</td><td width='100%'>")
+				+ FixEmail(s_translations[i][1]) + wxT("</td></tr>");
 	
 	page += _T("<tr><td colspan='3'><b>") + wxString(_("Libraries and Tools")) + _T("</b></td></tr>");
 	page += _T("<tr><td>&nbsp;</td><td>wxWidgets</td><td>Julian Smart, Robert Roebling and other</td></tr>");
