@@ -3,7 +3,7 @@
 // Purpose:     About dialog
 // Author:      Alex Thuering
 // Created:     6.11.2003
-// RCS-ID:      $Id: About.h,v 1.23 2011/02/10 20:50:46 ntalex Exp $
+// RCS-ID:      $Id: About.h,v 1.24 2012/01/15 19:40:29 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -12,10 +12,10 @@
 #include <wx/html/htmlwin.h>
 #include "Version.h" //APP_VERSION
 
-const wxString APP_MAINT		= _T("Alex Thuering");
+const wxString APP_MAINT		= wxString(wxT("Alex Thüring"), wxConvUTF8);
 const wxString APP_NAME			= _T("DVDStyler");
 const wxString APP_LICENCE		= _T("GPL");
-const wxString APP_COPYRIGHT	= _T("(c) 2011 Alex Thuering");
+const wxString APP_COPYRIGHT	= _T("(c) 2012 Alex Thuering");
 const wxString APP_WEBSITE		= _T("http://www.dvdstyler.org");
 
 class About: public wxDialog {
