@@ -1,9 +1,9 @@
 #include "AudioPropDlg.h"
 
 //(*InternalHeaders(AudioPropDlg)
+#include <wx/intl.h>
 #include <wx/button.h>
 #include <wx/string.h>
-#include <wx/intl.h>
 //*)
 
 //(*IdInit(AudioPropDlg)
@@ -39,21 +39,21 @@ AudioPropDlg::AudioPropDlg(wxWindow* parent,Vob* vob, const wxString& audioFile,
 	m_stream = vob->GetStreams()[streamIdx];
 
 	//(*Initialize(AudioPropDlg)
-	wxStaticText* label3;
-	wxStaticText* label4;
-	wxBoxSizer* BoxSizer3;
-	wxStdDialogButtonSizer* stdDialogButtonSizer;
-	wxFlexGridSizer* propGridSizer;
-	wxStaticText* label5;
-	wxBoxSizer* BoxSizer2;
-	wxStaticText* label2;
 	wxStaticText* label6;
-	wxBoxSizer* mainVSizer;
-	wxStaticText* label8;
+	wxFlexGridSizer* propGridSizer;
+	wxBoxSizer* boxSizer3;
 	wxStaticText* label7;
-	wxBoxSizer* BoxSizer1;
+	wxStaticText* label4;
+	wxBoxSizer* boxSizer1;
+	wxStaticText* label8;
+	wxBoxSizer* boxSizer2;
+	wxStaticText* label3;
+	wxBoxSizer* mainVSizer;
 	wxStaticText* label1;
-	
+	wxStdDialogButtonSizer* stdDialogButtonSizer;
+	wxStaticText* label2;
+	wxStaticText* label5;
+
 	Create(parent, wxID_ANY, _("Audio properties"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER, _T("wxID_ANY"));
 	mainVSizer = new wxBoxSizer(wxVERTICAL);
 	propGridSizer = new wxFlexGridSizer(0, 2, 4, 4);
@@ -71,39 +71,39 @@ AudioPropDlg::AudioPropDlg(wxWindow* parent,Vob* vob, const wxString& audioFile,
 	propGridSizer->Add(m_srcText, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
 	label4 = new wxStaticText(this, ID_STATICTEXT7, _("Destination Format:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT7"));
 	propGridSizer->Add(label4, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
-	BoxSizer3 = new wxBoxSizer(wxHORIZONTAL);
+	boxSizer3 = new wxBoxSizer(wxHORIZONTAL);
 	m_dstChoice = new wxChoice(this, ID_DST_CHOICE, wxDefaultPosition, wxDefaultSize, 0, 0, 0, wxDefaultValidator, _T("ID_DST_CHOICE"));
-	BoxSizer3->Add(m_dstChoice, 0, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
+	boxSizer3->Add(m_dstChoice, 0, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
 	m_audio51 = new wxCheckBox(this, ID_A51_CHECK, _("5.1"), wxDefaultPosition, wxSize(-1,-1), 0, wxDefaultValidator, _T("ID_A51_CHECK"));
 	m_audio51->SetValue(false);
-	BoxSizer3->Add(m_audio51, 0, wxLEFT|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	propGridSizer->Add(BoxSizer3, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
+	boxSizer3->Add(m_audio51, 0, wxLEFT|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	propGridSizer->Add(boxSizer3, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
 	label5 = new wxStaticText(this, ID_STATICTEXT8, _("Language:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT8"));
 	propGridSizer->Add(label5, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
 	m_langChoice = new wxChoice(this, ID_LANG_CHOICE, wxDefaultPosition, wxDefaultSize, 0, 0, 0, wxDefaultValidator, _T("ID_LANG_CHOICE"));
 	propGridSizer->Add(m_langChoice, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
 	label6 = new wxStaticText(this, ID_STATICTEXT9, _("Volume:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT9"));
 	propGridSizer->Add(label6, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
-	BoxSizer1 = new wxBoxSizer(wxHORIZONTAL);
+	boxSizer1 = new wxBoxSizer(wxHORIZONTAL);
 	m_volumeCtrl = new wxTextCtrl(this, ID_VOLUME_CTRL, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_VOLUME_CTRL"));
-	BoxSizer1->Add(m_volumeCtrl, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	boxSizer1->Add(m_volumeCtrl, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	m_volumeSpin = new wxSpinButton(this, ID_SPINBUTTON1, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS, _T("ID_SPINBUTTON1"));
 	m_volumeSpin->SetRange(0, 1000);
 	m_volumeSpin->SetMinSize(wxSize(16,12));
-	BoxSizer1->Add(m_volumeSpin, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
-	propGridSizer->Add(BoxSizer1, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
+	boxSizer1->Add(m_volumeSpin, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	propGridSizer->Add(boxSizer1, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
 	label7 = new wxStaticText(this, ID_STATICTEXT10, _("Time delay:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT10"));
 	propGridSizer->Add(label7, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
-	BoxSizer2 = new wxBoxSizer(wxHORIZONTAL);
+	boxSizer2 = new wxBoxSizer(wxHORIZONTAL);
 	m_offsetCtrl = new wxTextCtrl(this, ID_TEXTCTRL1, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL1"));
-	BoxSizer2->Add(m_offsetCtrl, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	boxSizer2->Add(m_offsetCtrl, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	m_offsetSpin = new wxSpinButton(this, ID_SPINBUTTON2, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS, _T("ID_SPINBUTTON2"));
 	m_offsetSpin->SetRange(0, 999);
 	m_offsetSpin->SetMinSize(wxSize(16,12));
-	BoxSizer2->Add(m_offsetSpin, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	boxSizer2->Add(m_offsetSpin, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	label8 = new wxStaticText(this, ID_STATICTEXT11, _("ms"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT11"));
-	BoxSizer2->Add(label8, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	propGridSizer->Add(BoxSizer2, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
+	boxSizer2->Add(label8, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	propGridSizer->Add(boxSizer2, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
 	mainVSizer->Add(propGridSizer, 1, wxTOP|wxLEFT|wxRIGHT|wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
 	stdDialogButtonSizer = new wxStdDialogButtonSizer();
 	stdDialogButtonSizer->AddButton(new wxButton(this, wxID_OK, wxEmptyString));
@@ -114,7 +114,7 @@ AudioPropDlg::AudioPropDlg(wxWindow* parent,Vob* vob, const wxString& audioFile,
 	mainVSizer->Fit(this);
 	mainVSizer->SetSizeHints(this);
 	Center();
-	
+
 	Connect(ID_DST_CHOICE,wxEVT_COMMAND_CHOICE_SELECTED,(wxObjectEventFunction)&AudioPropDlg::OnChangeFormat);
 	Connect(ID_VOLUME_CTRL,wxEVT_COMMAND_TEXT_UPDATED,(wxObjectEventFunction)&AudioPropDlg::OnChangeVolume);
 	Connect(ID_SPINBUTTON1,wxEVT_SCROLL_THUMBTRACK,(wxObjectEventFunction)&AudioPropDlg::OnVolumeSpin);
