@@ -3,7 +3,7 @@
 // Purpose:     Burn dialog
 // Author:      Alex Thuering
 // Created:     23.03.2003
-// RCS-ID:      $Id: BurnDlg.cpp,v 1.34 2012/06/17 21:56:20 ntalex Exp $
+// RCS-ID:      $Id: BurnDlg.cpp,v 1.35 2013/05/20 08:15:56 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -159,34 +159,6 @@ typedef struct _SCSI_PASS_THROUGH_WITH_BUFFERS {
 #define SCSIOP_MODE_SENSE 0x1A
 #define MODE_PAGE_CAPABILITIES 0x2A
 
-bool IsDvdWriter(HANDLE hDevice) {
-	SCSI_PASS_THROUGH_WITH_BUFFERS sptwb;
-	ZeroMemory(&sptwb,sizeof(SCSI_PASS_THROUGH_WITH_BUFFERS));
-	sptwb.Spt.Length = sizeof (SCSI_PASS_THROUGH);
-	sptwb.Spt.PathId = 0;
-	sptwb.Spt.TargetId = 1;
-	sptwb.Spt.Lun = 0;
-	sptwb.Spt.CdbLength = 6;
-	sptwb.Spt.SenseInfoLength = 24;
-	sptwb.Spt.DataIn = SCSI_IOCTL_DATA_IN;
-	sptwb.Spt.DataTransferLength = 192;
-	sptwb.Spt.TimeOutValue = 2;
-	sptwb.Spt.DataBufferOffset = offsetof(SCSI_PASS_THROUGH_WITH_BUFFERS, DataBuf);
-	sptwb.Spt.SenseInfoOffset = offsetof(SCSI_PASS_THROUGH_WITH_BUFFERS, SenseBuf);
-	sptwb.Spt.Cdb[0] = SCSIOP_MODE_SENSE;
-	sptwb.Spt.Cdb[1] = 0x08;
-	sptwb.Spt.Cdb[2] = MODE_PAGE_CAPABILITIES;
-	sptwb.Spt.Cdb[4] = 192;
-	ULONG length = offsetof(SCSI_PASS_THROUGH_WITH_BUFFERS, DataBuf) + sptwb.Spt.DataTransferLength;
-	ULONG returned = 0;
-	bool status = DeviceIoControl(hDevice, IOCTL_SCSI_PASS_THROUGH, &sptwb,
-			sizeof(SCSI_PASS_THROUGH), &sptwb, length, &returned, NULL);
-	if (status && sptwb.Spt.ScsiStatus == 0) {
-		return (sptwb.DataBuf[7] & 0x10) || (sptwb.DataBuf[7] & 0x20);
-	}
-	return true; // cannot check
-}
-
 wxString GetProductId(HANDLE hDevice) {
 	STORAGE_PROPERTY_QUERY query;
 	query.PropertyId = StorageAdapterProperty;
@@ -210,76 +182,38 @@ wxString GetProductId(HANDLE hDevice) {
 	return wxT("");
 }
 
-bool GetDeviceHandle(HDEVINFO IntDevInfo, int index, HANDLE& hDevice, wxString& drive) {
-	hDevice = INVALID_HANDLE_VALUE;
+wxString GetProductId(const wxString& drive) {
+	TCHAR volPath[MAX_PATH];
+	if (GetVolumePathName(drive, volPath, sizeof(volPath))) {
+		for (size_t cchVolPath = _tcslen(volPath);
+				cchVolPath > 0 && volPath[cchVolPath - 1] == TEXT('\\');
+				cchVolPath--) {
+			volPath[cchVolPath - 1] = TEXT('\0');
+		}
 
-	SP_DEVICE_INTERFACE_DATA interfaceData;
-	interfaceData.cbSize = sizeof(SP_INTERFACE_DEVICE_DATA);
-	if (!SetupDiEnumDeviceInterfaces(IntDevInfo, 0, (LPGUID)(&GUID_DEVINTERFACE_CDROM), index, &interfaceData))
-		return false;
-	
-	DWORD reqSize;
-	if (!SetupDiGetDeviceInterfaceDetail(IntDevInfo, &interfaceData, NULL, 0, &reqSize, NULL)
-			&& GetLastError() != ERROR_INSUFFICIENT_BUFFER)
-		return false;
-	
-	DWORD iddSize = reqSize;
-	PSP_DEVICE_INTERFACE_DETAIL_DATA interfaceDetailData = (PSP_DEVICE_INTERFACE_DETAIL_DATA) malloc(iddSize);
-	if (interfaceDetailData == NULL)
-		return false;
-	
-	bool result = true;
-	interfaceDetailData->cbSize = sizeof (SP_INTERFACE_DEVICE_DETAIL_DATA);
-	if (SetupDiGetDeviceInterfaceDetail(IntDevInfo, &interfaceData, interfaceDetailData, iddSize, &reqSize, NULL)) {
-		drive = GetDriveString(interfaceDetailData->DevicePath);
-		if (drive.length() > 0)
-			hDevice = CreateFile(interfaceDetailData->DevicePath, GENERIC_READ|GENERIC_WRITE,
-					FILE_SHARE_READ|FILE_SHARE_WRITE, NULL, OPEN_EXISTING, 0, NULL);
-	} else
-		result = false;
-	
-	free(interfaceDetailData);
-	return result;
+		TCHAR volPathWithLeadingPrefix[sizeof(volPath)];
+		if (_sntprintf(volPathWithLeadingPrefix,
+				sizeof(volPathWithLeadingPrefix),
+				volPath[0] == _T('\\') ? _T("%s") : _T("\\\\.\\%s"),
+				volPath) < sizeof(volPathWithLeadingPrefix)) {
+		    HANDLE hDevice = CreateFile(volPathWithLeadingPrefix, 0, FILE_SHARE_READ|FILE_SHARE_WRITE,
+		    		NULL, OPEN_EXISTING, 0, NULL);
+		    if (hDevice != INVALID_HANDLE_VALUE)
+		    	return GetProductId(hDevice);
+		}
+	} 
+	return wxT("");
 }
 
 void EnumDevices(wxArrayString& devices, wxComboBox* deviceChoice) {
-	HDEVINFO hDevInfo = SetupDiGetClassDevs((LPGUID) &GUID_DEVCLASS_CDROM, NULL, NULL, DIGCF_PRESENT);
-	if (hDevInfo == INVALID_HANDLE_VALUE) {
-		wxLogError(wxT("SetupDiGetClassDevs(GUID_DEVCLASS_CDROM) failed with error: %d"), GetLastError());
-		return;
-	}
-
-	HDEVINFO hIntDevInfo = SetupDiGetClassDevs((LPGUID) &GUID_DEVINTERFACE_CDROM, NULL, NULL,
-			(DIGCF_PRESENT | DIGCF_INTERFACEDEVICE));
-	if (hIntDevInfo == INVALID_HANDLE_VALUE) {
-		wxLogError(wxT("SetupDiGetClassDevs(GUID_DEVINTERFACE_CDROM) failed with error: %d"), GetLastError());
-		return;
-	}
-
-	// enumerate all the DVD devices
-	int index = 0;
-	while (true) {
-		HANDLE hDevice;
-		wxString drive;
-		if (!GetDeviceHandle(hIntDevInfo, index++, hDevice, drive))
-			break;
-		if (drive.length() == 0)
-			continue;
-		
-		if (hDevice != INVALID_HANDLE_VALUE) {
-			wxString productId = GetProductId(hDevice);
-			if (IsDvdWriter(hDevice)) {
-				devices.Add(drive);
-				deviceChoice->Append(drive + wxT(" ") + productId);
-			}
-			CloseHandle(hDevice);
-		} else {
+	wxString drive = wxT("C:");
+	for (char c = 'C'; c < 'Z';  c++) {
+		drive[0] = wxChar(c);
+		if (GetDriveType(drive) == DRIVE_CDROM) {
 			devices.Add(drive);
-			deviceChoice->Append(drive);
+			deviceChoice->Append(drive + wxT(" ") + GetProductId(drive));
 		}
 	}
-	SetupDiDestroyDeviceInfoList(hDevInfo);
-	SetupDiDestroyDeviceInfoList(hIntDevInfo);
 }
 #elif defined(__WXMAC__)
 extern "C" void EnumDevices(wxArrayString& devices, wxComboBox* deviceChoice);
