@@ -3,7 +3,7 @@
 // Purpose:     Manage cache of transcoded files
 // Author:      Alex Thuering
 // Created:     29.08.2008
-// RCS-ID:      $Id: Cache.cpp,v 1.11 2012/06/03 20:55:54 ntalex Exp $
+// RCS-ID:      $Id: Cache.cpp,v 1.13 2013/01/10 15:29:57 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -52,7 +52,7 @@ CacheEntry::CacheEntry(Vob* vob, DVD* dvd, int idx) {
 	for (unsigned int stIdx = 0; stIdx < vob->GetStreams().GetCount(); stIdx++)
 		m_formats.Add(vob->GetStreams()[stIdx]->GetDestinationFormat());
 	m_videoBitrate = dvd->GetVideoBitrate();
-	m_audioBitrate = s_config.GetAudioBitrate();
+	m_audioBitrate = dvd->GetAudioBitrate();
 	m_startTime = vob->GetStartTime();
 	m_recordingTime = vob->GetRecordingTime();
 	m_videoFilters = vob->GetAllVideoFilters();
@@ -200,7 +200,8 @@ void Cache::EndClean() {
 	while (it != m_cacheMap.end()) {
 		CacheEntry* entry = it->second;
 		if (!entry->IsUsed()) {
-			wxRemoveFile(GetFileName(entry->GetIdx()));
+			if (wxFileExists(GetFileName(entry->GetIdx())))
+				wxRemoveFile(GetFileName(entry->GetIdx()));
 			m_cacheMap.erase(it++);
 			delete entry;
 		} else
