@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Structure (Titles/Menus)
 // Author:      Alex Thuering
 // Created:     29.01.2003
-// RCS-ID:      $Id: DVD.cpp,v 1.117 2012/07/22 09:32:04 ntalex Exp $
+// RCS-ID:      $Id: DVD.cpp,v 1.122 2013/06/16 19:27:48 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -27,6 +27,7 @@ DVD::DVD() {
 	m_capacity = dcDVD5;
 	m_videoBitrateAuto = true;
 	m_videoBitrate = 4500;
+	m_audioBitrate = s_config.GetAudioBitrate();
 	m_jumppad = false;
 	m_emptyMenu = true;
 	m_playAllRegister = -1;
@@ -45,7 +46,9 @@ DVD::~DVD() {
 
 /** Returns disc capacity in KB */
 long DVD::GetCapacityValue() {
-	if (m_capacity == dcDVD1)
+	if (m_capacity == dcCD)
+		return 720000;
+	else if (m_capacity == dcDVD1)
 		return 1426063;
 	else if (m_capacity == dcDVD2)
 		return 2589982;
@@ -240,7 +243,9 @@ bool DVD::HasMenus() {
 bool DVD::CheckMenus() {
 	for (int tsi = -1; tsi < (int) GetTitlesets().Count(); tsi++) {
 		PgcArray& pgcs = GetPgcArray(tsi, true);
+		bool hasRootMenu = false;
 		for (unsigned int pgci = 0; pgci < pgcs.GetCount(); pgci++) {
+			hasRootMenu = hasRootMenu || pgcs[pgci]->GetEntries().find(wxT("root")) != pgcs[pgci]->GetEntries().end();
 			Menu* menu = pgcs[pgci]->GetMenu();
 			if (menu) {
 				wxString src = DVDAction::GetSourceStr(this, tsi, pgci, true, wxT("")) + wxString(wxT(": "));
@@ -264,6 +269,9 @@ bool DVD::CheckMenus() {
 				}
 			}
 		}
+		if (!hasRootMenu && tsi >= 0 && pgcs.GetCount() > 0) {
+			pgcs[0]->GetEntries().insert(wxT("root"));
+		}
 	}
 	return true;
 }
@@ -393,7 +401,7 @@ wxString DVD::GetDefPostCommandStr() {
 		return GetVmgm().size() > 0 ? wxT("call vmgm menu 1;") : wxT("call menu entry root;");
 	else if (m_defPostCommand == cmdJUMP_NEXT_TITLE)
 		return wxT("jump next title;");
-	return HasMenus() ? wxT("call menu entry root;") : wxT("");
+	return HasMenus() ? wxT("call menu;") : wxT("");
 }
 
 /** Sets default title post command */
@@ -461,7 +469,7 @@ bool DVD::PutXML(const wxSvgXmlDocument& xml) {
 	if (root->GetPropVal(wxT("isoFile"), &val))
 		m_isoFile = val;
 	if (root->GetPropVal(wxT("capacity"), &val) && val.ToLong(&lval))
-		m_capacity = DiscCapacity(lval + 2);
+		m_capacity = DiscCapacity(lval + 3);
 	if (root->GetPropVal(wxT("jumppad"), &val) && val.ToLong(&lval))
 		m_jumppad = int(lval);
 	if (root->GetPropVal(wxT("emptyMenu"), &val) && val.ToLong(&lval))
@@ -476,6 +484,8 @@ bool DVD::PutXML(const wxSvgXmlDocument& xml) {
 		m_videoBitrateAuto = lval == -1;
 		m_videoBitrate = lval == -1 ? 4500 : lval;
 	}
+	if (root->GetPropVal(wxT("audioBitrate"), &val) && val.ToLong(&lval))
+		m_audioBitrate = lval;
 	if (root->GetPropVal(wxT("defPostCommand"), &val) && val.ToLong(&lval))
 		m_defPostCommand = DefaultPostCommand(lval);
 
@@ -534,15 +544,21 @@ wxSvgXmlDocument* DVD::GetXml() {
 	if (m_isoFile.length() > 0)
 		root->AddProperty(wxT("isoFile"), m_isoFile);
 	root->AddProperty(wxT("name"), m_label);
-	root->AddProperty(wxT("capacity"), wxString::Format(wxT("%d"), m_capacity - 2));
+	if (m_capacity != dcDVD5)
+		root->AddProperty(wxT("capacity"), wxString::Format(wxT("%d"), m_capacity - 3));
 	if (m_defPostCommand != cmdCALL_LAST_MENU)
 		root->AddProperty(wxT("defPostCommand"), wxString::Format(wxT("%d"), m_defPostCommand));
-	root->AddProperty(wxT("jumppad"), m_jumppad ? wxT("1") : wxT("0"));
-	root->AddProperty(wxT("emptyMenu"), m_emptyMenu ? wxT("1") : wxT("0"));
+	if (m_jumppad)
+		root->AddProperty(wxT("jumppad"), wxT("1"));
+	if (!m_emptyMenu)
+		root->AddProperty(wxT("emptyMenu"), wxT("0"));
 	root->AddProperty(wxT("videoFormat"), wxString::Format(wxT("%d"), m_videoFormat));
 	root->AddProperty(wxT("audioFormat"), wxString::Format(wxT("%d"), m_audioFormat));
 	root->AddProperty(wxT("aspectRatio"), wxString::Format(wxT("%d"), m_aspectRatio));
-	root->AddProperty(wxT("videoBitrate"), wxString::Format(wxT("%d"), m_videoBitrateAuto ? -1 : m_videoBitrate));
+	if (!m_videoBitrateAuto)
+		root->AddProperty(wxT("videoBitrate"), wxString::Format(wxT("%d"), m_videoBitrate));
+	if (m_audioBitrate != s_config.GetAudioBitrate())
+		root->AddProperty(wxT("audioBitrate"), wxString::Format(wxT("%d"), m_audioBitrate));
 	wxSvgXmlNode* coloursNode = NULL;
 	for (int i = 0; i < 16; i++) {
 		wxColour colour = wxPropDlg::GetColourData().GetCustomColour(i);
@@ -837,6 +853,7 @@ wxArrayString DVD::GetAspectRatioLabels(bool autom) {
 
 wxArrayString DVD::GetCapacityLabels() {
 	wxArrayString labels;
+	labels.Add(_("CD (700 MB)"));
 	labels.Add(_("DVD-1 (1.4 GB)"));
 	labels.Add(_("DVD-2 (2.6 GB)"));
 	labels.Add(_("DVD-5 (4.7 GB)"));
