@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Structure (Titles/Menus)
 // Author:      Alex Thuering
 // Created:     29.01.2003
-// RCS-ID:      $Id: DVD.h,v 1.77 2012/07/02 21:38:37 ntalex Exp $
+// RCS-ID:      $Id: DVD.h,v 1.79 2013/06/16 19:27:48 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -14,7 +14,8 @@
 #include "Titleset.h"
 
 enum DiscCapacity {
-	dcDVD1 = 0,
+	dcCD = 0,
+	dcDVD1,
 	dcDVD2,
 	dcDVD5,
 	dcDVD9,
@@ -54,6 +55,10 @@ public:
     void SetVideoBitrate(int bitrate) { m_videoBitrate = bitrate; }
     /** Calculates video bitrate if it set to auto */
     wxArrayInt CalculateVideoBitrate();
+	/** Returns audio bitrate */
+    int GetAudioBitrate() { return m_audioBitrate; }
+    /** Sets audio bitrate */
+    void SetAudioBitrate(int bitrate) { m_audioBitrate = bitrate; }
 	
 	/** Returns true if creation of jumppads enabled */
 	bool IsJumppadsEnabled() { return m_jumppad; }
@@ -219,6 +224,7 @@ private:
     DefaultPostCommand m_defPostCommand;
     bool m_videoBitrateAuto;
     int m_videoBitrate;
+    int m_audioBitrate;
 	bool m_jumppad;
 	bool m_emptyMenu;
 	TitlesetArray m_titlesets;
