@@ -3,7 +3,7 @@
 // Purpose:     Stores a DVD Action
 // Author:      Alex Thuering
 // Created:     03.09.2009
-// RCS-ID:      $Id: DVDAction.cpp,v 1.27 2012/10/14 16:23:29 ntalex Exp $
+// RCS-ID:      $Id: DVDAction.cpp,v 1.28 2012/12/23 17:26:15 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -202,7 +202,7 @@ bool validateJumpTarget(wxString msgPrefix, DVD* dvd, int tsi, int pgci, bool me
 			return false;
 		} else if (entry.length() > 0) { // menu entry
 			const StringSet& entrySet = menus.GetEntries();
-			if (entry != wxT("default") && entrySet.find(entry) == entrySet.end()){
+			if (entry != wxT("default") && entry != wxT("root") && entrySet.find(entry) == entrySet.end()){
 				const wxString entries[6] = {_("title menu"), _("root menu"), _("subtitle menu"), _("audio menu"),
 						_("angle menu"), _("chapter menu")};
 				int entryIdx = s_entries.Index(entry);
