@@ -3,7 +3,7 @@
 // Purpose:     DVD properties dialog
 // Author:      Alex Thuering
 // Created:     7.03.2005
-// RCS-ID:      $Id: DVDPropDlg.h,v 1.3 2009/12/30 17:44:18 ntalex Exp $
+// RCS-ID:      $Id: DVDPropDlg.h,v 1.4 2010/05/28 19:46:12 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -13,9 +13,9 @@
 
 #include <wx/wx.h>
 #include <wxVillaLib/PropDlg.h>
-#include "DVD.h"
+#include "NewProjectDlg.h"
 
-class DVDPropDlg: public wxPropDlg {
+class DVDPropDlg: public NewProjectDlg {
 public:
     DVDPropDlg(wxWindow *parent, DVD* dvd);
 	virtual ~DVDPropDlg() {}
