@@ -3,7 +3,7 @@
 // Purpose:     Languages dialog
 // Author:      Alex Thuering
 // Created:	23.05.2003
-// RCS-ID:      $Id: Languages.h,v 1.6 2010/06/30 20:05:05 ntalex Exp $
+// RCS-ID:      $Id: Languages.h,v 1.8 2012/07/22 09:31:23 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -14,10 +14,10 @@
 #include <wx/wx.h>
 #include <wxVillaLib/PropDlg.h>
 
-int ChooseLanguage();
+int ChooseLanguage(int defLanguage);
 const wxArrayString& GetLangNames();
-wxString GetLangName(int code);
-int GetLangCode(int index);
+wxString GetLangName(wxString langCode);
+wxString GetLangCode(int index);
 const BitmapArray& GetLangBitmaps();
 
 #endif // DVDSTYLER_LANGUAGES_H
