@@ -3,7 +3,7 @@
 // Purpose:     Main window
 // Author:      Alex Thuering
 // Created:     10.10.2003
-// RCS-ID:      $Id: MainWin.cpp,v 1.164 2012/09/18 20:20:02 ntalex Exp $
+// RCS-ID:      $Id: MainWin.cpp,v 1.171 2013/04/06 17:46:48 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -26,10 +26,12 @@
 #include <wx/artprov.h>
 #include <wx/msgdlg.h>
 #include <wx/stdpaths.h>
+#include <wx/progdlg.h>
 #include "math.h"
 
 #ifdef __WXMSW__
 #include <wx/msw/registry.h>
+#include "winutils.h"
 #endif
 
 #if defined(__WXMSW__) || defined(__WXMAC__)
@@ -121,7 +123,6 @@ BEGIN_EVENT_TABLE(MainWin, wxFrame)
 	EVT_MENU(THUMBMENU_DELETE_ID, MainWin::OnDelete)
 	EVT_UPDATE_UI(THUMBMENU_DELETE_ID, MainWin::OnDeleteUI)
 	EVT_MENU(THUMBMENU_REFRESH_ID, MainWin::OnRefresh)
-	EVT_UPDATE_UI(THUMBMENU_REFRESH_ID, MainWin::OnRefreshUI)
 	
 	EVT_SIZE(MainWin::OnResize)
 	EVT_SPLITTER_SASH_POS_CHANGED(SPLIITTER_TITLE_ID, MainWin::OnSplitterTitleSash)
@@ -131,6 +132,9 @@ END_EVENT_TABLE()
 /** Constructor */
 MainWin::MainWin(): wxFrame(NULL, -1, _T(""), wxDefaultPosition, wxDefaultSize,
 		wxDEFAULT_FRAME_STYLE), m_dvd(NULL), m_undoPos(0) {
+#ifdef __WXMSW__
+	m_taskbarInterface = NULL;
+#endif
     // begin wxGlade: MainWin::MainWin
     m_splitterTitle = new wxSplitterWindow(this, SPLIITTER_TITLE_ID, wxDefaultPosition, wxDefaultSize, wxCLIP_CHILDREN);
 #ifdef __WXMAC__
@@ -232,7 +236,7 @@ MainWin::MainWin(): wxFrame(NULL, -1, _T(""), wxDefaultPosition, wxDefaultSize,
 	AudioFormat af = (AudioFormat) s_config.GetDefAudioFormat();
 	AspectRatio ar = (AspectRatio) s_config.GetDefAspectRatio();
 	DiscCapacity dc = (DiscCapacity) s_config.GetDefDiscCapacity();
-	NewDVD(wxT(""), wxT(""), s_config.GetDefDiscLabel(), dc, s_config.GetVideoBitrate(),
+	NewDVD(wxT(""), wxT(""), s_config.GetDefDiscLabel(), dc, s_config.GetVideoBitrate(), s_config.GetAudioBitrate(),
 			vf <= vfCOPY ? vfPAL : vf, af <= afCOPY ? afMP2 : af, ar <= arAUTO ? ar4_3 : ar, cmdCALL_LAST_MENU);
 
 	// Restore frame size/position
@@ -264,6 +268,10 @@ MainWin::MainWin(): wxFrame(NULL, -1, _T(""), wxDefaultPosition, wxDefaultSize,
 
 MainWin::~MainWin() {
 	m_cache.Clear();
+#ifdef __WXMSW__
+	if (m_taskbarInterface != NULL)
+		m_taskbarInterface->Release();
+#endif
 }
 
 void MainWin::set_properties() {
@@ -599,11 +607,12 @@ void MainWin::OnSetBackgroundUI(wxUpdateUIEvent& event) {
 }
 
 void MainWin::OnRefresh(wxCommandEvent& event) {
-	m_thumbnails->UpdateItems();
-}
-
-void MainWin::OnRefreshUI(wxUpdateUIEvent& event) {
-	event.Enable(IsButtonSelected(DIR_TREE_BT_ID) && m_thumbnails->GetSelected() >= 0);
+	if (IsButtonSelected(DIR_TREE_BT_ID))
+		m_thumbnails->UpdateItems();
+	else if (IsButtonSelected(BACKGROUNS_BT_ID))
+		OnBackgroundsBt(event);
+	else if (IsButtonSelected(BUTTONS_BT_ID))
+		OnButtonsBt(event);
 }
 
 void MainWin::OnDelete(wxCommandEvent& event) {
@@ -649,7 +658,7 @@ void MainWin::OnClose(wxCloseEvent &event) {
 }
 
 void MainWin::NewDVD(wxString templateFile, wxString discTitle, wxString discLabel, DiscCapacity capacity,
-		int videoBitrate, VideoFormat videoFormat, AudioFormat audioFormat, AspectRatio aspectRatio,
+		int videoBitrate, int audioBitrate, VideoFormat videoFormat, AudioFormat audioFormat, AspectRatio aspectRatio,
 		DefaultPostCommand defPostCommand) {
 	if (aspectRatio == ar16_9 && templateFile.Length()
 			&& wxFile::Exists(templateFile.substr(0, templateFile.length()-5) + wxT("WS.dvdt")))
@@ -659,11 +668,17 @@ void MainWin::NewDVD(wxString templateFile, wxString discTitle, wxString discLab
 		m_dvd->SetCapacity(capacity);
 		m_dvd->SetVideoBitrateAuto(videoBitrate == -1);
 		m_dvd->SetVideoBitrate(videoBitrate > 0 ? videoBitrate : 4500);
+		m_dvd->SetAudioBitrate(audioBitrate);
 		m_dvd->SetVideoFormat(videoFormat);
 		m_dvd->SetAudioFormat(audioFormat);
 		m_dvd->SetAspectRatio(aspectRatio);
 		m_dvd->SetDefPostCommand(defPostCommand);
 		for (int tsi = -1; tsi < (int) m_dvd->GetTitlesets().GetCount(); tsi++) {
+			if (tsi >= 0) {
+				PgcArray& titles = m_dvd->GetPgcArray(tsi, false);
+				titles.GetVideo().SetFormat(videoFormat);
+				titles.GetVideo().SetAspect(aspectRatio);
+			}
 			PgcArray& menus = m_dvd->GetPgcArray(tsi, true);
 			menus.GetVideo().SetFormat(videoFormat);
 			menus.GetVideo().SetAspect(aspectRatio);
@@ -677,9 +692,9 @@ void MainWin::NewDVD(wxString templateFile, wxString discTitle, wxString discLab
 						MenuObjectParam* initParam = obj->GetInitParam();
 						if (initParam && (initParam->type == wxT("text") || initParam->type == wxT("string"))) {
 							wxString value = obj->GetParam(initParam->name);
-							if (value == wxT("Play All"))
+							if (value == wxT("Play All") || value == wxT("Play all"))
 								value = _("Play all");
-							else if (value == wxT("Select Title"))
+							else if (value == wxT("Select Title") || value == wxT("Select title"))
 								value = _("Select title");
 							else if (value == wxT("Back"))
 								value = _("Back");
@@ -716,9 +731,20 @@ void MainWin::NewDVD(wxString templateFile, wxString discTitle, wxString discLab
 }
 
 bool MainWin::Open(wxString filename) {
+	bool showProgressDlg = !filename.EndsWith(wxT(".dvdt"));
+	wxProgressDialog* pdlg = NULL;
+	if (showProgressDlg) {
+		pdlg = new wxProgressDialog(wxT("DVDStyler"), _("Please wait..."), 99, this,
+				wxPD_APP_MODAL | wxPD_AUTO_HIDE | wxPD_SMOOTH);
+		pdlg->Show();
+		pdlg->SetFocus();
+		pdlg->Pulse();
+	}
+	
 	DVD* dvd = new DVD;
 	if (!dvd->Open(filename)) {
 		delete dvd;
+		delete pdlg;
 		wxLogError(_("Error opening '%s'"), filename.c_str());
 		return false;
 	}
@@ -731,6 +757,8 @@ bool MainWin::Open(wxString filename) {
 	m_cache.Clear();
 	m_fileHistory.AddFileToHistory(m_dvd->GetFilename());
 	m_fileHistory.Save(*s_config.GetConfigBase());
+
+	delete pdlg;
 	return true;
 }
 
@@ -800,8 +828,7 @@ void MainWin::DoChangedDVD(bool doUndo) {
 	wxArrayInt b = m_dvd->CalculateVideoBitrate();
 	long size = m_dvd->GetSize();
 	long total = m_dvd->GetCapacityValue();
-	m_statusbar->SetFillStatus(size, total, b[1], b[2]/60, b[0],
-			m_dvd->IsVideoBitrateAuto(), s_config.GetAudioBitrate());
+	m_statusbar->SetFillStatus(size, total, b[1], b[2]/60, b[0], m_dvd->IsVideoBitrateAuto(), m_dvd->GetAudioBitrate());
 	// update selection
 	if (m_menuEditor->GetSelected().length())
 		m_menuEditor->Select(m_menuEditor->GetSelected());
@@ -837,7 +864,8 @@ void MainWin::OnNew(wxCommandEvent& event) {
 		TemplateDlg templateDlg(this, dlg.GetAspectRatio());
 		wxString templateFile = templateDlg.ShowModal() == wxID_OK ? templateDlg.GetTemplate() : wxT("");
 		NewDVD(templateFile, templateDlg.GetTitle(), dlg.GetLabel(), dlg.GetCapacity(), dlg.GetVideoBitrate(),
-				dlg.GetVideoFormat(), dlg.GetAudioFormat(), dlg.GetAspectRatio(), dlg.GetDefPostCommand());
+				dlg.GetAudioBitrate(), dlg.GetVideoFormat(), dlg.GetAudioFormat(), dlg.GetAspectRatio(),
+				dlg.GetDefPostCommand());
 	}
 }
 
@@ -928,6 +956,10 @@ please drag a video file into the bottom section of the window."), emptyTsi+1),
 }
 
 void MainWin::OnExit(wxCommandEvent& event) {
+	if (!TestSaved())
+		return;
+	if (!IsIconized())
+		s_config.SetMainWinLocation(GetRect(), IsMaximized());
 	Close(true);
 }
 
@@ -1102,3 +1134,50 @@ void MainWin::OnHelpContents(wxCommandEvent& event) {
 void MainWin::OnAbout(wxCommandEvent& event) {
 	About(this);
 }
+
+#ifdef __WXMSW__
+static const UINT uTaskbarBtnCreatedMsg = RegisterWindowMessage ( _T("TaskbarButtonCreated") );
+WXLRESULT MainWin::MSWWindowProc(WXUINT message, WXWPARAM wParam, WXLPARAM lParam) {
+	UNREFERENCED_PARAMETER(lParam);
+	if (message == uTaskbarBtnCreatedMsg) {
+		DWORD dwMajor = LOBYTE(LOWORD(GetVersion()));
+		DWORD dwMinor = HIBYTE(LOWORD(GetVersion()));
+		// Check that the Windows version is at least 6.1 (Win 7)
+		if (dwMajor > 6 || (dwMajor == 6 && dwMinor > 0)) {
+			HRESULT hr = 0;
+			hr = CoCreateInstance(CLSID_TaskbarList, NULL, CLSCTX_INPROC_SERVER,
+					IID_ITaskbarList3, (void**) &m_taskbarInterface);
+			if (FAILED(hr)) {
+				m_taskbarInterface->Release();
+				m_taskbarInterface = NULL;
+			}
+			if (m_taskbarInterface != NULL) {
+				m_taskbarInterface->SetProgressState(GetHWND(), TBPF_NORMAL);
+				m_taskbarInterface->SetProgressValue(GetHWND(), 0, 100);
+			}
+
+		}
+
+		return TRUE;
+	}
+	return wxFrame::MSWWindowProc(message, wParam, lParam);
+}
+#endif
+
+/** Sets progress bar value */
+void MainWin::SetProgressBarValue(unsigned int completed, unsigned int total) {
+#ifdef __WXMSW__
+	if (m_taskbarInterface != NULL) {
+		m_taskbarInterface->SetProgressValue(GetHWND(), completed, total);
+	}
+#endif
+}
+
+/** Sets progress bar state */
+void MainWin::SetProgressBarState(bool error) {
+#ifdef __WXMSW__
+	if (m_taskbarInterface != NULL) {
+		m_taskbarInterface->SetProgressState(GetHWND(), error ? TBPF_ERROR : TBPF_NORMAL);
+	}
+#endif
+}
