@@ -3,7 +3,7 @@
 // Purpose:     Main window
 // Author:      Alex Thuering
 // Created:	10.10.2003
-// RCS-ID:      $Id: MainWin.h,v 1.44 2012/06/24 23:01:23 ntalex Exp $
+// RCS-ID:      $Id: MainWin.h,v 1.47 2013/03/08 16:29:38 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -27,6 +27,10 @@
 
 using namespace std;
 
+#ifdef __WXMSW__
+	struct ITaskbarList3;
+#endif
+
 // begin wxGlade: dependencies
 #include <wx/splitter.h>
 // end wxGlade
@@ -68,7 +72,8 @@ public:
 	~MainWin();
 	/** Creates new project */
 	void NewDVD(wxString templateFile, wxString discTitle, wxString discLabel, DiscCapacity capacity, int videoBitrate,
-			VideoFormat videoFormat, AudioFormat audioFormat, AspectRatio aspectRatio, DefaultPostCommand defPostCommand);
+			int audioBitrate, VideoFormat videoFormat, AudioFormat audioFormat, AspectRatio aspectRatio,
+			DefaultPostCommand defPostCommand);
     /** Loads a project file */
 	bool Open(wxString filename);
 	/** Shows open dialog */
@@ -79,7 +84,11 @@ public:
     void Burn(bool start_close);
     /** Returns the file history */
     wxFileHistory& GetFileHistory() { return m_fileHistory; }
-	
+    /** Sets progress bar value */
+    void SetProgressBarValue(unsigned int completed, unsigned int total);
+    /** Sets progress bar state */
+    void SetProgressBarState(bool error = false);
+    
   private:
     // begin wxGlade: MainWin::attributes
     wxMenuBar* m_menubar;
@@ -159,7 +168,6 @@ public:
 	void OnDelete(wxCommandEvent& event);
 	void OnDeleteUI(wxUpdateUIEvent& event);
 	void OnRefresh(wxCommandEvent& event);
-	void OnRefreshUI(wxUpdateUIEvent& event);
 	
 	virtual void OnNew(wxCommandEvent& event); // wxGlade: <event_handler>
 	virtual void OnOpen(wxCommandEvent& event); // wxGlade: <event_handler>
@@ -186,6 +194,13 @@ public:
 	void OnSplitterTitleSash(wxSplitterEvent &event);
 	void OnResize(wxSizeEvent &event);
 	void OnClose(wxCloseEvent &event);
+	
+	
+#ifdef __WXMSW__
+	ITaskbarList3 *m_taskbarInterface;
+	WXLRESULT MSWWindowProc(WXUINT nMsg, WXWPARAM wParam, WXLPARAM lParam);
+#endif
+	
     DECLARE_EVENT_TABLE()
 }; // wxGlade: end class
 
