@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Menu
 // Author:      Alex Thuering
 // Created:	04.11.2003
-// RCS-ID:      $Id: Menu.cpp,v 1.110 2012/04/01 23:25:42 ntalex Exp $
+// RCS-ID:      $Id: Menu.cpp,v 1.114 2013/08/15 07:06:45 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -338,8 +338,7 @@ bool Menu::RemoveNotChangeable(wxSVGElement* element, MenuObject* obj) {
 	return element->GetChildren() == NULL; // return if has no children
 }
 
-void CopyCachedImages(wxSVGDocument* doc, wxSVGElement* parent1,
-		wxSVGElement* parent2) {
+void CopyCachedImages(wxSVGDocument* doc, wxSVGElement* parent1, wxSVGElement* parent2) {
 	wxSVGElement* elem1 = (wxSVGElement*) parent1->GetChildren();
 	wxSVGElement* elem2 = (wxSVGElement*) parent2->GetChildren();
 	while (elem1 && elem2) {
@@ -710,6 +709,7 @@ bool Menu::UpdateButtonImageFor(int actionTsi, int actionPgci, DVD* dvd) {
 		if (obj->IsButton() && !obj->GetAction().IsCustom() && obj->IsDisplayVideoFrame()
 				&& obj->GetAction().GetTsi() == actionTsi && obj->GetAction().GetPgci() == actionPgci
 				&& !obj->GetAction().IsMenu()) {
+			result = true; // action is found
 			for (int i = 0; i < obj->GetObjectParamsCount(); i++) {
 				MenuObjectParam* param = obj->GetObjectParam(i);
 				if (param->type == _T("image")) {
@@ -726,7 +726,6 @@ bool Menu::UpdateButtonImageFor(int actionTsi, int actionPgci, DVD* dvd) {
 						double dur = obj->GetParamVideoDuration(param->name);
 						obj->SetParamImageVideo(param->name, uri, pos, (int) lround(dur));
 						obj->UpdateSize();
-						result = true;
 					}
 				}
 			}
@@ -832,9 +831,13 @@ wxSvgXmlNode* Menu::GetXML(DVDFileType type, wxSvgXmlNode* node) {
 			// set relative path
 			wxSVGElement* elem = svg;
 			while (elem != NULL) {
-				if (elem->GetDtd() == wxSVG_IMAGE_ELEMENT) {
-					wxSVGImageElement* imgElem = (wxSVGImageElement*)elem;
-					wxString href = imgElem->GetHref();
+				if (elem->GetDtd() == wxSVG_IMAGE_ELEMENT || elem->GetDtd() == wxSVG_VIDEO_ELEMENT) {
+					wxSVGURIReference* uriElem = NULL;
+					if (elem->GetDtd() == wxSVG_IMAGE_ELEMENT)
+						uriElem = (wxSVGImageElement*) elem;
+					else // elem->GetDtd() == wxSVG_VIDEO_ELEMENT
+						uriElem = (wxSVGVideoElement*) elem;
+					wxString href = uriElem->GetHref();
 					wxString frameStr;
 					if (href.Find(wxT('#')) > 0) {
 						frameStr = wxT('#') + href.AfterLast(wxT('#'));
@@ -842,9 +845,9 @@ wxSvgXmlNode* Menu::GetXML(DVDFileType type, wxSvgXmlNode* node) {
 					}
 					wxFileName fname(href);
 					if (fname.GetPath() == m_dvd->GetPath(false))
-						imgElem->SetHref(fname.GetFullName() + frameStr);
+						uriElem->SetHref(fname.GetFullName() + frameStr);
 					else if (m_dvd->GetPath(false).length() > 0 && fname.GetPath().StartsWith(m_dvd->GetPath(false)))
-						imgElem->SetHref(fname.GetPath().substr(m_dvd->GetPath(false).length() + 1)
+						uriElem->SetHref(fname.GetPath().substr(m_dvd->GetPath(false).length() + 1)
 								+ wxFILE_SEP_PATH + fname.GetFullName() + frameStr);
 				}
 				if (elem->GetChildren() != NULL && (elem->GetDtd() == wxSVG_SVG_ELEMENT
@@ -926,9 +929,13 @@ bool Menu::PutXML(wxSvgXmlNode* node) {
 			// fix relative path
 			wxSVGElement* elem = m_svg->GetRootElement();
 			while (elem != NULL) {
-				if (elem->GetDtd() == wxSVG_IMAGE_ELEMENT) {
-					wxSVGImageElement* imgElem = (wxSVGImageElement*)elem;
-					wxString href = imgElem->GetHref();
+				if (elem->GetDtd() == wxSVG_IMAGE_ELEMENT || elem->GetDtd() == wxSVG_VIDEO_ELEMENT) {
+					wxSVGURIReference* uriElem = NULL;
+					if (elem->GetDtd() == wxSVG_IMAGE_ELEMENT)
+						uriElem = (wxSVGImageElement*) elem;
+					else // elem->GetDtd() == wxSVG_VIDEO_ELEMENT
+						uriElem = (wxSVGVideoElement*) elem;
+					wxString href = uriElem->GetHref();
 					if (href.length()) {
 						wxString frameStr;
 						if (href.Find(wxT('#')) > 0) {
@@ -937,9 +944,9 @@ bool Menu::PutXML(wxSvgXmlNode* node) {
 						}
 						wxFileName fname(href);
 						if (fname.IsRelative())
-							imgElem->SetHref(m_dvd->GetPath() + fname.GetFullPath() + frameStr);
+							uriElem->SetHref(m_dvd->GetPath() + fname.GetFullPath() + frameStr);
 						else if (!wxFileExists(href) && wxFileExists(m_dvd->GetPath() + fname.GetFullName()))
-							imgElem->SetHref(m_dvd->GetPath() + fname.GetFullName() + frameStr);
+							uriElem->SetHref(m_dvd->GetPath() + fname.GetFullName() + frameStr);
 					}
 				}
 				if (elem->GetChildren() != NULL && (elem->GetDtd() == wxSVG_SVG_ELEMENT
@@ -952,6 +959,8 @@ bool Menu::PutXML(wxSvgXmlNode* node) {
 						elem = (wxSVGElement*) elem->GetNextSibling();
 				}
 			}
+			// Init SVG Canvas
+			m_svg->Render();
 	    } else { // deprecated
 	    	if (node->GetPropVal(wxT("bgFile"), &val))
 	    		SetBackground(val);
