@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Menu
 // Author:      Alex Thuering
 // Created:	    04.11.2003
-// RCS-ID:      $Id: Menu.h,v 1.57 2011/08/14 08:43:49 ntalex Exp $
+// RCS-ID:      $Id: Menu.h,v 1.59 2012/03/29 21:19:22 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -12,6 +12,7 @@
 #define MENU_H
 
 #include "MenuObject.h"
+#include "Utils.h"
 #include "mediaenc.h"
 #include <wxSVG/SVGPreserveAspectRatio.h>
 
@@ -23,7 +24,6 @@ enum MenuDrawType {
 	mdBUTTONS_SELECTED
 };
 
-WX_DEFINE_ARRAY(DVDAction*, DVDActions);
 WX_DEFINE_ARRAY(MenuObject*, MenuObjects);
 class DVD;
 
@@ -112,7 +112,8 @@ public:
 	/** Makes button with given id the first button */
 	void SetFirstButton(wxString id);
 	
-	inline unsigned int GetActionsCount() { return m_actions.Count(); }
+	inline vector<DVDAction*>& GetActions() { return m_actions; }
+	inline unsigned int GetActionsCount() { return m_actions.size(); }
 	inline DVDAction* GetAction(int index) { return m_actions[index]; }
 	
 	/** Returns true if the last selected button must be remembered */
@@ -123,6 +124,9 @@ public:
 	inline int GetRememberLastButtonRegister() { return m_rememberLastButtonRegister; }
 	/** Sets g-register for "remember last selected button" */
 	inline void SetRememberLastButtonRegister(int gregister) { m_rememberLastButtonRegister = gregister; }
+	
+	/** Checks if buttons overlapping */
+	bool isButtonsOverlapping();
 
 	wxImage GetImage(int width, int height);
 	wxImage GetBackgroundImage();
@@ -160,7 +164,7 @@ private:
 	AspectRatio m_aspectRatio;
 	wxString 	m_startTime, m_endTime;
 	MenuObjects m_objects;
-	DVDActions m_actions;
+	vector<DVDAction*> m_actions;
 	bool m_rememberLastButton;
 	int m_rememberLastButtonRegister;
 	void SetBackground(wxSVGSVGElement* svg, wxString fileName);
