@@ -3,7 +3,7 @@
 // Purpose:     The widget to edit a DVD Menu
 // Author:      Alex Thuering
 // Created:     11.10.2003
-// RCS-ID:      $Id: MenuEditor.cpp,v 1.67 2012/07/22 09:33:20 ntalex Exp $
+// RCS-ID:      $Id: MenuEditor.cpp,v 1.69 2013/01/07 14:40:03 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -130,7 +130,7 @@ public:
 					tsi = m_menuEditor->GetDVD()->GetTitlesets().size() - 1;
 				if (tsi == -1)
 					tsi = 0;
-				if (m_menuEditor->GetTitlesetManager()->AddVideo(filename, true, tsi)) {
+				if (m_menuEditor->GetTitlesetManager()->AddVideo(filename, true, tsi, false)) {
 					int pgci = m_menuEditor->GetDVD()->GetPgcArray(tsi, false).GetCount()-1;
 					AddButton(x, y, tsi, pgci, false, 0, !first);
 				}
@@ -1045,6 +1045,21 @@ void MenuEditor::OnKeyDown(wxKeyEvent& event) {
 				OnObjectDelete(evt);
 			}
 			break;
+		case 'A':
+			if (event.ControlDown()) {
+				// select all objects
+				for (unsigned int i = 0; i < m_menu->GetObjectsCount(); i++) {
+					MenuObject* obj = m_menu->GetObject(i);
+					wxString id = obj->GetId();
+					if (m_selectedIds.Index(id) == wxNOT_FOUND) {
+						m_selectedIds.push_back(id);
+						CreateSelection(id);
+					}
+				}
+				Refresh();
+				SendChangedEvent();
+			}
+			break;
 		case 'C':
 			if (event.ControlDown() && m_selectedIds.size() == 1) {
 				wxCommandEvent evt;
