@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Menu Object
 // Author:      Alex Thuering
 // Created:	04.11.2006
-// RCS-ID:      $Id: MenuObject.cpp,v 1.42 2012/10/14 14:58:19 ntalex Exp $
+// RCS-ID:      $Id: MenuObject.cpp,v 1.46 2013/04/02 06:44:00 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -47,6 +47,7 @@ MenuObject::MenuObject(Menu* menu, bool vmg, wxString fileName, int x, int y, wx
 	m_previewHighlighted = false;
 
 	m_button = false;
+	m_autoExecute = false;
 	m_displayVideoFrame = true;
 	m_customVideoFrame = false;
 
@@ -447,6 +448,8 @@ wxString MenuObject::GetParam(wxString name, wxString attribute) {
 		return elem->GetAttribute(attribute.length() && attribute[0] != wxT('-') ?
 				attribute : param->attribute + attribute);
 	} else if (elem->GetDtd() == wxSVG_TEXT_ELEMENT) {
+		if (attribute.length())
+			return elem->GetAttribute(attribute);
 		wxString value;
 		wxSvgXmlNode* child = elem->GetChildren();
 		while (child != NULL) {
@@ -494,6 +497,10 @@ void MenuObject::SetParam(wxString name, wxString value, wxString attribute) {
 		if (elem->GetDtd() == wxSVG_IMAGE_ELEMENT && param->attribute == wxT("xlink:href"))
 			((wxSVGImageElement*) elem)->SetCanvasItem(NULL);
 	} else if (elem->GetDtd() == wxSVG_TEXT_ELEMENT) {
+		if (attribute.length()) {
+			elem->SetAttribute(attribute, value);
+			return;
+		}
 		wxStringTokenizer tokenizer(value, wxT("\r\n"), wxTOKEN_RET_EMPTY_ALL);
 		wxSvgXmlNode* child = elem->GetChildren();
 		while (tokenizer.HasMoreTokens()) {
@@ -834,7 +841,7 @@ wxString MenuObject::GetDefaultFocusDest(NavigationButton navButton) {
 			buttons.insert(buttons.begin(), it->second.begin(), it->second.end());
 	if (buttons.IsEmpty()) {
 		if (btMapAll.empty())
-			return wxT("");
+			return GetId(); // 'none'
 		buttons = btMapAll[minDistAll];
 	}
 	// filter by distance to left/up
@@ -853,7 +860,7 @@ wxString MenuObject::GetDefaultFocusDest(NavigationButton navButton) {
 			resultDist = dist;
 		}
 	}
-	return result;
+	return result.length() ? result : GetId(); // GetID() -> 'none'
 }
 
 wxImage MenuObject::GetImage(int maxWidth, int maxHeight) {
@@ -879,7 +886,7 @@ wxImage MenuObject::GetImage(int maxWidth, int maxHeight) {
 wxSvgXmlNode* MenuObject::GetXML(DVDFileType type, DVD* dvd, SubStreamMode mode, bool withSVG) {
 	wxString rootName = wxT("object");
 	if (IsButton())
-		rootName = wxT("button");
+		rootName = IsAutoExecute() && type == SPUMUX_XML ? wxT("action") : wxT("button");
 	wxSvgXmlNode* rootNode = new wxSvgXmlNode(wxSVGXML_ELEMENT_NODE, rootName);
 	switch (type) {
 	case DVDSTYLER_XML:
@@ -913,6 +920,8 @@ wxSvgXmlNode* MenuObject::GetXML(DVDFileType type, DVD* dvd, SubStreamMode mode,
 		rootNode->AddProperty(wxT("id"), GetId());
 		if (m_defaultSize)
 			rootNode->AddProperty(wxT("defSize"), wxT("true"));
+		if (IsAutoExecute())
+			rootNode->AddProperty(wxT("autoExecute"), wxT("true"));
 		if (m_keepAspectRatio)
 			rootNode->AddProperty(wxT("keepAspectRatio"), wxT("true"));
 		if (!m_displayVideoFrame)
@@ -1049,6 +1058,7 @@ bool MenuObject::PutXML(wxSvgXmlNode* node) {
 	}
 
 	node->GetPropVal(wxT("id"), &m_id);
+	m_autoExecute = node->GetPropVal(wxT("autoExecute"), &val) && (val == wxT("true") || val == wxT("1"));
 	if (!node->GetPropVal(wxT("defSize"), &val) || (val != wxT("true") && val != wxT("1")))
 		m_defaultSize = false;
 	m_keepAspectRatio = node->GetPropVal(wxT("keepAspectRatio"), &val) && (val == wxT("true") || val == wxT("1"));
