@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Menu Object
 // Author:      Alex Thuering
 // Created:	04.11.2006
-// RCS-ID:      $Id: MenuObject.h,v 1.24 2012/01/08 16:10:56 ntalex Exp $
+// RCS-ID:      $Id: MenuObject.h,v 1.25 2012/10/27 09:33:39 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -78,6 +78,11 @@ public:
 	inline bool IsButton() { return m_button; }
 	/** Returns button action */
 	inline DVDAction& GetAction() { return m_action; }
+	
+	/** Returns true, if it's an auto-execute button. */
+	inline bool IsAutoExecute() { return m_autoExecute; }
+	/** Sets, if it's an auto-execute button. */
+	inline void SetAutoExecute(bool autoExecute) { m_autoExecute = autoExecute; }
     
     inline wxString GetFileName() { return m_fileName; }
     inline wxString GetTitle() { return m_title; }
@@ -151,6 +156,7 @@ public:
 	Menu* m_menu; // can be null
 	wxString m_id;
 	bool m_button;
+	bool m_autoExecute;
 	DVDAction m_action;
 	wxString m_fileName;
 	wxString m_title;
