@@ -3,7 +3,7 @@
 // Purpose:     DVD menu button properties dialog
 // Author:      Alex Thuering
 // Created:	20.11.2003
-// RCS-ID:      $Id: MenuObjectPropDlg.cpp,v 1.58 2012/07/01 19:27:08 ntalex Exp $
+// RCS-ID:      $Id: MenuObjectPropDlg.cpp,v 1.67 2013/06/23 20:59:55 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -11,9 +11,18 @@
 #include "MenuObjectPropDlg.h"
 #include "VideoFrameDlg.h"
 #include "Config.h"
+#include <wxVillaLib/utils.h>
 #include <wxSVG/svg.h>
 #include <wx/statline.h>
+#include <wx/collpane.h>
+#include <wx/tglbtn.h>
 #include <stdint.h>
+#include "rc/justifyLeft.png.h"
+#include "rc/justifyCenter.png.h"
+#include "rc/justifyRight.png.h"
+#if !wxCHECK_VERSION(2,9,0)
+#define wxBitmapToggleButton wxToggleBitmapButton
+#endif
 
 enum {
 	JUMP_ACTION_RADIO_ID = 7900,
@@ -24,7 +33,10 @@ enum {
 	KEEP_ASPECT_CB_ID,
 	IMAGE_RADIO_ID,
 	VIDEOFRAME_RADIO_ID,
-	VIDEOFRAME_BT_ID
+	VIDEOFRAME_BT_ID,
+	JUSTIFY_LEFT_BT_ID,
+	JUSTIFY_CENTER_BT_ID,
+	JUSTIFY_RIGHT_BT_ID,
 };
 
 BEGIN_EVENT_TABLE(MenuObjectPropDlg, wxPropDlg)
@@ -36,11 +48,13 @@ BEGIN_EVENT_TABLE(MenuObjectPropDlg, wxPropDlg)
 	EVT_RADIOBUTTON(IMAGE_RADIO_ID, MenuObjectPropDlg::OnImageRadio)
 	EVT_RADIOBUTTON(VIDEOFRAME_RADIO_ID, MenuObjectPropDlg::OnImageRadio)
 	EVT_BUTTON(VIDEOFRAME_BT_ID, MenuObjectPropDlg::OnVideoFrame)
+	EVT_TOGGLEBUTTON(JUSTIFY_LEFT_BT_ID, MenuObjectPropDlg::OnJustifyText)
+	EVT_TOGGLEBUTTON(JUSTIFY_CENTER_BT_ID, MenuObjectPropDlg::OnJustifyText)
+	EVT_TOGGLEBUTTON(JUSTIFY_RIGHT_BT_ID, MenuObjectPropDlg::OnJustifyText)
 END_EVENT_TABLE()
 
 MenuObjectPropDlg::MenuObjectPropDlg(wxWindow* parent, wxString id, bool multObjects, Menu* menu, DVD* dvd, int tsi,
-		int pgci): wxPropDlg(parent, wxString(_("Properties"))
-				+ (!multObjects ? wxT(" - ") + menu->GetObject(id)->GetId(true) : wxT(""))) {
+		int pgci): wxPropDlg(parent, wxString(_("Properties"))) {
 	m_id = id;
 	m_multObjects = multObjects;
 	m_menu = menu;
@@ -48,6 +62,7 @@ MenuObjectPropDlg::MenuObjectPropDlg(wxWindow* parent, wxString id, bool multObj
 	m_tsi = tsi;
 	m_pgci = pgci;
 	m_imageEdit = NULL;
+	m_imageEditIdx = -1;
 	m_imageRadio = NULL;
 	m_videoFrameRadio = NULL;
 	m_videoFrameBt = NULL;
@@ -59,7 +74,11 @@ MenuObjectPropDlg::MenuObjectPropDlg(wxWindow* parent, wxString id, bool multObj
 	m_defaultPos = 0;
 	m_videoPos = 0;
 	m_videoDuration = 0;
+	m_targetChoice = NULL;
+	m_chapterChoice = NULL;
 	Create();
+	if (!multObjects)
+		SetTitle(GetTitle()+ wxT(" - ") + menu->GetObject(id)->GetId(true));
 }
 
 void MenuObjectPropDlg::CreatePropPanel(wxSizer* sizer) {
@@ -70,6 +89,12 @@ void MenuObjectPropDlg::CreatePropPanel(wxSizer* sizer) {
 	if (m_object->IsButton() && !m_multObjects) {
 		DVDAction& action = m_object->GetAction();
 		AddStaticLine(mainSizer, _("Action"));
+//		wxCollapsiblePane* collPane = new wxCollapsiblePane(this, wxID_ANY, _("Action"));
+//		mainSizer->Add(collPane, 0, wxEXPAND);
+//#ifdef __WXMSW__
+//		((wxButton*) ((wxGenericCollapsiblePane*) collPane)->GetControlWidget())->SetWindowStyle(wxBORDER_NONE | wxBU_NOTEXT);
+//		((wxButton*) ((wxGenericCollapsiblePane*) collPane)->GetControlWidget())->SetLabel("test");
+//#endif
 		grid = new wxFlexGridSizer(2, 4, 16);
 		grid->AddGrowableCol(1);
 		// check menu entry if it is set
@@ -139,20 +164,18 @@ void MenuObjectPropDlg::CreatePropPanel(wxSizer* sizer) {
 		AddChoiceProp(s, wxT(""), labels[subtitleIdx], labels, 0, true);
 		if (m_dvd->GetSubtitleStreamsCount() == 0)
 			GetLastControl()->Enable(false);
+		
+		AddCheckProp(s, _("Auto execute"), m_object->IsAutoExecute());
 
-		grid = new wxFlexGridSizer(3, 4, 4, 16);
-		grid->AddGrowableCol(0);
+		grid = new wxFlexGridSizer(3, 4, 16);
+		AddText(grid, _("Navigation"));
+		AddNavigationProp(grid, nbUP);
 		grid->Add(10,10);
-		AddText(grid, _("Focus"));
-		AddFocusDestProp(grid, nbUP);
+		AddNavigationProp(grid, nbLEFT);
 		grid->Add(10,10);
+		AddNavigationProp(grid, nbRIGHT);
 		grid->Add(10,10);
-		AddFocusDestProp(grid, nbLEFT);
-		grid->Add(10,10);
-		AddFocusDestProp(grid, nbRIGHT);
-		grid->Add(10,10);
-		grid->Add(10,10);
-		AddFocusDestProp(grid, nbDOWN);
+		AddNavigationProp(grid, nbDOWN);
 		grid->Add(10,10);
 		mainSizer->Add(grid, 0, wxEXPAND|wxALL, 4);
 		AddStaticLine(mainSizer, _("Look"));
@@ -201,12 +224,33 @@ void MenuObjectPropDlg::CreateLook(wxBoxSizer* mainSizer, wxFlexGridSizer* grid)
 				AddTextProp(sizer2, wxT(""), m_object->GetParam(param->name), m_multObjects, -1, true, wxTE_MULTILINE);
 				if (m_multObjects)
 					GetLastControl()->Enable(false);
-				AddFontProp(sizer2, wxT(""), m_object->GetParamFont(param->name), _("Font..."));
+				wxBoxSizer* sizer3 = new wxBoxSizer(wxVERTICAL);
+				AddFontProp(sizer3, wxT(""), m_object->GetParamFont(param->name), _("Font..."));
+				wxBoxSizer* sizer4 = new wxBoxSizer(wxHORIZONTAL);
+				bool enableJustify = m_object->GetParam(param->name, wxT("x")) == wxT("0")
+						|| m_object->GetParam(param->name, wxT("x")) == wxT("50%")
+						|| m_object->GetParam(param->name, wxT("x")) == wxT("100%");
+				AddBitmapToggleButton(sizer4, m_object->GetParam(param->name, wxT("text-anchor")) == wxT("start"),
+						JUSTIFY_LEFT_BT_ID, wxBITMAP_FROM_MEMORY(justifyLeft), wxSize(22, 22));
+				GetLastControl()->Enable(enableJustify);
+				AddBitmapToggleButton(sizer4, m_object->GetParam(param->name, wxT("text-anchor")) == wxT("middle"),
+						JUSTIFY_CENTER_BT_ID, wxBITMAP_FROM_MEMORY(justifyCenter), wxSize(22, 22));
+				GetLastControl()->Enable(enableJustify);
+				AddBitmapToggleButton(sizer4, m_object->GetParam(param->name, wxT("text-anchor")) == wxT("end"),
+						JUSTIFY_RIGHT_BT_ID, wxBITMAP_FROM_MEMORY(justifyRight), wxSize(22, 22));
+				GetLastControl()->Enable(enableJustify);
+				sizer3->Add(sizer4, 0, wxEXPAND);
+				sizer2->Add(sizer3, 0, wxEXPAND);
 				grid->Add(sizer2, 0, wxEXPAND);
 			} else if (param->type == _T("string")) {
 				AddTextProp(grid, title, m_object->GetParam(param->name));
 			} else if (param->type == _T("decimal")) {
-				AddTextProp(grid, title, m_object->GetParam(param->name), false, 54);
+				long min = 0, max = 999;
+				if (param->type.Find(wxT('(')) != -1 && param->type.Find(wxT(')')) != -1) {
+					param->type.AfterFirst(wxT('(')).BeforeFirst(wxT(',')).Strip(wxString::both).ToLong(&min);
+					param->type.BeforeFirst(wxT(')')).AfterFirst(wxT(',')).Strip(wxString::both).ToLong(&max);
+				}
+				AddSpinDoubleProp(grid, title, m_object->GetParamDouble(param->name), min, max, 54);
 				if (m_multObjects && param->attribute.Find(wxT('#')) != wxNOT_FOUND)
 					GetLastControl()->Enable(false);
 			} else if (param->type.Mid(0,7) == _T("integer")) {
@@ -218,6 +262,10 @@ void MenuObjectPropDlg::CreateLook(wxBoxSizer* mainSizer, wxFlexGridSizer* grid)
 				AddSpinProp(grid, title, m_object->GetParamInt(param->name), min, max, max < 1000 ? 54 : 80);
 				if (m_multObjects && param->attribute.Find(wxT('#')) != wxNOT_FOUND)
 					GetLastControl()->Enable(false);
+			} else if (param->type.Mid(0,7) == _T("percent")) {
+				AddSpinProp(grid, title, m_object->GetParamDouble(param->name)*100, 0, 100, 54, wxT("%"));
+				if (m_multObjects && param->attribute.Find(wxT('#')) != wxNOT_FOUND)
+					GetLastControl()->Enable(false);
 			} else if (param->type == _T("image") && !m_multObjects) {
 				wxString imageFile = m_object->GetParam(param->name);
 				if (m_object->IsButton()) {
@@ -226,9 +274,9 @@ void MenuObjectPropDlg::CreateLook(wxBoxSizer* mainSizer, wxFlexGridSizer* grid)
 					bool image = !m_displayVideoFrame || !hasVideo || fname != GetVideoFilename(false);
 					AddRadioProp(grid, wxString(_("Image")) + wxT(":"), image, wxRB_GROUP, false, IMAGE_RADIO_ID);
 					m_imageRadio = (wxRadioButton*) GetLastControl();
-					AddFileProp(grid, wxT(""), image ? imageFile : wxT(""), wxFD_OPEN, wxT("..."),
-							_("Image Files ") + wxImage::GetImageExtWildcard()
-							+ wxT("|") + wxString(_("All Files")) + wxT(" (*.*)|*.*"));
+					wxString wildcard = _("Image Files ") + wxImage::GetImageExtWildcard()
+						+ wxT("|") + wxString(_("All Files")) + wxT(" (*.*)|*.*"); 
+					AddFileProp(grid, wxT(""), wxString(image ? imageFile : wxT("")), wxFD_OPEN, wxT("..."), wildcard);
 					m_imageEdit = (wxTextCtrl*) GetLastControl();
 					m_imageEditIdx = GetLastControlIndex();
 					AddRadioProp(grid, wxString(_("Video")) + wxT(":"), !image, 0, false, VIDEOFRAME_RADIO_ID);
@@ -288,15 +336,15 @@ void MenuObjectPropDlg::CreateLook(wxBoxSizer* mainSizer, wxFlexGridSizer* grid)
 				shadowSizer->AddSpacer(8);
 				AddText(shadowSizer, _("Offset:"));
 				shadowSizer->AddSpacer(4);
-				AddSpinProp(shadowSizer, wxT(""), m_object->GetParamInt(param->name, wxT("x")), -999, 999, 54, wxT(""), false);
-				AddSpinProp(shadowSizer, wxT(""), m_object->GetParamInt(param->name, wxT("y")), -999, 999, 54, wxT(""), false);
+				AddSpinProp(shadowSizer, wxT(""), m_object->GetParamInt(param->name, wxT("x")), -999, 999, 46, wxT(""), false);
+				AddSpinProp(shadowSizer, wxT(""), m_object->GetParamInt(param->name, wxT("y")), -999, 999, 46, wxT(""), false);
 				shadowSizer->AddSpacer(4);
 				wxSVGElement* filter = m_object->GetElementById(param->element + wxT("Filter"));
 				if (filter && ((wxSVGElement*)filter->GetFirstChild())->GetDtd() == wxSVG_FEGAUSSIANBLUR_ELEMENT) {
 					wxSVGFEGaussianBlurElement* blur = (wxSVGFEGaussianBlurElement*) filter->GetFirstChild();
 					AddText(shadowSizer, _("Deviation:"));
 					shadowSizer->AddSpacer(4);
-					AddTextProp(shadowSizer, wxT(""), blur->GetAttribute(wxT("stdDeviation")), false, 54);
+					AddSpinDoubleProp(shadowSizer, wxT(""), blur->GetStdDeviationX(), 0, 99, 46);
 				}
 				EndGroup();
 			}
@@ -564,11 +612,17 @@ void MenuObjectPropDlg::OnVideoFrame(wxCommandEvent& evt) {
 	}
 }
 
+void MenuObjectPropDlg::OnJustifyText(wxCommandEvent& evt) {
+	((wxBitmapToggleButton*) this->FindWindow(JUSTIFY_LEFT_BT_ID))->SetValue(evt.GetId() == JUSTIFY_LEFT_BT_ID);
+	((wxBitmapToggleButton*) this->FindWindow(JUSTIFY_CENTER_BT_ID))->SetValue(evt.GetId() == JUSTIFY_CENTER_BT_ID);
+	((wxBitmapToggleButton*) this->FindWindow(JUSTIFY_RIGHT_BT_ID))->SetValue(evt.GetId() == JUSTIFY_RIGHT_BT_ID);
+}
+
 void MenuObjectPropDlg::OnKeepAspectRatio(wxCommandEvent& evt) {
 	m_heightEdit->SetValue(m_widthEdit->GetValue());
 }
 
-void MenuObjectPropDlg::AddFocusDestProp(wxSizer* sizer, NavigationButton navButton) {
+void MenuObjectPropDlg::AddNavigationProp(wxSizer* sizer, NavigationButton navButton) {
 	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 1, 4, 16);
 	AddChoiceProp(grid, wxT(""), wxT(""), wxArrayString());
 	wxChoice* ctrl = (wxChoice*) m_controls[m_controls.Count()-1];
@@ -576,21 +630,22 @@ void MenuObjectPropDlg::AddFocusDestProp(wxSizer* sizer, NavigationButton navBut
 	// default navigation
 	wxString defBtId = m_object->GetDefaultFocusDest(navButton);
 	wxString text = _("none");
-	if (defBtId.length()) {
+	if (defBtId != m_object->GetId()) {
 		long l = -1;
 		if (defBtId.Mid(6).ToLong(&l))
 			text = _("button") + wxString::Format(wxT(" %d"), (int) l);
 	}
 	ctrl->Append(_("auto") + wxString(wxT(" (")) + text + wxT(")"), new wxString);
+	ctrl->Append(_("none"), new wxString(m_object->GetId()));
 
 	// add all buttons except current
-	int sel = 0;
+	int sel = m_object->GetFocusDest(navButton) == m_object->GetId() ? 1 : 0;
 	for (unsigned int i=0; i<m_menu->GetObjectsCount(); i++) {
 		MenuObject* obj = m_menu->GetObject(i);
 		if (obj->IsButton() && obj != m_object) {
 			wxString id = obj->GetId();
 			if (m_object->GetFocusDest(navButton) == id)
-			sel = ctrl->GetCount();
+				sel = ctrl->GetCount();
 			long l = -1;
 			id.Mid(6).ToLong(&l);
 			wxString text = _("button") + wxString::Format(wxT(" %d"), (int) l);
@@ -607,9 +662,6 @@ void MenuObjectPropDlg::AddFocusDestProp(wxSizer* sizer, NavigationButton navBut
 		ctrl->Append(id, new wxString(id));
 	}
 	ctrl->SetSelection(sel);
-#ifdef __WXMSW__
-	ctrl->SetSizeHints(ctrl->GetSize().GetWidth()*3/2, -1, ctrl->GetSize().GetWidth()*3/2, -1);
-#endif
 	sizer->Add(grid, 0, 0, 0);
 }
 
@@ -640,7 +692,7 @@ bool MenuObjectPropDlg::SetValues() {
 		action.SetMenu(IsSelectedMenu());
 		if (GetSelectedTsi() != m_tsi && IsSelectedMenu() && GetSelectedPgci() > 0) {
 			const StringSet& entries = m_dvd->GetPgcArray(GetSelectedTsi(), true)[GetSelectedPgci()]->GetEntries();
-			action.SetEntry(entries.size() > 0 ? *entries.begin() : wxT(""));
+			action.SetEntry(wxString(entries.size() > 0 ? *entries.begin() : wxT("")));
 		} else
 			action.SetEntry(wxT(""));
 		action.SetChapter(GetSelectedChapter());
@@ -660,6 +712,7 @@ bool MenuObjectPropDlg::SetValues() {
 		n++;
 		action.SetAudio(GetInt(n++) - 1);
 		action.SetSubtitle(GetInt(n++) - 1);
+		m_object->SetAutoExecute(GetBool(n++));
 
 		wxString* id = (wxString*) GetClientData(n++);
 		m_object->SetFocusDest(nbUP, *id);
@@ -686,10 +739,26 @@ bool MenuObjectPropDlg::SetValues() {
 			if (param->type == _T("text")) {
 				m_object->SetParam(param->name, GetString(n++));
 				m_object->SetParamFont(param->name, GetFont(n++).GetChosenFont());
-			} else if (param->type == _T("string") || param->type == _T("decimal"))
+				if (GetBool(n++)) {
+					m_object->SetParam(param->name, wxT("start"), wxT("text-anchor"));
+					m_object->SetParam(param->name, wxT("0"), wxT("x"));
+				}
+				if (GetBool(n++)) {
+					m_object->SetParam(param->name, wxT("middle"), wxT("text-anchor"));
+					m_object->SetParam(param->name, wxT("50%"), wxT("x"));
+				}
+				if (GetBool(n++)) {
+					m_object->SetParam(param->name, wxT("end"), wxT("text-anchor"));
+					m_object->SetParam(param->name, wxT("100%"), wxT("x"));
+				}
+			} else if (param->type == _T("string"))
 				m_object->SetParam(param->name, GetString(n++));
 			else if (param->type.Mid(0, 7) == _T("integer"))
 				m_object->SetParamInt(param->name, GetInt(n++));
+			else if (param->type.Mid(0, 7) == _T("decimal"))
+				m_object->SetParamDouble(param->name, GetDouble(n++));
+			else if (param->type == _T("percent"))
+				m_object->SetParamDouble(param->name, ((double)GetInt(n++))/100);
 			else if (param->type == _T("colour")) {
 				m_object->SetParamColour(param->name, GetColour(n++));
 				wxString opacity = wxString::Format(wxT("%g"), (double) GetInt(n++) / 100);
@@ -717,7 +786,8 @@ bool MenuObjectPropDlg::SetValues() {
 				wxSVGElement* filter = m_object->GetElementById(param->element + wxT("Filter"));
 				if (filter && ((wxSVGElement*)filter->GetFirstChild())->GetDtd() == wxSVG_FEGAUSSIANBLUR_ELEMENT) {
 					wxSVGFEGaussianBlurElement* blur = (wxSVGFEGaussianBlurElement*) filter->GetFirstChild();
-					blur->SetAttribute(wxT("stdDeviation"), GetString(n++));
+					double stdDeviation = GetDouble(n++);
+					blur->SetStdDeviation(stdDeviation, stdDeviation);
 				}
 			}
 		}
