@@ -3,7 +3,7 @@
 // Purpose:     DVD menu button properties dialog
 // Author:      Alex Thuering
 // Created:	20.11.2003
-// RCS-ID:      $Id: MenuObjectPropDlg.h,v 1.20 2012/01/13 18:20:44 ntalex Exp $
+// RCS-ID:      $Id: MenuObjectPropDlg.h,v 1.22 2013/04/02 06:45:27 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -61,6 +61,7 @@ private:
 	wxString GetVideoFilename(bool withTimestamp = false, long position = -1);
 	void OnImageRadio(wxCommandEvent& evt);
 	void OnVideoFrame(wxCommandEvent& evt);
+	void OnJustifyText(wxCommandEvent& evt);
 	
 	wxTextCtrl* m_customActionEdit;
 	void OnJumpActionSelected(wxCommandEvent& evt);
@@ -70,7 +71,7 @@ private:
 	wxTextCtrl* m_heightEdit;
 	void OnKeepAspectRatio(wxCommandEvent& evt);
 	
-	void AddFocusDestProp(wxSizer* sizer, NavigationButton navButton);
+	void AddNavigationProp(wxSizer* sizer, NavigationButton navButton);
 	bool SetValues();
 	
 	DECLARE_EVENT_TABLE()
