@@ -3,7 +3,7 @@
 // Purpose:     The class to create and store menu palettes 
 // Author:      Alex Thuering
 // Created:	04.11.2006
-// RCS-ID:      $Id: MenuPalettes.h,v 1.3 2010/06/30 20:18:59 ntalex Exp $
+// RCS-ID:      $Id: MenuPalettes.h,v 1.4 2011/07/15 13:43:33 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -18,43 +18,41 @@
 
 WX_DECLARE_HASH_SET(int, wxIntegerHash, wxIntegerEqual, IntHashSet);
 
-class Palette: public wxPalette
-{
-  private:
+class Palette: public wxPalette {
+private:
     int coloursCount;
-    wxColour m_transpColour;
+    bool m_hasTranspColour;
     
-  public:
+public:
     Palette() { coloursCount = 0; }
     virtual ~Palette() {}
-    bool Create(IntHashSet& colours, const wxColour& transpColour);    
-    bool Apply(const unsigned char* pixel, unsigned char *dest) const;
+    bool Create(IntHashSet& colours);    
+    bool Apply(const unsigned char* pixel, unsigned char *dest, unsigned char *destAlpha) const;
 };
 
 WX_DECLARE_HASH_MAP(int, Palette, wxIntegerHash, wxIntegerEqual, PaletteMap);
 WX_DECLARE_HASH_MAP(int, PaletteMap, wxIntegerHash, wxIntegerEqual, Palette2DMap);
 
 class MenuPalettes {
-  private:
+private:
     Palette m_palette1;
     PaletteMap m_palette2;
     Palette2DMap m_palette3;
-    wxColour m_transpColour;
     bool m_drawButtonsOnBackground;
-    int GetKey(const unsigned char* pixel);
+    int GetKey(const unsigned char* pixel, unsigned char alpha);
     
-  public:
+public:
     /** Constructor. Creates palettes */
-	MenuPalettes(MenuObject& obj, const wxColour& transpColour, bool drawButtonsOnBackground);
+	MenuPalettes(MenuObject& obj, bool drawButtonsOnBackground);
 	
 	/** Returns rgb value for first image (buttons normal) */
-	bool Apply(const unsigned char* pixel1, unsigned char *dest);
+	bool Apply(const unsigned char* pixel1, unsigned char *dest, unsigned char *destAlpha);
 	/** Returns rgb value for second image (buttons highlighted) */
-	bool Apply(const unsigned char* pixel1, const unsigned char* pixel2,
-	  unsigned char *dest);
+	bool Apply(const unsigned char* pixel1, unsigned char pixel1Alpha, const unsigned char* pixel2,
+			unsigned char *dest, unsigned char *destAlpha);
 	/** Returns rgb value for third image (buttons selected) */
-	bool Apply(const unsigned char* pixel1, const unsigned char*  pixel2,
-	  const unsigned char* pixel3, unsigned char *dest);
+	bool Apply(const unsigned char* pixel1, unsigned char pixel1Alpha, const unsigned char* pixel2,
+			unsigned char pixel2Alpha, const unsigned char* pixel3, unsigned char *dest, unsigned char *destAlpha);
 };
 
 #endif // MENU_PALETTES_H
