@@ -3,7 +3,7 @@
 // Purpose:     DVD menu properties dialog
 // Author:      Alex Thuering
 // Created:     25.04.2004
-// RCS-ID:      $Id: MenuPropDlg.cpp,v 1.41 2012/03/31 11:36:12 ntalex Exp $
+// RCS-ID:      $Id: MenuPropDlg.cpp,v 1.43 2013/03/04 04:55:20 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -34,7 +34,8 @@ BEGIN_EVENT_TABLE(MenuPropDlg, wxPropDlg)
 END_EVENT_TABLE()
 
 MenuPropDlg::MenuPropDlg(wxWindow *parent, DVD* dvd, int tsi, int pgci):
-		wxPropDlg(parent), m_dvd(dvd), m_tsi(tsi), m_pgci(pgci) {
+		wxPropDlg(parent), m_dvd(dvd), m_tsi(tsi), m_pgci(pgci),
+		m_aspect(NULL), m_wsFormat(NULL), m_audioFormat(NULL), m_pauseCtrl(NULL), m_postCommandsCtrl(NULL) {
 	PgcArray& pgcs = m_dvd->GetPgcArray(tsi, true);
 	m_video = &pgcs.GetVideo();
 	m_langCodes = &pgcs.GetAudioLangCodes();
@@ -185,7 +186,7 @@ void MenuPropDlg::CreateVobGroup(wxSizer* sizer, bool loop) {
 	m_pauseCtrl = (wxSpinCtrl*) GetLastControl();
 	m_pauseCtrl->Enable(!loop);
 	pSizer->AddSpacer(4);
-	AddCheckProp(pSizer, _T("Loop"), loop, false, LOOP_CB_ID);
+	AddCheckProp(pSizer, _("Loop"), loop, false, LOOP_CB_ID);
 	
 	grpSizer->Add(grid, 0, wxEXPAND|wxALL, 4);
 	sizer->AddSpacer(6);
