@@ -3,7 +3,7 @@
 // Purpose:     DVD menu properties dialog
 // Author:      Alex Thuering
 // Created:     25.04.2004
-// RCS-ID:      $Id: MenuPropDlg.h,v 1.10 2011/02/13 19:12:14 ntalex Exp $
+// RCS-ID:      $Id: MenuPropDlg.h,v 1.11 2012/01/13 18:26:08 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -21,7 +21,7 @@
 class MenuPropDlg: public wxPropDlg {
 public:
     MenuPropDlg(wxWindow *parent, DVD* dvd, int tsi, int pgci);
-	virtual ~MenuPropDlg() {}
+	virtual ~MenuPropDlg();
 	
 protected:
 	void CreatePropPanel(wxSizer* sizer);
@@ -36,6 +36,8 @@ private:
     Pgc* m_pgc;
 	Vob* m_vob;
 	Menu* m_menu;
+	vector<Cell*> m_cells;
+	vector<DVDAction*> m_actions;
 	wxChoice* m_aspect;
 	wxChoice* m_wsFormat;
 	wxChoice* m_audioFormat;
@@ -48,6 +50,8 @@ private:
 	void OnChangeAspect(wxCommandEvent& event);
 	void OnChangeAudio(wxCommandEvent& event);
 	void OnLoopCheck(wxCommandEvent& event);
+	void OnCellsBt(wxCommandEvent& event);
+	void OnActionsBt(wxCommandEvent& event);
 	wxArrayString GetCommands();
     DECLARE_EVENT_TABLE()
 };
