@@ -3,7 +3,7 @@
 // Purpose:     New project dialog
 // Author:      Alex Thuering
 // Created:     29.10.2006
-// RCS-ID:      $Id: NewProjectDlg.cpp,v 1.18 2012/06/19 21:52:45 ntalex Exp $
+// RCS-ID:      $Id: NewProjectDlg.cpp,v 1.19 2013/01/10 15:29:57 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -40,12 +40,16 @@ void NewProjectDlg::CreateDVDPropPanel(wxSizer* sizer, DVD* dvd) {
 	labels = DVD::GetVideoBitrateLabels();
 	int b = dvd ? dvd->GetVideoBitrate() : s_config.GetVideoBitrate();
 	int q = (dvd && dvd->IsVideoBitrateAuto()) || b == -1 ? 0 : (b%1000 == 0 && b>=2000 && b<=8000 ? 9-b/1000 : 8);
-	wxSizer* vbSizer = AddChoiceCustomProp(grid, _("Video quality:"), labels[q], labels, 8, 100, false);
+	wxSizer* vbSizer = AddChoiceCustomProp(grid, _("Video bitrate:"), labels[q], labels, 8, 100, false);
 	if (vbSizer)
 		vbSizer->AddSpacer(4);
 	AddSpinProp(vbSizer, wxT(""), b == -1 ? 4500 : b, 500, 9000, 80, _("KBit/s"), false);
 	if (vbSizer)
 		SetLastControlCustom(GetLastControlIndex()-1, q == 8);
+	
+	// Audio bitrate
+	b = dvd ? dvd->GetAudioBitrate() : s_config.GetAudioBitrate();
+	AddSpinProp(grid, _("Audio bitrate:"), b, 1, 9999, 80, _("KBit/s"));
 
 	// Video and audio format
 	wxFlexGridSizer* fSizer = sizer ? new wxFlexGridSizer(3, 1, 16) : NULL;
@@ -120,18 +124,22 @@ int NewProjectDlg::GetVideoBitrate() {
 	return q < 8 ? (9-q)*1000 : b;
 }
 
+int NewProjectDlg::GetAudioBitrate() {
+	return GetInt(propIndex+4);
+}
+
 VideoFormat NewProjectDlg::GetVideoFormat() {
-	return (VideoFormat) (GetInt(propIndex+4) + 2);
+	return (VideoFormat) (GetInt(propIndex+5) + 2);
 }
 
 AspectRatio NewProjectDlg::GetAspectRatio() {
-	return (AspectRatio) (GetInt(propIndex+5) + 1);
+	return (AspectRatio) (GetInt(propIndex+6) + 1);
 }
 
 AudioFormat NewProjectDlg::GetAudioFormat() {
-	return (AudioFormat) (GetInt(propIndex+6) + 2);
+	return (AudioFormat) (GetInt(propIndex+7) + 2);
 }
 
 DefaultPostCommand NewProjectDlg::GetDefPostCommand() {
-	return (DefaultPostCommand) (GetInt(propIndex+7));
+	return (DefaultPostCommand) (GetInt(propIndex+8));
 }
