@@ -3,7 +3,7 @@
 // Purpose:     The class to store a PGC
 // Author:      Alex Thuering
 // Created:     29.01.2003
-// RCS-ID:      $Id: Pgc.cpp,v 1.30 2012/10/30 19:23:11 ntalex Exp $
+// RCS-ID:      $Id: Pgc.cpp,v 1.40 2013/04/28 08:03:11 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -62,11 +62,11 @@ void Cell::SetEnd(const wxString& endStr) {
 	m_end = endStr.length() ? String2Time(endStr) : -1;
 }
 
-wxSvgXmlNode* Cell::GetXML(DVDFileType type) {
+wxSvgXmlNode* Cell::GetXML(DVDFileType type, long endTime) {
 	wxSvgXmlNode* node = new wxSvgXmlNode(wxSVGXML_ELEMENT_NODE, wxT("cell"));
 	if (m_start >= 0)
 		node->AddProperty(wxT("start"), GetStartStr());
-	if (m_end >= 0)
+	if (endTime >= 0)
 		node->AddProperty(wxT("end"), GetEndStr());
 	if (m_chapter)
 		node->AddProperty(wxT("chapter"), wxT("1"));
@@ -76,8 +76,15 @@ wxSvgXmlNode* Cell::GetXML(DVDFileType type) {
 		wxString pauseStr = m_pause == -1 ? wxT("inf") : wxString::Format(wxT("%d"), m_pause);
 		node->AddProperty(wxT("pause"), pauseStr);
 	}
-	if (m_commands.length())
-		node->AddChild(new wxSvgXmlNode(wxSVGXML_TEXT_NODE, wxEmptyString, m_commands));
+	if (m_commands.length()) {
+		// replace call last menu
+		wxString commands = m_commands;
+		wxString cmd = wxT("call last menu");
+		int stPos = commands.Find(cmd);
+		if (stPos >= 0)
+			commands.replace(stPos, cmd.length(), wxT("call menu entry root"));
+		node->AddChild(new wxSvgXmlNode(wxSVGXML_TEXT_NODE, wxEmptyString, commands));
+	}
 	return node;
 }
 
@@ -262,7 +269,7 @@ bool Vob::SetFilename(const wxString& filename) {
 	if (filename.length() == 0 || !ffmpeg.Load(filename))
 		return false;
 	m_filename = filename;
-	m_duration = ffmpeg.GetDuration() > 0 ? ffmpeg.GetDuration() : 0;
+	// read streams information
 	if (m_streams.GetCount() - m_audioFilenames.GetCount() > 0)
 		m_streams.RemoveAt(0, m_streams.GetCount() - m_audioFilenames.GetCount());
 	for (unsigned int stIdx = 0; stIdx < ffmpeg.GetStreamCount(); stIdx++) {
@@ -279,6 +286,12 @@ bool Vob::SetFilename(const wxString& filename) {
 		}
 		m_streams.Insert(stream, stIdx);
 	}
+	// get video duration
+	m_duration = ffmpeg.GetDuration();
+	if (m_duration < 0) {
+		if (ffmpeg.SetPosition(360000, false))
+			m_duration = ffmpeg.GetPosition();
+	}
 	return true;
 }
 
@@ -354,13 +367,20 @@ void Vob::RemoveAudioFile(int index) {
 }
 
 /** Sets chapter list */
-void Vob::SetChapters(const wxString& value) {
+void Vob::SetChapters(const wxString& value, bool firstVob) {
+	Stream* stream = GetVideoStream();
+	float fps = stream != NULL ? stream->GetSourceFps() : 25;
 	VECTOR_CLEAR(m_cells, Cell);
 	wxStringTokenizer tkz(value, _T(","));
 	while (tkz.HasMoreTokens()) {
 		wxString token = tkz.GetNextToken().Strip(wxString::both);
-		m_cells.push_back(new Cell(String2Time(token)));
+		long startTime = String2Time(token, fps);
+		if (m_cells.size() == 0 && startTime > 0)
+			m_cells.push_back(new Cell(0, firstVob));
+		m_cells.push_back(new Cell(startTime));
 	}
+	if (firstVob && m_cells.size() == 0)
+		m_cells.push_back(new Cell(0));
 }
 
 /** Returns chapter list */
@@ -375,6 +395,15 @@ wxString Vob::GetChapters() {
 	return result;
 }
 
+/** Returns count of chapters */
+int Vob::GetChapterCount() {
+	int result = 0;
+	for (vector<Cell*>::iterator it = m_cells.begin(); it != m_cells.end(); it++)
+		if ((*it)->IsChapter())
+			result++;
+	return result;
+}
+
 /** Updates pad values to keep aspect ratio*/
 void Vob::UpdatePad(AspectRatio aspectRatio) {
 	int padx = 0;
@@ -471,6 +500,11 @@ wxString Vob::GetAllVideoFilters() {
 	return result;
 }
 
+/** Returns duration of result video (sec) */
+double Vob::GetResultDuration() {
+	return GetRecordingTime() >= 0 ? GetRecordingTime() : GetDuration() - GetStartTime();
+}	
+
 /** Returns video stream parameters */
 Stream* Vob::GetVideoStream() {
 	for (int i = 0; i < (int)GetStreams().GetCount(); i++)
@@ -492,8 +526,28 @@ void ReplaceCallLastMenu(wxString& commands, DVD* dvd) {
 		return;
 	wxString cmd = wxT("call menu;");
 	int stPos = commands.Find(cmd);
-	if (stPos >= 0)
-		commands.replace(stPos, cmd.length(), wxString::Format(wxT("g%d = 0;"), dvd->GetLastMenuRegister()));
+	if (stPos >= 0) {
+		wxChar ch = wxT(' ');
+		int pos2 = stPos;
+		while (--pos2 >= 0 && ch == wxT(' '))
+			ch = commands[pos2];
+		if (ch == wxT(')'))
+			commands.replace(stPos, cmd.length(), wxString::Format(wxT("{ g%d = 0;call menu; }"), dvd->GetLastMenuRegister()));
+		else
+			commands.replace(stPos, cmd.length(), wxString::Format(wxT("g%d = 0;call menu;"), dvd->GetLastMenuRegister()));
+	}
+	cmd = wxT("call menu entry root;");
+	stPos = commands.Find(cmd);
+	if (stPos >= 0) {
+		wxChar ch = wxT(' ');
+		int pos2 = stPos;
+		while (--pos2 >= 0 && ch == wxT(' '))
+			ch = commands[pos2];
+		if (ch == wxT(')'))
+			commands.replace(stPos, cmd.length(), wxString::Format(wxT("{ g%d = 0;call menu entry root; }"), dvd->GetLastMenuRegister()));
+		else
+			commands.replace(stPos, cmd.length(), wxString::Format(wxT("g%d = 0;call menu entry root;"), dvd->GetLastMenuRegister()));
+	}
 	cmd = wxT("call last menu");
 	stPos = commands.Find(cmd);
 	if (stPos >= 0)
@@ -627,9 +681,15 @@ wxSvgXmlNode* Vob::GetXML(DVDFileType type, DVD* dvd) {
 	
 	// chapters/cells
 	bool cells = false;
+	if (m_cells.size()) {
+		if ((*m_cells.begin())->GetStart() > 0)
+			cells = true;
+		else if ((*(m_cells.end()-1))->GetEnd() != -1)
+			cells = true;
+	}
 	for (vector<Cell*>::iterator it = m_cells.begin(); it != m_cells.end(); it++) {
-		if (!(*it)->IsChapter() || (*it)->GetEnd() >= 0 || (*it)->GetPause() != 0
-				|| (*it)->GetCommands().length() > 0) {
+		if ((!(*it)->IsChapter() && m_cells.size() > 0)
+				|| (*it)->GetPause() != 0 || (*it)->GetCommands().length() > 0) {
 			cells = true;
 			break;
 		}
@@ -637,28 +697,14 @@ wxSvgXmlNode* Vob::GetXML(DVDFileType type, DVD* dvd) {
 	if (cells) {
 		for (vector<Cell*>::iterator it = m_cells.begin(); it != m_cells.end(); it++) {
 			Cell* cell = *it;
-			if (type == DVDAUTHOR_XML && cell->GetCommands().length() > 0) {
-				wxString cmd = cell->GetCommands();
-				ReplaceCallLastMenu(cmd, dvd);
-				wxStringTokenizer tkz(cmd, wxT(";"));
-				while (tkz.HasMoreTokens()) {
-					wxString token = tkz.GetNextToken().Strip(wxString::both) + wxT(";");
-					if (tkz.HasMoreTokens()) {
-						Cell tmpCell(cell->GetStart(), false);
-						tmpCell.SetCommands(token);
-						node->AddChild(tmpCell.GetXML(type));
-					} else {
-						Cell tmpCell(*cell);
-						tmpCell.SetCommands(token);
-						node->AddChild(tmpCell.GetXML(type));
-					}
-				}
-			} else
-				node->AddChild(cell->GetXML(type));
+			long nextTime = it + 1 != m_cells.end() ? (*(it + 1))->GetStart() : -1;
+			long endTime = type == DVDAUTHOR_XML && cell->GetEnd() == -1 ? nextTime : cell->GetEnd();
+			node->AddChild(cell->GetXML(type, endTime));
 		}
 	} else {
-		if (m_cells.size() > 0)
-			node->AddProperty(wxT("chapters"), GetChapters());
+		wxString chapters = GetChapters();
+		if (chapters.length())
+			node->AddProperty(wxT("chapters"), chapters);
 		
 		if (GetPause() != 0) {
 			wxString pauseStr = GetPause() > 0 ? wxString::Format(wxT("%d"), GetPause()) : wxT("inf");
@@ -691,7 +737,7 @@ wxSvgXmlNode* Vob::GetXML(DVDFileType type, DVD* dvd) {
 	return node;
 }
 
-bool Vob::PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, int pgci, bool menu) {
+bool Vob::PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, int pgci, bool menu, bool firstVob) {
 	wxString val;
 	long lval;
 	double dval;
@@ -829,7 +875,7 @@ bool Vob::PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, int pgci, bool menu) {
 	if (node->GetPropVal(wxT("doNotTranscode"), &val) && val == wxT("1"))
 		SetDoNotTranscode(true);
 	if (node->GetPropVal(wxT("chapters"), &val))
-		SetChapters(val);
+		SetChapters(val, firstVob);
 	
 	return true;
 }
@@ -877,15 +923,15 @@ int Vob::GetSize(DVD* dvd) {
 						if (stream->GetVideoFormat() == vfCOPY)
 							copyVideo = true;
 						else
-							size += (long) (GetDuration()*dvd->GetVideoBitrate()/8);
+							size += (long) (GetResultDuration()*dvd->GetVideoBitrate()/8);
 						break;
 					case stAUDIO: {
 						int srcBitrate = stream->GetSourceBitrate() > 0 ? stream->GetSourceBitrate() : 64000;
-						audioSize += (long) (GetDuration()*srcBitrate/8/1024);
+						audioSize += (long) (GetResultDuration()*srcBitrate/8/1024);
 						if (stream->GetAudioFormat() == afCOPY)
-							size += (long) (GetDuration()*srcBitrate/8/1024);
+							size += (long) (GetResultDuration()*srcBitrate/8/1024);
 						else if (stream->GetAudioFormat() != afNONE)
-							size += (long) (GetDuration()*s_config.GetAudioBitrate()/8);
+							size += (long) (GetResultDuration()*dvd->GetAudioBitrate()/8);
 						break;
 					}
 					case stSUBTITLE:
@@ -904,7 +950,7 @@ int Vob::GetSize(DVD* dvd) {
 		if (stream->GetAudioFormat() == afCOPY)
 			size += GetFileSize(GetAudioFilenames()[i]);
 		else
-			size += (long) (GetDuration()*s_config.GetAudioBitrate()/8);
+			size += (long) (GetResultDuration()*dvd->GetAudioBitrate()/8);
 	}
 	for (unsigned int i=0; i<GetSubtitles().Count(); i++)
 		size += GetFileSize(GetSubtitles()[i]->GetFilename());
@@ -977,18 +1023,13 @@ Slideshow* Pgc::GetSlideshow() {
 unsigned int Pgc::GetChapterCount(int lastVobi) {
 	if (lastVobi == -1)
 		lastVobi = (int) GetVobs().Count();
-	int result = 1;
+	int result = 0;
 	for (int vi = 0; vi < lastVobi; vi++) {
 		Vob& vob = *GetVobs()[vi];
 		if (vob.GetSlideshow()) {
-			result += vob.GetSlideshow()->GetCount() / 5;
+			result += 1 + vob.GetSlideshow()->GetCount() / 5;
 		} else {
-			wxStringTokenizer tkz(vob.GetChapters(), _T(","));
-			while (tkz.HasMoreTokens()) {
-				wxString token = tkz.GetNextToken();
-				if (token != _T("0") || vi > 0)
-					result++;
-			}
+			result += vob.GetChapterCount();
 		}
 	}
 	return result;
@@ -1000,11 +1041,11 @@ wxString Pgc::GetVideoFrameUri(int chapter, long position, bool fileNameOnly) {
 		return wxT("");
 	wxString uri;
 	if (position == -1 && chapter > 0) {
-		for (unsigned int vobi = 0; vobi < m_vobs.size() && chapter > 0; vobi++) {
+		for (unsigned int vobi = 0; vobi < m_vobs.size() && chapter >= 0; vobi++) {
 			Vob* vob = GetVobs()[vobi];
 			uri = vob->GetFilename();
 			for (vector<Cell*>::iterator it = vob->GetCells().begin();
-					it != vob->GetCells().end() && chapter > 0; it++) {
+					it != vob->GetCells().end() && chapter >= 0; it++) {
 				if ((*it)->IsChapter()) {
 					position = lround(vob->GetStartTime() * 1000) + (*it)->GetStart();
 					chapter--;
@@ -1141,7 +1182,7 @@ bool Pgc::PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, int pgci, bool menu) {
 				vob = new Vob(menuObj);
 			else
 				vob = new Vob(wxT(""));
-			if (vob->PutXML(child, dvd, tsi, pgci, menu))
+			if (vob->PutXML(child, dvd, tsi, pgci, menu, GetVobs().size() == 0))
 				GetVobs().Add(vob);
 			else {
 				delete vob;
