@@ -3,7 +3,7 @@
 // Purpose:     The class to store a PGC
 // Author:      Alex Thuering
 // Created:	    29.01.2003
-// RCS-ID:      $Id: Pgc.h,v 1.12 2012/10/30 19:23:11 ntalex Exp $
+// RCS-ID:      $Id: Pgc.h,v 1.17 2013/04/28 08:03:11 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -72,7 +72,7 @@ public:
 	/** Sets the VM commands that will be executed when the cell plays. */
 	void SetCommands(const wxString& commands) { m_commands = commands; }
 		
-	wxSvgXmlNode* GetXML(DVDFileType type);
+	wxSvgXmlNode* GetXML(DVDFileType type, long endTime = -1);
 	bool PutXML(wxSvgXmlNode* node);
 	
 private:
@@ -214,9 +214,11 @@ public:
 	const wxString& GetTmpFilename() { return m_tmpFilename; }
 	
     /** Sets chapter list */
-	void SetChapters(const wxString& value);
+	void SetChapters(const wxString& value, bool firstVob);
     /** Returns chapter list */
 	wxString GetChapters();
+    /** Returns count of chapters */
+	int GetChapterCount();
 	
     /** Sets pause */
 	void SetPause(int value) { m_pause = value; }
@@ -283,9 +285,11 @@ public:
     void SetSlideshow(Slideshow* slideshow) { m_slideshow = slideshow; }
 	Slideshow* GetSlideshow() { return m_slideshow; }
 	
-	/** Returns duration of video (sec) */
+	/** Returns duration of original video (sec) */
 	inline double GetDuration() { return m_duration; }
-    /** Returns array with stream parameters */
+	/** Returns duration of result video (sec) */
+	double GetResultDuration();
+	/** Returns array with stream parameters */
     StreamArray& GetStreams() { return m_streams; }
     /** Returns video stream parameters */
     Stream* GetVideoStream();
@@ -298,7 +302,7 @@ public:
    	inline void SetDoNotTranscode(bool doNotTranscode) { m_doNotTranscode = doNotTranscode; }
 	
 	wxSvgXmlNode* GetXML(DVDFileType type, DVD* dvd);
-	bool PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, int pgci, bool menu);
+	bool PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, int pgci, bool menu, bool firstVob);
 	
 	/**
 	 * Returns size in KB
