@@ -3,12 +3,13 @@
 // Purpose:     Progress of generation/burning dialog
 // Author:      Alex Thuering
 // Created:     14.08.2004
-// RCS-ID:      $Id: ProgressDlg.cpp,v 1.140 2012/11/05 21:10:58 ntalex Exp $
+// RCS-ID:      $Id: ProgressDlg.cpp,v 1.152 2013/08/18 10:22:24 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
 
 #include "ProgressDlg.h"
+#include "MainWin.h"
 #include "Config.h"
 #include "MPEG.h"
 #include "mediaenc_ffmpeg.h"
@@ -261,8 +262,10 @@ public:
 	virtual ~DVDAuthorExecute() {};
 
 	virtual void ProcessOutput(wxString line) {
-		if (m_dvdauthorStep)
-			return ProgressExecute::ProcessOutput(line);
+		if (m_dvdauthorStep) {
+			ProgressExecute::ProcessOutput(line);
+			return;
+		}
 		if (line.Mid(0, 11) == _T("STAT: fixed")) {
 			m_dvdauthorStep++;
 			m_initSubStep += 200;
@@ -321,7 +324,7 @@ BEGIN_EVENT_TABLE(ProgressDlg, wxDialog)
 END_EVENT_TABLE()
 
 /** Constructor */
-ProgressDlg::ProgressDlg(wxWindow* parent, Cache* cache, bool autoStart): wxDialog(parent, -1, wxEmptyString,
+ProgressDlg::ProgressDlg(MainWin* parent, Cache* cache, bool autoStart): wxDialog(parent, -1, wxEmptyString,
 		wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER) {
     // begin wxGlade: ProgressDlg::ProgressDlg
     m_summaryLabel = new wxStaticText(this, wxID_ANY, _("Summary:"));
@@ -401,7 +404,7 @@ void ProgressDlg::OnHideDetails(wxCommandEvent& WXUNUSED(event)) {
 void ProgressDlg::OnMinimize(wxCommandEvent& event) {
 	wxPlatformInfo info;
 	if ((info.GetOperatingSystemId() & wxOS_WINDOWS) && !info.CheckOSVersion(6,0))
-		MakeModal(false);
+		wxDELETE(m_winDisabler);
 	((wxFrame*) GetParent())->Iconize();
 }
 
@@ -427,26 +430,41 @@ void ProgressDlg::AddDetailText(const wxString& text) {
 	m_detailsText->ShowPosition(m_detailsText->GetLastPosition());
 	if (wxLog::GetActiveTarget()->GetVerbose())
 		fprintf(stderr, "%s", (const char*) text.mb_str());
+	m_logFile.Write(text);
+	m_logFile.Flush();
 	wxYieldIfNeeded();
 }
 
+/** Sets the step count of generating process */
+void ProgressDlg::SetSteps(int stepCount) {
+	m_stepCount = stepCount;
+	m_step = 0;
+	m_gauge->SetRange(stepCount*100);
+	((MainWin*) this->GetParent())->SetProgressBarState();
+}
+
 void ProgressDlg::UpdateGauge() {
 	int subStep = 0;
 	if (m_subStepCount > 0)
 		subStep = m_subStep * 100 / m_subStepCount;
 	m_gauge->SetValue(m_step * 100 + subStep);
+	((MainWin*) this->GetParent())->SetProgressBarValue(m_step * 100 + subStep, m_stepCount * 100);
 }
 
 void ProgressDlg::Failed(const wxString& message) {
 	AddSummaryMsg(_("Failed"), message, *wxRED);
+	((MainWin*) this->GetParent())->SetProgressBarState(true);
 }
 
 void ProgressDlg::OnCancel(wxCommandEvent& WXUNUSED(event)) {
 	if (!m_cancel) {
 		AddSummaryMsg(_("Aborted"), wxEmptyString, *wxRED);
 		End();
-	} else
+	} else {
 		m_end = true;
+		((MainWin*) this->GetParent())->SetProgressBarValue(0, 100);
+		((MainWin*) this->GetParent())->SetProgressBarState();
+	}
 }
 
 void ProgressDlg::End() {
@@ -454,6 +472,7 @@ void ProgressDlg::End() {
 		wxBell();
 	m_cancelBt->SetLabel(_("Close"));
 	m_cancel = true;
+	m_logFile.Close();
 }
 
 bool ProgressDlg::IsCanceled() {
@@ -463,7 +482,7 @@ bool ProgressDlg::IsCanceled() {
 
 bool ProgressDlg::Start(BurnDlg* burnDlg, DVD* dvd) {
 	// disable parent window
-	MakeModal();
+	m_winDisabler = new wxWindowDisabler(this);
 	wxLog* previousLog = wxLog::SetActiveTarget(new ProgressDlgLog(this));
 	// show dialog
 	Show();
@@ -483,7 +502,7 @@ bool ProgressDlg::Start(BurnDlg* burnDlg, DVD* dvd) {
     		wxYield();
     	}
     }
-	MakeModal(false);
+	wxDELETE(m_winDisabler);
 	return isOk;
 }
 
@@ -591,24 +610,41 @@ int ProgressDlg::GetSubtitleSubSteps(wxArrayPtrVoid& subtitleVobs, wxArrayInt& s
 void ProgressDlg::Run(BurnDlg* burnDlg, DVD* dvd) {
 	if (IsCanceled())
 		return;
-
-	// print version
-	AddDetailMsg(wxT("DVDStyler v") + APP_VERSION);
-	AddDetailMsg(wxGetOsDescription());
-	AddDetailMsg(wxFfmpegMediaEncoder::GetBackendVersion());
 	
-	// prepare
-	AddSummaryMsg(_("Prepare"));
-
+	// check if libav or ffmpeg is present
+#ifdef __WXMSW__
+	if (!wxFileExists(wxGetAppPath() + s_config.GetAVConvCmd() + wxT(".exe"))
+			&& !wxFileExists(wxGetAppPath() + s_config.GetAVConvCmd())) {
+		if (wxFileExists(wxGetAppPath() + wxT("avconv.exe")))
+			s_config.SetAVConvCmd(wxT("avconv"));
+		else if (wxFileExists(wxGetAppPath() + wxT("ffmpeg.exe")))
+			s_config.SetAVConvCmd(wxT("ffmpeg"));
+	}
+#endif
+	
+	// clean temp dir
 	wxString tmpDir = burnDlg->GetTempDir();
 	if (tmpDir.Last() != wxFILE_SEP_PATH)
 		tmpDir += wxFILE_SEP_PATH;
 	wxString dvdOutDir = tmpDir + wxString(wxT("dvd-out")) + wxFILE_SEP_PATH;
 	wxString dvdTmpDir = tmpDir + wxString(wxT("dvd-tmp")) + wxFILE_SEP_PATH;
 	
+	// create log file
+	m_logFile.Open(tmpDir + wxT("dvdstyler.log"), wxT("w"));
+
+	// print version
+	AddDetailMsg(wxT("DVDStyler v") + APP_VERSION);
+	AddDetailMsg(wxGetOsDescription());
+	AddDetailMsg((s_config.GetAVConvCmd() == wxT("ffmpeg") ? wxT("FFmpeg: ") : wxT("Libav: "))
+			+ wxFfmpegMediaEncoder::GetBackendVersion());
+
+	// prepare
+	AddSummaryMsg(_("Prepare"));
+
+	// clean temp dir
 	if (!CleanTemp(tmpDir, dvdTmpDir, dvdOutDir))
 		return;
-	
+
 	// check cache and calculate steps
 	AddDetailMsg(_("Search for transcoded files in cache"));
 	m_cache->BeginClean();
@@ -712,9 +748,27 @@ bool ProgressDlg::GenerateMenus(wxArrayPtrVoid& menuVobs, wxArrayInt& menuWSType
 		AddDetailMsg(wxString::Format(_("Generating menu %u of %lu"), i + 1, menuVobs.Count()));
 		Vob* vob = (Vob*) menuVobs[i];
 		WidescreenType wsType = (WidescreenType) menuWSTypes[i];
-		if (!GenerateMenu(vob->GetMenu(), wsType, vob->GetTmpFilename(), (AudioFormat) dvd->GetAudioFormat(),
-				vob->GetAudioFilenames().size() > 0 ? vob->GetAudioFilenames()[0] : wxString(),
-				dvd->GetVideoBitrate()))
+		
+		wxString audioFile;
+		AudioFormat audioFormat = dvd->GetAudioFormat();
+		if (vob->GetAudioFilenames().size() > 0 && vob->GetStreams().GetCount() > 0
+				&& vob->GetStreams()[0]->GetType() == stAUDIO) {
+			audioFile = vob->GetAudioFilenames()[0];
+			Stream* stream = vob->GetStreams()[0];
+			audioFormat = stream->GetAudioFormat();
+			if (audioFormat == afCOPY) {
+				// set destination format if it set to COPY and codec is not mp2/ac3 or sample rate != 48 kHz
+				if (stream->GetSourceCodecName() != wxT("mp2")
+						&& stream->GetSourceCodecName() != wxT("ac3")
+						&& stream->GetSourceCodecName() != wxT("liba52")) {
+					audioFormat = dvd->GetAudioFormat();
+				} else if (stream->GetSourceSampleRate() != 48000) {
+					audioFormat = stream->GetSourceCodecName() == wxT("mp2") ? afMP2 : afAC3;
+				}
+			}
+		}
+		
+		if (!GenerateMenu(vob->GetMenu(), wsType, vob->GetTmpFilename(), audioFormat, audioFile, dvd->GetAudioBitrate()))
 			return false;
 	}
 	IncStep();
@@ -737,7 +791,7 @@ bool ProgressDlg::Transcode(wxArrayPtrVoid& titleVobs, wxArrayInt& titleAspects,
 		wxString cacheFile = m_cache->Add(vob, dvd);
 		AddDetailMsg(wxT("Add file to cache:") + cacheFile);
 		vob->SetTmpFilename(cacheFile);
-		if (!Transcode(vob, aspect, videoBitrate, s_config.GetUseMplex(), dvd->GetAudioFormat())) {
+		if (!Transcode(vob, aspect, videoBitrate, dvd->GetAudioBitrate(), s_config.GetUseMplex(), dvd->GetAudioFormat())) {
 			if (wxFileExists(vob->GetTmpFilename()))
 				wxRemoveFile(vob->GetTmpFilename());
 			return false;
@@ -757,8 +811,23 @@ bool ProgressDlg::GenerateSlideshow(wxArrayPtrVoid& slideshowVobs, int slideshow
 	for (unsigned int i = 0; i < slideshowVobs.Count(); i++) {
 		AddDetailMsg(wxString::Format(_("Generating slideshow %u of %lu"), i + 1, slideshowVobs.Count()));
 		Vob* vob = (Vob*) slideshowVobs[i];
-		if (!GenerateSlideshow(vob->GetSlideshow(), vob->GetTmpFilename(), dvd->GetAudioFormat(),
-				vob->GetAudioFilenames().size() > 0 ? vob->GetAudioFilenames()[0] : wxString()))
+		AudioFormat audioFormat = dvd->GetAudioFormat();
+		if (vob->GetStreams().GetCount() > 0 && vob->GetStreams()[0]->GetType() == stAUDIO) {
+			Stream* stream = vob->GetStreams()[0];
+			audioFormat = stream->GetAudioFormat();
+			if (audioFormat == afCOPY) {
+				// set destination format if it set to COPY and codec is not mp2/ac3 or sample rate != 48 kHz
+				if (stream->GetSourceCodecName() != wxT("mp2")
+						&& stream->GetSourceCodecName() != wxT("ac3")
+						&& stream->GetSourceCodecName() != wxT("liba52")) {
+					audioFormat = dvd->GetAudioFormat();
+				} else if (stream->GetSourceSampleRate() != 48000) {
+					audioFormat = stream->GetSourceCodecName() == wxT("mp2") ? afMP2 : afAC3;
+				}
+			}
+		}
+		if (!GenerateSlideshow(vob->GetSlideshow(), vob->GetTmpFilename(), audioFormat,
+				vob->GetAudioFilenames().size() > 0 ? vob->GetAudioFilenames()[0] : wxString(), dvd->GetAudioBitrate()))
 			return false;
 	}
 	IncStep();
@@ -1136,7 +1205,8 @@ bool ProgressDlg::BurnDvd(BurnDlg* burnDlg, DVD* dvd, const wxString& dvdOutDir,
 	return true;
 }
 
-bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, bool useMplex, AudioFormat defAudioFormat) {
+bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, int audioBitrate, bool useMplex,
+		AudioFormat defAudioFormat) {
 	if (IsCanceled())
 		return false;
 	int subStep = GetSubStep();
@@ -1144,8 +1214,6 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, bool
 	// set output formats
 	double startTime = vob->GetStartTime();
 	double recordingTime = vob->GetRecordingTime();
-	if (vob->GetSlideshow())
-		recordingTime = vob->GetSlideshow()->GetDuration() * vob->GetSlideshow()->GetCount();
 	bool needEncode = vob->GetAudioFilenames().GetCount() != vob->GetAudioStreamCount()
 			|| startTime != 0 || recordingTime != -1; // some files are not elementary streams
 	VideoFormat videoFormat = vfCOPY;
@@ -1181,28 +1249,34 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, bool
 			return false;
 	} else {
 		// add input files
-		bool disableAudio = vob->GetStreams().GetCount() > 1 + vob->GetAudioFilenames().GetCount()
-			&& vob->GetStreams()[1]->GetType() == stAUDIO && vob->GetStreams()[1]->GetDestinationFormat() == afNONE;
 		wxFfmpegMediaTranscoder transcoder(s_config.GetThreadCount());
-		if (!transcoder.AddInputFile(vob->GetFilename(), false, disableAudio)) {
+		if (!transcoder.AddInputFile(vob->GetFilename())) {
 			Failed(wxT("Error by transcoding of ") + vob->GetFilename());
 			return false;
 		}
 		for (int i = 0; i < (int)vob->GetAudioFilenames().size(); i++) {
 			int stIdx = vob->GetStreams().size() - vob->GetAudioFilenames().size() + i;
-			if (!transcoder.AddInputFile(vob->GetAudioFilenames()[i], false, false, false,
-					vob->GetStreams()[stIdx]->GetTsOffset())) {
+			long tsOffset = vob->GetStreams()[stIdx]->GetTsOffset();
+			if (!transcoder.AddInputFile(vob->GetAudioFilenames()[i], wxT(""), tsOffset)) {
 				Failed(wxT("Error by transcoding of ") + vob->GetAudioFilenames()[i]);
 				return false;
 			}
 		}
 		if (vob && vob->GetFilename().length() && !vob->HasAudio()) {
-			wxString zero = wxT("pipe:-1");
-			if (!transcoder.AddInputFile(zero, false, false, false, 0)) {
+#ifdef __WXMSW__
+			wxString zero = wxT("aevalsrc=0");
+			wxString format = wxT("lavfi");
+#else
+			wxString zero = wxT("/dev/zero");
+			wxString format = wxT("");
+#endif
+			if (!transcoder.AddInputFile(zero, format)) {
 				Failed(wxT("Error by transcoding of ") + zero);
 				return false;
 			}
 			audioFormats.Add(defAudioFormat);
+			if (recordingTime <= 0)
+				recordingTime = vob->GetDuration() > 0 ? vob->GetDuration() : 1.0;
 		}
 		
 		// set output options
@@ -1245,7 +1319,7 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, bool
 			double fps = GetFps(videoFormat, ntscFilm);
 			AVConvExecute exec(this, lround(vob->GetDuration() * fps));
 			if (!transcoder.SetOutputFile(vob->GetTmpFilename(), videoFormat, ntscFilm, audioFormats, subtitleFormats,
-					videoBitrate, s_config.GetVbr(), s_config.GetAudioBitrate())
+					videoBitrate, s_config.GetVbr(), audioBitrate)
 					|| !exec.Execute(transcoder.GetCmd())) {
 				if (wxFileExists(vob->GetTmpFilename()))
 					wxRemoveFile(vob->GetTmpFilename());
@@ -1258,7 +1332,7 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, bool
 				wxLogError(wxString::Format(_("Can't remove file '%s'"), videoFile.c_str()));
 			}
 			if (!transcoder.SetOutputFile(videoFile, videoFormat, ntscFilm, afNONE, sfNONE,
-					videoBitrate, s_config.GetVbr(), s_config.GetAudioBitrate(), vob->GetVideoStreamIndex())) {
+					videoBitrate, s_config.GetVbr(), audioBitrate, 0, vob->GetVideoStreamIndex())) {
 				Failed(_("Error transcoding of ") + vob->GetFilename());
 				return false;
 			}
@@ -1271,8 +1345,20 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, bool
 				if (wxFileExists(audioFile) && !wxRemoveFile(audioFile)) {
 					wxLogError(wxString::Format(_("Can't remove file '%s'"), audioFile.c_str()));
 				}
+				if (startTime != 0)
+					transcoder.SetStartTime(startTime);
+				if (recordingTime > 0)
+					transcoder.SetRecordingTime(recordingTime);
+				int audioFileIdx = audioIdx + 1 - audioFormats.GetCount() + vob->GetAudioFilenames().size();
+				int audioStreamIdx = audioIdx;
+				if (audioFileIdx <= 0) {
+					audioFileIdx = 0;
+					if (audioStreamIdx >= vob->GetVideoStreamIndex())
+						audioStreamIdx++;
+				} else
+					audioStreamIdx = 0;
 				if (!transcoder.SetOutputFile(audioFile, vfNONE, false, (AudioFormat) audioFormats[audioIdx], sfNONE,
-						videoBitrate, s_config.GetVbr(), s_config.GetAudioBitrate(), audioIdx + 1)) {
+						videoBitrate, s_config.GetVbr(), audioBitrate, audioFileIdx, audioStreamIdx)) {
 					Failed(_("Error transcoding of ") + vob->GetFilename());
 					return false;
 				}
@@ -1329,7 +1415,7 @@ bool ProgressDlg::Multiplex(const wxString& videoFile, const wxArrayString& audi
 }
 
 bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const wxString& menuFile,
-		AudioFormat audioFormat, wxString audioFile, int videoBitrate) {
+		AudioFormat audioFormat, wxString audioFile, int audioBitrate) {
 	if (IsCanceled())
 		return false;
 	wxString mpegFile = menuFile + _T("_bg.mpg");
@@ -1351,7 +1437,7 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 		// get background audio format
 		AudioFormat bgAudioFormat = afNONE;
 		wxString bgAudioOutputFormat;
-		if (menu->HasVideoBackground()) {
+		if (menu->HasVideoBackground() && audioFile.length() == 0) {
 			wxFfmpegMediaDecoder ffmpeg;
 			if (!ffmpeg.Load(menu->GetBackground()))
 				return false;
@@ -1408,13 +1494,13 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 				AddDetailMsg(_("Transcode audio from") + wxString(wxT(" ")) + menu->GetBackground());
 				// transcode audio
 				wxFfmpegMediaTranscoder transcoder(s_config.GetThreadCount());
-				if (!transcoder.AddInputFile(menu->GetBackground(), true)) {
+				if (!transcoder.AddInputFile(menu->GetBackground())) {
 					Failed(wxT("Error by transcoding of ") + menu->GetBackground());
 					return false;
 				}
 				transcoder.SetOutputFormat(bgAudioOutputFormat);
 				if (!transcoder.SetOutputFile(audioFileTmp, vfNONE, false, bgAudioFormat, sfNONE, 0, false,
-						s_config.GetAudioBitrate())) {
+						audioBitrate)) {
 					Failed(_("Error transcoding of ") + menu->GetBackground());
 					return false;
 				}
@@ -1443,7 +1529,7 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 			menuVob.SetTmpFilename(mpegFile);
 			if (!s_config.GetUseMplexForMenus())
 				AddDetailMsg(WARNING_MPLEX_MSG, *wxRED);
-			if (!Transcode(&menuVob, menu->GetAspectRatio(), s_config.GetMenuVideoBitrate(),
+			if (!Transcode(&menuVob, menu->GetAspectRatio(), s_config.GetMenuVideoBitrate(), audioBitrate,
 					s_config.GetUseMplexForMenus()))
 				return false;
 			if (s_config.GetRemoveTempFiles()) {
@@ -1452,7 +1538,7 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 					wxRemoveFile(audioFileTmp);
 			}
 		}
-	} else {
+	} else { // menu with still image
 		wxImage bgImage = menu->GetBackgroundImage();
 		if (!bgImage.Ok()) {
 			Failed(_("Error creation of menu"));
@@ -1493,19 +1579,13 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 			menuVob.AddAudioFile(audioFile);
 			for (unsigned int i=0; i<menuVob.GetStreams().GetCount(); i++) {
 				Stream* stream = menuVob.GetStreams()[i];
-				if (stream->GetType() == stAUDIO && stream->GetAudioFormat() == afCOPY) {
-					// change destination format if it set to COPY and codec is not mp2/ac3 or sample rate != 48 kHz
-					if (stream->GetSourceCodecName() != wxT("mp2") && stream->GetSourceCodecName() != wxT("ac3")) {
-						stream->SetDestinationFormat(audioFormat);
-					} else if (stream->GetSourceSampleRate() != 48000) {
-						stream->SetDestinationFormat(stream->GetSourceCodecName() == wxT("mp2") ? afMP2 : afAC3);
-					}
-				}
+				if (stream->GetType() == stAUDIO)
+					stream->SetDestinationFormat(audioFormat);
 			}
 			menuVob.SetTmpFilename(mpegFile);
 			if (!s_config.GetUseMplexForMenus())
 				AddDetailMsg(WARNING_MPLEX_MSG, *wxRED);
-			if (!Transcode(&menuVob, menu->GetAspectRatio(), s_config.GetMenuVideoBitrate(),
+			if (!Transcode(&menuVob, menu->GetAspectRatio(), s_config.GetMenuVideoBitrate(), audioBitrate,
 					s_config.GetUseMplexForMenus()))
 				return false;
 			if (s_config.GetRemoveTempFiles())
@@ -1564,7 +1644,7 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 }
 
 bool ProgressDlg::GenerateSlideshow(Slideshow* slideshow, const wxString& vobFile, AudioFormat audioFormat,
-		wxString audioFile) {
+		wxString audioFile, int audioBitrate) {
 	if (IsCanceled())
 		return false;
 	AddDetailMsg(_("Generating slideshow"));
@@ -1601,20 +1681,13 @@ bool ProgressDlg::GenerateSlideshow(Slideshow* slideshow, const wxString& vobFil
 		slideShowVob.AddAudioFile(audioFile);
 		for (unsigned int i=0; i<slideShowVob.GetStreams().GetCount(); i++) {
 			Stream* stream = slideShowVob.GetStreams()[i];
-			if (stream->GetType() == stAUDIO && stream->GetAudioFormat() == afCOPY) {
-				// set destination format if it set to COPY and codec is not mp2/ac3 or sample rate != 48 kHz
-				if (stream->GetSourceCodecName() != wxT("mp2")
-						&& stream->GetSourceCodecName() != wxT("ac3")
-						&& stream->GetSourceCodecName() != wxT("liba52")) {
-					stream->SetDestinationFormat(audioFormat);
-				} else if (stream->GetSourceSampleRate() != 48000) {
-					stream->SetDestinationFormat(stream->GetSourceCodecName() == wxT("mp2") ? afMP2 : afAC3);
-				}
-			}
+			if (stream->GetType() == stAUDIO)
+				stream->SetAudioFormat(audioFormat);
 		}
 		slideShowVob.SetTmpFilename(vobFile);
+		slideShowVob.SetRecordingTime(slideshow->GetDuration() * slideshow->GetCount());
 		if (!Transcode(&slideShowVob, slideshow->GetAspectRatio(), s_config.GetSlideshowVideoBitrate(),
-				s_config.GetUseMplexForMenus()))
+				audioBitrate, s_config.GetUseMplexForMenus()))
 			return false;
 		if (s_config.GetRemoveTempFiles())
 			DeleteFile(m2vFile);
