@@ -3,7 +3,7 @@
 // Purpose:     Progress of generation/burning dialog
 // Author:      Alex Thuering
 // Created:     14.08.2004
-// RCS-ID:      $Id: ProgressDlg.h,v 1.34 2012/01/22 20:40:34 ntalex Exp $
+// RCS-ID:      $Id: ProgressDlg.h,v 1.38 2013/08/18 08:46:00 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -14,10 +14,13 @@
 #include "DVD.h"
 #include "Cache.h"
 #include "BurnDlg.h"
+#include <wx/ffile.h>
 
 // begin wxGlade: dependencies
 // end wxGlade
 
+class MainWin;
+
 class ProgressDlg : public wxDialog {
 public:
     // begin wxGlade: ProgressDlg::ids
@@ -28,50 +31,44 @@ public:
     // end wxGlade
 
 public:
-	/**
-	 * Constructor
-	 */
-	ProgressDlg(wxWindow* parent, Cache* cache, bool autoStart);
-	// starts the generating of DVD
+	/** Constructor */
+	ProgressDlg(MainWin* parent, Cache* cache, bool autoStart);
+	/** starts the generating of DVD */
 	bool Start(BurnDlg* burnDlg, DVD* dvd);
 
-	// add the given message to summary textbox
-	void AddSummaryMsg(const wxString& message,
-			const wxString& details = wxEmptyString,
+	/** Adds the given message to summary textbox */
+	void AddSummaryMsg(const wxString& message, const wxString& details = wxEmptyString,
 			const wxColour& colour = wxNullColour);
-	// add the given message to details textbox
+	/** Add the given message to details textbox */
 	void AddDetailMsg(const wxString& message,
 			const wxColour& colour = wxNullColour);
-	// add the given text to details textbox
+	/** Add the given text to details textbox */
 	void AddDetailText(const wxString& text);
 
-	// sets the step count of generating process
-	void SetSteps(int value) {
-		m_gauge->SetRange(value*100);
-		m_step = 0;
-	}
-	// increments the step
+	/** Sets the step count of generating process */
+	void SetSteps(int stepCount);
+	/** Increments the step */
 	void IncStep() {
 		m_step ++;
 		m_subStep = 0;
 		UpdateGauge();
 	}
 
-	// sets the sub-step count of current step
+	/** Sets the sub-step count of current step */
 	void SetSubSteps(int value) {
 		m_subStepCount = value;
 		m_subStep = 0;
 	}
-	// sets the sub-step
+	/** Sets the sub-step */
 	void SetSubStep(int value) {
 		m_subStep = value;
 		UpdateGauge();
 	}
-	// increments the sub-step
+	/** increments the sub-step */
 	void IncSubStep(int value = 1) {
 		SetSubStep(GetSubStep() + value);
 	}
-	// returns the sub-step
+	/** Returns the sub-step */
 	int GetSubStep() {
 		return m_subStep;
 	}
@@ -99,12 +96,14 @@ private:
 	
 	bool m_autoStart;
 	int m_step;
+	int m_stepCount;
 	int m_subStepCount;
 	int m_subStep;
 	bool m_cancel;
 	bool m_end;
 	
 	Cache* m_cache;
+	wxFFile m_logFile;
 	
 	void UpdateGauge();
 
@@ -136,9 +135,11 @@ private:
 	bool BurnDvd(BurnDlg* burnDlg, DVD* dvd, const wxString& dvdOutDir, const wxString& tmpDir);
 	
 	bool GenerateMenu(Menu* menu, WidescreenType widescreenType, const wxString& menuFile, AudioFormat audioFormat,
-			wxString audioFile, int videoBitrate);
-    bool GenerateSlideshow(Slideshow* slideshow, const wxString& vobFile, AudioFormat audioFormat, wxString audioFile);
-	bool Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, bool useMplex, AudioFormat defAudioFormat = afAC3);
+			wxString audioFile, int audioBitrate);
+    bool GenerateSlideshow(Slideshow* slideshow, const wxString& vobFile, AudioFormat audioFormat, wxString audioFile,
+    		int audioBitrate);
+	bool Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, int audioBitrate, bool useMplex,
+			AudioFormat defAudioFormat = afAC3);
 	bool MultiplexSubtitles(const wxString& vobFile, TextSub* textSub, unsigned int streamIdx, VideoFormat videoFormat,
 			const wxString& resultFile);
 	/** removes given file and print error message if it failed */
