@@ -3,7 +3,7 @@
 // Purpose:     Settings dialog
 // Author:      Alex Thuering
 // Created:     27.03.2004
-// RCS-ID:      $Id: SettingsDlg.cpp,v 1.64 2012/08/29 18:49:06 ntalex Exp $
+// RCS-ID:      $Id: SettingsDlg.cpp,v 1.68 2013/06/23 21:02:31 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -81,10 +81,21 @@ void SettingsDlg::CreatePropPanel(wxSizer* sizer) {
 	// fix size
 	wxControl* videoChoice = GetLastControl();
 	discCapacityChoice->SetMinSize(videoChoice->GetBestSize());
+	if (vfSizer)
+		vfSizer->AddSpacer(4);
 	// aspect ratio
 	labels = DVD::GetAspectRatioLabels();
-	AddChoiceProp(vfSizer, wxT(""), labels[s_config.GetDefAspectRatio() - 1], labels, 0);
+	AddChoiceProp(vfSizer, wxT(""), labels[s_config.GetDefAspectRatio() - 1], labels);
+#if wxCHECK_VERSION(2,9,3)
+	if (vfSizer)
+		vfSizer->GetItem(vfSizer->GetItemCount()-1)->SetProportion(0);
+#endif
 	wxControl* aspectRatioChoice = GetLastControl();
+	if (vfSizer)
+		vfSizer->AddSpacer(4);
+	AddCheckProp(vfSizer, _("Keep aspect ratio"), s_config.GetDefKeepAspectRatio(def));
+	if (vfSizer)
+		vfSizer->AddStretchSpacer(1);
 	
 	// audio format
 	AddText(interfaceGrid, _("Default audio format:"));
@@ -98,13 +109,15 @@ void SettingsDlg::CreatePropPanel(wxSizer* sizer) {
 	AddChoiceProp(afSizer, wxT(""), labels[af], labels);
 	// fix size
 	GetLastControl()->SetMinSize(videoChoice->GetBestSize());
+	if (afSizer)
+		afSizer->AddSpacer(4);
 	// default audio language
 	labels = DVD::GetAudioLanguageCodes();
 	AddChoiceProp(afSizer, wxT(""), s_config.GetDefAudioLanguage(), labels, 0);
 	GetLastControl()->SetMinSize(aspectRatioChoice->GetBestSize());
 	
 	// default chapter length
-	AddSpinProp(interfaceGrid, _("Default chapter length:"), s_config.GetDefChapterLength(def), 1, 999, 60, _("min"));
+	AddSpinProp(interfaceGrid, _("Default chapter length:"), s_config.GetDefChapterLength(def), 0, 999, 60, _("min"));
 	
 	// default title post command
 	labels = DVD::GetDefPostCommandLabels();
@@ -196,11 +209,11 @@ void SettingsDlg::CreatePropPanel(wxSizer* sizer) {
 	if (menuSizer)
 		menuSizer->AddSpacer(6);
 	AddCheckProp(menuSizer, _("Draw buttons on background"), s_config.GetDrawButtonsOnBackground(def));
-	AddSpinProp(coreGrid, _("Menu video bitrate:"), s_config.GetMenuVideoBitrate(def), 1, 9999999, 80);
-	AddSpinProp(coreGrid, _("Slideshow video bitrate:"), s_config.GetSlideshowVideoBitrate(def), 1, 9999999, 80);
-	AddSpinProp(coreGrid, _("Audio bitrate:"), s_config.GetAudioBitrate(def), 1, 9999999, 80);
+	AddSpinProp(coreGrid, _("Menu video bitrate:"), s_config.GetMenuVideoBitrate(def), 1, 9999, 80, _("KBit/s"));
+	AddSpinProp(coreGrid, _("Slideshow video bitrate:"), s_config.GetSlideshowVideoBitrate(def), 1, 9999, 80, _("KBit/s"));
+	AddSpinProp(coreGrid, _("Default audio bitrate:"), s_config.GetAudioBitrate(def), 1, 9999, 80, _("KBit/s"));
 	AddSpinProp(coreGrid, _("Thread count:"), s_config.GetThreadCount(def), 1, 99, 80);
-	AddSpinProp(coreGrid, _("DVD reserved space:"), s_config.GetDvdReservedSpace(def), 0, 9999999, 80);
+	AddSpinProp(coreGrid, _("DVD reserved space:"), s_config.GetDvdReservedSpace(def), 0, 9999999, 80, _("KB"));
 #if defined(__WXMSW__)
 	AddFileProp(coreGrid, _("Preview command:"), s_config.GetPreviewCmd(def), wxFD_OPEN, wxT("..."),
 			wxString(_("Executable Files ")) + wxT(" (*.exe)|*.exe") + wxT("|") +
@@ -235,6 +248,7 @@ bool SettingsDlg::SetValues() {
 	s_config.SetDefDiscCapacity(GetInt(i++));
 	s_config.SetDefVideoFormat(GetInt(i++) + 2);
 	s_config.SetDefAspectRatio(GetInt(i++) + 1);
+	s_config.SetDefKeepAspectRatio(GetBool(i++));
 	s_config.SetDefAudioFormat(GetInt(i++) + 2);
 	s_config.SetDefAudioLanguage(GetString(i++));
 	s_config.SetDefChapterLength(GetInt(i++));
