@@ -3,7 +3,7 @@
 // Purpose:     The class to store information for slideshow
 // Author:      Alex Thuering
 // Created:	26.06.2005
-// RCS-ID:      $Id: Slideshow.cpp,v 1.8 2011/07/07 22:10:20 ntalex Exp $
+// RCS-ID:      $Id: Slideshow.cpp,v 1.9 2012/11/02 19:28:25 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 //////////////////////////////////////////////////////////////////////////////
@@ -58,9 +58,9 @@ Slideshow::~Slideshow() {
 }
 
 wxSize Slideshow::GetResolution() {
-	if (m_videoFormat == vfNTSC)
-		return wxSize(720, 480);
-	return wxSize(720, 576); // vfPAL
+	if (m_aspectRatio == ar16_9)
+		return wxSize(720, 405);
+	return wxSize(720, 540); // 4:3
 }
 
 float Slideshow::GetFPS() {
@@ -135,11 +135,15 @@ wxImage Slideshow::GetImage(int index) {
 	if (index < (int) m_slides.size())
 		img.LoadFile(m_slides[index]->GetFilename());
 	if (img.GetWidth() == 0 || img.GetHeight() == 0)
-		return wxImage(width, height);
+		return wxImage(GetFrameSize(m_videoFormat).GetWidth(), GetFrameSize(m_videoFormat).GetHeight());
 	float scale = (float) width / img.GetWidth();
 	if (scale > (float) height / img.GetHeight())
 		scale = (float) height / img.GetHeight();
-	img.Rescale((int) (img.GetWidth() * scale), (int) (img.GetHeight() * scale));
+	img.Rescale((int) (img.GetWidth() * scale),
+			(int) (img.GetHeight() * scale * GetFrameSize(m_videoFormat).GetHeight() / height));
+	
+	width = GetFrameSize(m_videoFormat).GetWidth();
+	height = GetFrameSize(m_videoFormat).GetHeight();
 	wxImage resImg(width, height);
 	int x_offset1 = (width - img.GetWidth()) / 2;
 	int x_offset2 = width - img.GetWidth() - x_offset1;
