@@ -3,7 +3,7 @@
 // Purpose:     The class to store information for slideshow
 // Author:      Alex Thuering
 // Created:	26.06.2005
-// RCS-ID:      $Id: Slideshow.h,v 1.6 2011/07/07 22:10:20 ntalex Exp $
+// RCS-ID:      $Id: Slideshow.h,v 1.7 2012/01/13 18:22:55 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -12,18 +12,7 @@
 #define SLIDESHOW_H
 
 #include "Menu.h"
-#include <vector>
-
-using namespace std;
-
-#define VECTOR_CLEAR(obj, elem_type) \
-	for (vector<elem_type*>::iterator vectorIt = obj.begin(); vectorIt != obj.end(); vectorIt++) \
-		delete *vectorIt; \
-	obj.clear();
-
-#define VECTOR_COPY(src, dst, elem_type) \
-	for (vector<elem_type*>::const_iterator vectorIt = src.begin(); vectorIt != src.end(); vectorIt++) \
-		dst.push_back(new elem_type(**vectorIt));
+#include "Utils.h"
 
 class Slide {
 public:
