@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD TextSub parameters
 // Author:      Alex Thuering
 // Created:	    09.04.2011
-// RCS-ID:      $Id: TextSub.cpp,v 1.2 2012/10/14 13:15:12 ntalex Exp $
+// RCS-ID:      $Id: TextSub.cpp,v 1.3 2012/11/13 22:00:07 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -50,6 +50,13 @@ wxString TextSub::GetFontFile() {
 	return fonts.begin() != fonts.end() ? fonts.begin()->second : wxT("");
 }
 
+wxString ToString(const wxColour& colour, DVDFileType type) {
+	if (!colour.IsOk())
+		return type == DVDAUTHOR_XML ? wxT("rgba(0,0,0,0)") : wxT("#00000000");
+	return wxString::Format(type == DVDAUTHOR_XML ? wxT("rgba(%d,%d,%d,%d)") : wxT("#%02x%02x%02x%02x"),
+			colour.Red(), colour.Green(), colour.Blue(), colour.Alpha());
+}
+
 wxSvgXmlNode* TextSub::GetXML(DVDFileType type) {
 	wxSvgXmlNode* textsubNode = new wxSvgXmlNode(wxSVGXML_ELEMENT_NODE, _T("textsub"));
 	TextSub* defaults = new TextSub(wxT(""));
@@ -71,17 +78,10 @@ wxSvgXmlNode* TextSub::GetXML(DVDFileType type) {
 		textsubNode->AddProperty(_T("fontsize"), wxString::Format(wxT("%g"), m_fontSize));
 	
 	// colours
-	if (m_fillColour.IsOk() && m_fillColour != defaults->m_fillColour)
-		textsubNode->AddProperty(wxT("fill-color"), wxString::Format(wxT("#%02x%02x%02x"),
-				m_fillColour.Red(), m_fillColour.Green(), m_fillColour.Blue()));
-	if (m_outlineColour.IsOk() && m_outlineColour != defaults->m_outlineColour)
-		textsubNode->AddProperty(wxT("outline-color"), wxString::Format(wxT("#%02x%02x%02x"),
-				m_outlineColour.Red(), m_outlineColour.Green(), m_outlineColour.Blue()));
-	if (m_outlineThickness != defaults->m_outlineThickness)
-		textsubNode->AddProperty(wxT("outline-thickness"), wxString::Format(wxT("%f"), m_outlineThickness));
-	if (m_shadowColour.IsOk() && m_shadowColour != defaults->m_shadowColour)
-		textsubNode->AddProperty(wxT("shadow-color"), wxString::Format(wxT("#%02x%02x%02x"),
-				m_shadowColour.Red(), m_shadowColour.Green(), m_shadowColour.Blue()));
+	textsubNode->AddProperty(wxT("fill-color"), ToString(m_fillColour, type));
+	textsubNode->AddProperty(wxT("outline-color"), ToString(m_outlineColour, type));
+	textsubNode->AddProperty(wxT("outline-thickness"), wxString::Format(wxT("%f"), m_outlineThickness));
+	textsubNode->AddProperty(wxT("shadow-color"), ToString(m_shadowColour, type));
 	if (m_shadowOffset != defaults->m_shadowOffset)
 		textsubNode->AddProperty(wxT("shadow-offset"),
 				wxString::Format(wxT("%d,%d"), m_shadowOffset.x, m_shadowOffset.y));
@@ -127,11 +127,13 @@ wxSvgXmlNode* TextSub::GetXML(DVDFileType type) {
 }
 
 wxColour ParseColour(const wxString& value) {
-	long r = 0, g = 0, b = 0;
+	long r = 0, g = 0, b = 0, a = 255;
 	value.Mid(1, 2).ToLong(&r, 16);
 	value.Mid(3, 2).ToLong(&g, 16);
 	value.Mid(5, 2).ToLong(&b, 16);
-	return wxColour(r, g, b);
+	if (value.length() >= 9)
+		value.Mid(7, 2).ToLong(&a, 16);
+	return wxColour(r, g, b, a);
 }
 
 bool TextSub::PutXML(wxSvgXmlNode* node) {
@@ -151,13 +153,13 @@ bool TextSub::PutXML(wxSvgXmlNode* node) {
 		m_fontSize = dval;
 	
 	// colours
-	if (node->GetPropVal(wxT("fill-color"), &val) && val.length() == 7 && val.GetChar(0) == wxT('#'))
+	if (node->GetPropVal(wxT("fill-color"), &val) && val.length() >= 7 && val.GetChar(0) == wxT('#'))
 		m_fillColour = ParseColour(val);
-	if (node->GetPropVal(wxT("outline-color"), &val) && val.length() == 7 && val.GetChar(0) == wxT('#'))
+	if (node->GetPropVal(wxT("outline-color"), &val) && val.length() >= 7 && val.GetChar(0) == wxT('#'))
 		m_outlineColour = ParseColour(val);
 	if (node->GetPropVal(wxT("outline-thickness"), &val) && val.ToDouble(&dval))
 		m_outlineThickness = dval;
-	if (node->GetPropVal(wxT("shadow-color"), &val) && val.length() == 7 && val.GetChar(0) == wxT('#'))
+	if (node->GetPropVal(wxT("shadow-color"), &val) && val.length() >= 7 && val.GetChar(0) == wxT('#'))
 		m_shadowColour = ParseColour(val);
 	if (node->GetPropVal(wxT("shadow-offset"), &val) && val.Find(wxT(',')) > 0
 			&& val.Mid(0, val.Find(wxT(','))).ToLong(&lval) && val.Mid(val.Find(wxT(',')) + 1).ToLong(&lval2))
@@ -242,9 +244,7 @@ FontMap& TextSub::GetFontMap() {
 		if (FcPatternGetString(fontSet->fonts[fi], FC_FILE, 0, &str) != FcResultMatch)
 			continue;
 		wxString fontFilename = wxString::FromUTF8((char*) str);
-#if 1
-		fontFilename = fontFilename.AfterLast(wxT('/'));
-#endif
+		
 		// font file index
 		int fontFileIndex = 0;
 		FcPatternGetInteger(fontSet->fonts[fi], FC_INDEX, 0, &fontFileIndex);
