@@ -3,7 +3,7 @@
 // Purpose:     DVD title properties dialog
 // Author:      Alex Thuering
 // Created:     31.01.2004
-// RCS-ID:      $Id: TitlePropDlg.cpp,v 1.57 2012/06/24 22:57:24 ntalex Exp $
+// RCS-ID:      $Id: TitlePropDlg.cpp,v 1.60 2013/04/14 05:33:21 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -22,7 +22,7 @@
 #include "rc/remove.png.h"
 #include "rc/preferences.png.h"
 
-wxRegEx s_chapterRegEx(wxT("^(([[:digit:]]+:)?[[:digit:]][[:digit:]]?:)?[[:digit:]][[:digit:]]?(\\.[[:digit:]]+)?$"));
+wxRegEx s_chapterRegEx(wxT("^([[:digit:]][[:digit:]]?:)?([[:digit:]][[:digit:]]?:)?([[:digit:]][[:digit:]]?:)?[[:digit:]][[:digit:]]?(\\.[[:digit:]]+)?$"));
 
 enum {
 	VOB_BOX_ID = 7850,
@@ -228,6 +228,9 @@ void TitlePropDlg::CreateTitleGroup(wxSizer* sizer) {
  */
 wxArrayString TitlePropDlg::GetCommandList(DVD* dvd, int currentTsi) {
 	wxArrayString commands;
+#ifdef __WXMAC__
+	commands.Add(wxT(""));
+#endif
 	commands.Add(wxT("call last menu;"));
 	for (unsigned int pgci=0; pgci < dvd->GetVmgm().Count(); pgci++)
 		commands.Add(wxString::Format(wxT("call vmgm menu %d;"),pgci+1));
@@ -337,7 +340,7 @@ bool TitlePropDlg::SetValues() {
 		m_vobListBox->SetValues();
 		m_vob->SetDoNotTranscode(GetBool(n++) && m_vob->GetAudioFilenames().GetCount() == 0);
 		if (m_chaptersCtrl->IsEnabled()) {
-			m_vob->SetChapters(GetString(n++));
+			m_vob->SetChapters(GetString(n++), m_vobi == 0);
 			m_vob->SetPause(GetInt(n++));
 		} else {
 			m_vob->SetPause(0);
@@ -447,9 +450,9 @@ void TitlePropDlg::OnChaptersBt(wxCommandEvent& event) {
 				return;
 			}
 		}
-		m_vob->SetChapters(m_chaptersCtrl->GetValue());
+		m_vob->SetChapters(m_chaptersCtrl->GetValue(), m_vobi == 0);
 	}
-	ChaptersDlg dialog(this, m_dvd, m_tsi, m_pgci, m_vob);
+	ChaptersDlg dialog(this, m_dvd, m_tsi, m_pgci, m_vobi, m_vob);
 	if (dialog.ShowModal() == wxID_OK)
 		UpdateChaptersCtrl();
 }
@@ -457,6 +460,8 @@ void TitlePropDlg::OnChaptersBt(wxCommandEvent& event) {
 void TitlePropDlg::UpdateChaptersCtrl() {
 	m_chaptersCtrl->SetValue(m_vob->GetChapters());
 	bool readonly = false;
+	if (m_vob->GetCells().size() > 0 && m_vob->GetCells().front()->GetStart() != 0)
+		readonly = true;
 	for (vector<Cell*>::iterator it = m_vob->GetCells().begin(); it != m_vob->GetCells().end(); it++) {
 		if (!(*it)->IsChapter() || (*it)->GetEnd() >= 0 || (*it)->GetPause() != 0
 				|| (*it)->GetCommands().length() > 0) {
