@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Titleset
 // Author:      Alex Thuering
 // Created:     29.01.2003
-// RCS-ID:      $Id: Titleset.cpp,v 1.11 2012/07/01 22:14:29 ntalex Exp $
+// RCS-ID:      $Id: Titleset.cpp,v 1.12 2013/03/27 22:00:57 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -384,10 +384,11 @@ wxSvgXmlNode* Titleset::GetXML(DVDFileType type, DVD* dvd, int nextTitleset) {
 	wxSvgXmlNode* node = new wxSvgXmlNode(wxSVGXML_ELEMENT_NODE, wxT("titleset"));
 	if (m_menus.Count() || type != DVDAUTHOR_XML)
 		node->AddChild(m_menus.GetXML(type, dvd));
-	else if (dvd->IsEmptyMenuEnabled() && dvd->GetVmgm().Count()) {
+	else if (dvd->IsEmptyMenuEnabled() && dvd->HasMenus()) {
 		// create empty menu with post command
 		Menus menus;
 		Pgc* pgc = new Pgc;
+		pgc->GetEntries().insert(wxT("root"));
 		pgc->SetPreCommands(wxT("jump vmgm menu;"));
 		pgc->GetVobs().Add(Vob::CreateEmptyVob(dvd->GetVideoFormat(), dvd->GetAudioFormat()));
 		menus.Add(pgc);
