@@ -3,7 +3,7 @@
 // Purpose:     Titleset Manager
 // Author:      Alex Thuering
 // Created:	27.01.2003
-// RCS-ID:      $Id: TitlesetManager.cpp,v 1.67 2012/10/14 16:23:02 ntalex Exp $
+// RCS-ID:      $Id: TitlesetManager.cpp,v 1.76 2013/06/23 21:02:31 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -24,7 +24,7 @@
 #include <wx/clipbrd.h>
 #include <wx/utils.h>
 #include <wx/artprov.h>
-#include "rc/noaudio.png.h"
+#include <wx/progdlg.h>
 
 //////////////////////////////////////////////////////////////////////////////
 ///////////////////////////// TitleDnDFile ///////////////////////////////////
@@ -81,26 +81,7 @@ public:
 			m_pOwner->AddImage(filename, def == wxDragMove && first);
 			return true;
 		} else if (wxThumbnails::IsVideo(filename)) {
-			wxFfmpegMediaDecoder decoder;
-			if (!decoder.Load(filename))
-				return false;
-			bool hasVideo = false;
-			bool hasAudio = false;
-			for (unsigned int i = 0; i < decoder.GetStreamCount(); i++) {
-				if (decoder.GetStreamType(i) == stVIDEO)
-					hasVideo = true;
-				else if (decoder.GetStreamType(i) == stAUDIO)
-					hasAudio = true;
-			}
-			if (!hasVideo && !hasAudio) {
-				wxLogError(_("File '%s' doesn't contain any audio or video streams."));
-				return false;
-			}
-			if (hasVideo)
-				m_pOwner->AddVideo(filename, def == wxDragMove);
-			else
-				m_pOwner->AddAudio(filename);
-			return true;
+			return m_pOwner->AddVideo(filename, def == wxDragMove);
 		} else if (wxThumbnails::IsAudio(filename)) {
 			m_pOwner->AddAudio(filename);
 			return true;
@@ -110,11 +91,7 @@ public:
 		}
 		
 		// try to load it as video
-		wxFfmpegMediaDecoder decoder;
-		if (!decoder.Load(filename))
-			return false;
-		m_pOwner->AddVideo(filename, def == wxDragMove);
-		return true;
+		return m_pOwner->AddVideo(filename, def == wxDragMove);
 	}
 protected:
 	TitlesetManager *m_pOwner;
@@ -161,6 +138,7 @@ TitlesetManager::TitlesetManager(wxWindow* parent, int id): wxThumbnails(parent,
 	EnableDragging(false); // disable standard dragging of wxThumbnails
 	m_dvd = NULL;
 	m_selectedMenu = -1;
+	m_reEncodingByDefault = false;
 
 	wxMenu* addMenu = new wxMenu;
 	addMenu->Append(MainWin::MENU_DVD_ADD_FILE_ID, _("&File..."));
@@ -301,13 +279,8 @@ void TitlesetManager::DrawThumbnail(wxBitmap& bmp, wxThumb& thumb, int index) {
 	wxRect imgRect(x + (m_tWidth-img.GetWidth())/2, y + titleHeight + (m_tHeight-titleHeight-img.GetHeight())/2,
 			img.GetWidth(), img.GetHeight());
 	dc.DrawBitmap(img, imgRect.x, imgRect.y);
-	// check audio
-	if (!vob->GetMenu() && !vob->GetSlideshow() && !vob->HasAudio()) {
-		wxBitmap noaudioBitmap = wxBITMAP_FROM_MEMORY(noaudio);
-		dc.DrawBitmap(noaudioBitmap,
-				imgRect.x + img.GetWidth() - noaudioBitmap.GetWidth(),
-				imgRect.y + img.GetHeight() - noaudioBitmap.GetHeight());
-	} else if (vob->GetAudioFilenames().GetCount() > 0) {
+	// audio files
+	if (vob->GetAudioFilenames().GetCount() > 0) {
 		wxString text = vob->GetAudioFilenames()[0].AfterLast(wxT('.')).Lower();
 		for (int fi = 1; fi < (int)vob->GetAudioFilenames().GetCount(); fi++)
 			text += wxT(",") + vob->GetAudioFilenames()[fi].AfterLast(wxT('.')).Lower();
@@ -444,14 +417,29 @@ int TitlesetManager::GetIndex(int id) {
 	return -1;
 }
 
-bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi) {
+bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi, bool allowMenuDuplication) {
+	wxProgressDialog pdlg(wxT("DVDStyler"), wxString::Format(_("Adding file %s. Please wait..."), fname.c_str()),
+			99, this, wxPD_APP_MODAL | wxPD_AUTO_HIDE | wxPD_SMOOTH);
+	pdlg.Show();
+	pdlg.SetFocus();
+	pdlg.Pulse();
 	Vob* vob = new Vob(_T(""));
-	if (!vob->SetFilename(fname))
+	if (!vob->SetFilename(fname)) {
+		pdlg.Close();
+		delete vob;
 		return false;
+	}
+	pdlg.Close();
+	
 	Stream* videoStream = vob->GetVideoStream();
 	if (videoStream == NULL) {
-		wxLogError(_("%s doesn't contain video stream."), fname.c_str());
-		return false;
+		if (vob->GetAudioStreamCount() == 0) {
+			delete vob;
+			wxLogError(_("File '%s' doesn't contain any audio or video streams."), fname.c_str());
+			return false;
+		}
+		delete vob;
+		return AddAudio(fname);
 	}
 		
 	int videoBitrateOld = m_dvd->GetVideoBitrate();
@@ -489,12 +477,15 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi)
 		Stream* stream = vob->GetStreams()[i];
 		if (stream->GetType() == stVIDEO) {
 			// set destination format (default COPY) if codec is not mpeg2
-			if (!stream->GetSourceCodecName().StartsWith(wxT("mpeg2video"))
+			if (m_reEncodingByDefault
+					|| vob->GetStreams().GetCount() == 1 // only video is available
+					|| !stream->GetSourceCodecName().StartsWith(wxT("mpeg2video"))
 					|| stream->GetSourceVideoFormat() != pgcs.GetVideo().GetFormat()
 					|| fabs(stream->GetSourceAspectRatio()
-							- GetFrameAspectRatio(vfPAL, pgcs.GetVideo().GetAspect())) >= 0.15)
+							- GetFrameAspectRatio(vfPAL, pgcs.GetVideo().GetAspect())) >= 0.15) {
 				stream->SetDestinationFormat(pgcs.GetVideo().GetFormat());
-			else if (vob->GetAudioFilenames().Count() == 0 && MPEG::HasNavPacks(vob->GetFilename()))
+				vob->SetKeepAspectRatio(s_config.GetDefKeepAspectRatio());
+			} else if (vob->GetAudioFilenames().Count() == 0 && MPEG::HasNavPacks(vob->GetFilename()) && i == 0)
 				vob->SetDoNotTranscode(true);  // do not remultiplex/transcode if the video is already a VOB
 		} else if (stream->GetType() == stAUDIO) {
 			// set destination format (default COPY) if codec is not mp2/ac3 or sample rate is not 48 kHz
@@ -504,25 +495,27 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi)
 				vob->SetDoNotTranscode(false);
 			}
 		} else if (stream->GetType() == stSUBTITLE) {
-			stream->SetDestinationFormat(sfNONE);
+			stream->SetDestinationFormat(stream->GetSourceCodecName() == wxT("dvdsub") ? sfCOPY : sfNONE);
 		}
 	}
 	// set chapters
-	int n = 10;
-	if (vob->GetDuration() > 0) {
-		int duration = (int) vob->GetDuration() / 60;
-		n = duration / s_config.GetDefChapterLength();
-		if (n > 0 && duration - s_config.GetDefChapterLength()*n < s_config.GetDefChapterLength()/5)
-			n--;
+	int n = 0;
+	if (s_config.GetDefChapterLength() > 0) {
+		if (vob->GetDuration() > 0) {
+			int duration = (int) vob->GetDuration() / 60;
+			n = duration / s_config.GetDefChapterLength();
+			if (n > 0 && duration - s_config.GetDefChapterLength()*n < s_config.GetDefChapterLength()/5)
+				n--;
+			if (n>100)
+				n = 100;
+		} else {
+			n = 10;
+		}
 	}
-	if (n>100)
-		n = 100;
 	
 	Pgc* pgc = pgcs.Count()>0 ? pgcs.Last() : NULL;
-	if (!createTitle && pgc != NULL)
-		vob->GetCells().push_back(new Cell(0));
-		long t = s_config.GetDefChapterLength();
-		for (int i = 0; i < n; i++) {
+	long t = 0;
+	for (int i = 0; i <= n; i++) {
 		vob->GetCells().push_back(new Cell(t * 60000));
 		t += s_config.GetDefChapterLength();
 	}
@@ -533,7 +526,7 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi)
 		pgc->SetPostCommands(m_dvd->GetDefPostCommandStr());
 		pgc->GetVobs().Add(vob);
 		pgcs.Add(pgc);
-		if (!m_dvd->UpdateButtonImageFor(tsi, pgcs.GetCount() - 1) && pgcs.GetCount() > 4) {
+		if (allowMenuDuplication && !m_dvd->UpdateButtonImageFor(tsi, pgcs.GetCount() - 1) && pgcs.GetCount() > 4) {
 			// find menu to duplicate
 			PgcArray& menus = m_dvd->GetPgcArray(tsi, true);
 			for (unsigned int menuIdx = 0; menuIdx < menus.GetCount(); menuIdx++) {
@@ -560,7 +553,39 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi)
 	UpdateItems();
 	SendDvdChangedEvent();
 	
-	if (videoBitrateOld >= 2000 && m_dvd->GetVideoBitrate() < 2000) {
+	// check if video fit on DVD without re-encoding
+	bool isCopy = false;
+	for (int tsi = 0; tsi<(int)m_dvd->GetTitlesets().Count(); tsi++) {
+		Titleset* ts = m_dvd->GetTitlesets()[tsi];
+		for (int pgci = 0; pgci<(int)ts->GetTitles().Count(); pgci++) {
+			Pgc* pgc = ts->GetTitles()[pgci];
+			for (int vobi = 0; vobi<(int)pgc->GetVobs().Count(); vobi++) {
+				Stream* stream = pgc->GetVobs()[vobi]->GetVideoStream();
+				if (stream != NULL && stream->GetVideoFormat() == vfCOPY) {
+					isCopy = true;
+					break;
+				}
+			}
+		}
+	}
+	if (isCopy && m_dvd->GetCapacity() != dcUNLIMITED && m_dvd->GetSize() > m_dvd->GetCapacityValue()) {
+		if (wxMessageBox(_("The selected video files don't fit on DVD without re-encoding.\n\
+Do you want to enable re-encoding?"), _("Burn"), wxYES_NO|wxICON_QUESTION, this) == wxYES) {
+			m_reEncodingByDefault = true;
+			for (int tsi = 0; tsi<(int)m_dvd->GetTitlesets().Count(); tsi++) {
+				Titleset* ts = m_dvd->GetTitlesets()[tsi];
+				for (int pgci = 0; pgci<(int)ts->GetTitles().Count(); pgci++) {
+					Pgc* pgc = ts->GetTitles()[pgci];
+					for (int vobi = 0; vobi<(int)pgc->GetVobs().Count(); vobi++) {
+						Stream* stream = pgc->GetVobs()[vobi]->GetVideoStream();
+						if (stream != NULL)
+							stream->SetDestinationFormat(pgcs.GetVideo().GetFormat());
+					}
+				}
+			}
+			SendDvdChangedEvent();
+		}
+	} else if (videoBitrateOld >= 2000 && m_dvd->GetVideoBitrate() < 2000) {
 		wxMessageBox(_("The video bitrate is reduced below 2 MB/s to fit your video on DVD. \
 This can produce DVD with bad video quality."), wxT("DVDStyler"), wxOK | wxICON_WARNING, this);
 	}
@@ -578,7 +603,8 @@ bool TitlesetManager::AddAudio(const wxString& fname) {
 		return false;
 	}
 	Vob* vob = pgcs.Last()->GetVobs().Last();
-	vob->AddAudioFile(fname);
+	if (!vob->AddAudioFile(fname))
+		return false;
 	vob->SetDoNotTranscode(false);
 	// check if reencoding is needed
 	Stream* stream = vob->GetStreams()[vob->GetStreams().GetCount()-1];
@@ -618,7 +644,7 @@ void TitlesetManager::AddImage(const wxString& fname, bool createTitle) {
 
 	if (createTitle || pgc == NULL) {
 		pgc = new Pgc;
-		pgc->SetPostCommands(_T("call last menu;"));
+		pgc->SetPostCommands(m_dvd->GetDefPostCommandStr());
 		pgcs.Add(pgc);
 	}
 
@@ -785,9 +811,9 @@ void TitlesetManager::FixVobChapters(Pgc* pgc, int vobi, int vobi2) {
 	wxString chapters2 = pgc->GetVobs()[vobi2]->GetChapters();
 	if (!(chapters + wxT(",")).StartsWith(wxT("0:00,")) && (chapters2 + wxT(",")).StartsWith(wxT("0:00,"))) {
 		chapters = (chapters.length() ? wxT("0:00,") : wxT("0:00")) + chapters;
-		pgc->GetVobs()[vobi]->SetChapters(chapters);
+		pgc->GetVobs()[vobi]->SetChapters(chapters, vobi == 0);
 		chapters2 = chapters2.length() > 4 ? chapters2.substr(5) : wxT("");
-		pgc->GetVobs()[vobi2]->SetChapters(chapters2);
+		pgc->GetVobs()[vobi2]->SetChapters(chapters2, vobi2 == 0);
 	}
 }
 
