@@ -3,7 +3,7 @@
 // Purpose:     Titleset Manager
 // Author:      Alex Thuering
 // Created:	27.01.2003
-// RCS-ID:      $Id: TitlesetManager.h,v 1.19 2012/07/22 09:37:29 ntalex Exp $
+// RCS-ID:      $Id: TitlesetManager.h,v 1.21 2013/03/05 18:14:42 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -26,7 +26,7 @@ class TitlesetManager: public wxThumbnails {
 	int GetSelectedId() { return GetItem(GetSelected())->GetId(); }
 	int GetSelectedMenuId() { return GetSelectedMenu() >= 0 ? GetItem(GetSelectedMenu())->GetId() : -1; }
 	
-	bool AddVideo(const wxString& fname, bool createTitle = true, int tsi = -1);
+	bool AddVideo(const wxString& fname, bool createTitle = true, int tsi = -1, bool allowMenuDuplication = true);
     bool AddAudio(const wxString& fname);
     bool AddSubtitles(const wxString& fname);
     void AddImage(const wxString& fname, bool createTitle = true);
@@ -45,6 +45,7 @@ class TitlesetManager: public wxThumbnails {
   private:
 	DVD* m_dvd;
 	int m_selectedMenu;
+	bool m_reEncodingByDefault;
 	wxBitmap GetThumbImage(wxThumb& thumb);
     void DrawThumbnail(wxBitmap& bmp, wxThumb& thumb, int index);
     void Paint(wxPaintDC& dc);
