@@ -3,7 +3,7 @@
 // Purpose:     The list box to display information about streams in given VOB
 // Author:      Alex Thuering
 // Created:     03.05.2009
-// RCS-ID:      $Id: VobListBox.h,v 1.11 2011/08/01 20:30:09 ntalex Exp $
+// RCS-ID:      $Id: VobListBox.h,v 1.12 2012/06/17 12:06:38 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -21,6 +21,7 @@
 WX_DECLARE_OBJARRAY(wxRect, RectList);
 WX_DECLARE_OBJARRAY(RectList, RectListOfList);
 WX_DECLARE_OBJARRAY(wxArrayString, StringListOfList);
+class TitlePropDlg;
 
 /**
  * The list box to display information about streams in given VOB.
@@ -30,7 +31,7 @@ public:
 	/**
 	 * Constructor
 	 */
-	VobListBox(wxWindow* parent, wxWindowID id, Vob* vob, PgcArray* pgcs, DVD* dvd);
+	VobListBox(TitlePropDlg* parent, wxWindowID id, Vob* vob, PgcArray* pgcs, DVD* dvd);
 	
 	/**
 	 * Returns the height of the specified item (in pixels)
@@ -118,6 +119,7 @@ private:
 	wxImage LoadFrame(const wxString& filename) const;
 	wxBitmap Scale(wxImage image);
 	void RefreshInfo();
+	void UpdateDoNotTranscodeCheck();
 	
 	/**
 	 * Adds given string m_info[n] and coordinates/size to m_infoRect[n]
@@ -160,6 +162,8 @@ private:
 	void OnDoubleClick(wxMouseEvent& evt);
 	/** Processes a button event */
 	void OnButton(wxCommandEvent& event);
+	/** Processes a format change event */
+	void OnFormatChange(wxCommandEvent& event);
 
 	/** Event table */
 	DECLARE_EVENT_TABLE()
