@@ -3,7 +3,7 @@
 // Purpose:     New project dialog
 // Author:      Alex Thuering
 // Created:     23.03.2009
-// RCS-ID:      $Id: WelcomeDlg.cpp,v 1.5 2010/05/28 19:46:27 ntalex Exp $
+// RCS-ID:      $Id: WelcomeDlg.cpp,v 1.6 2012/09/02 14:49:25 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -39,9 +39,12 @@ BEGIN_EVENT_TABLE(WelcomeDlg, NewProjectDlg)
 END_EVENT_TABLE()
 
 WelcomeDlg::WelcomeDlg(wxWindow *parent) : NewProjectDlg(parent, false) {
+	m_newProjectBt = NULL;
+	m_openProjectBt = NULL;
+	m_listBox = NULL;
 	Create(false, true);
 	SetTitle(_("Welcome"));
-	SetSize(400, -1);
+	SetSize(500, -1);
 }
 
 void WelcomeDlg::CreatePropPanel(wxSizer* sizer) {
