@@ -3,7 +3,7 @@
 // Purpose:     Media Encoder Interface
 // Author:      Alex Thuering
 // Created:     2.05.2010
-// RCS-ID:      $Id: mediaenc.cpp,v 1.4 2012/06/24 22:30:05 ntalex Exp $
+// RCS-ID:      $Id: mediaenc.cpp,v 1.5 2013/03/12 06:44:13 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -48,5 +48,5 @@ bool isNTSC(VideoFormat format) {
 
 /** Returns count of frames per second */
 double GetFps(VideoFormat videoFormat, bool ntscFilm) {
-	return isNTSC(videoFormat) ? ntscFilm ? : 30000.0/1001 : 25;
+	return isNTSC(videoFormat) ? (ntscFilm ? 24 : 30000.0/1001) : 25;
 }
