@@ -3,7 +3,7 @@
 // Purpose:     Media Encoder Interface
 // Author:      Alex Thuering
 // Created:     24.02.2007
-// RCS-ID:      $Id: mediaenc.h,v 1.7 2011/02/20 18:51:35 ntalex Exp $
+// RCS-ID:      $Id: mediaenc.h,v 1.9 2012/06/24 22:30:05 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -30,7 +30,8 @@ enum AudioFormat {
 	afNONE = 0,
 	afCOPY,
 	afMP2,
-	afAC3
+	afAC3,
+	afPCM
 };
 
 enum SubtitleFormat {
@@ -51,6 +52,8 @@ wxSize GetFrameSize(VideoFormat format);
 double GetFrameAspectRatio(VideoFormat format, AspectRatio aspect);
 /** Returns true if video format is NTSC */
 bool isNTSC(VideoFormat format);
+/** Returns count of frames per second */
+double GetFps(VideoFormat format, bool ntscFilm);
 
 class wxMediaEncoder {
   public:
