@@ -3,7 +3,7 @@
 // Purpose:     FFMPEG Media Encoder
 // Author:      Alex Thuering
 // Created:     04.08.2007
-// RCS-ID:      $Id: mediaenc_ffmpeg.cpp,v 1.31 2012/10/14 14:44:58 ntalex Exp $
+// RCS-ID:      $Id: mediaenc_ffmpeg.cpp,v 1.37 2013/06/30 15:16:05 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -27,11 +27,16 @@ extern "C" {
 #include <libavformat/avformat.h>
 #include <libswscale/swscale.h>
 #include <libavutil/mathematics.h>
+#include <libavutil/avstring.h>
 }
 
 #define AUDIO_BUF_SIZE 524288
 #define VIDEO_BUF_SIZE 1835008
 
+#if LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(55, 0, 0)
+#define CodecID AVCodecID
+#endif
+
 wxFfmpegMediaEncoder::wxFfmpegMediaEncoder(int threadCount) {
 	m_threadCount = threadCount;
 	m_outputCtx = NULL;
@@ -48,7 +53,7 @@ wxFfmpegMediaEncoder::~wxFfmpegMediaEncoder() {
 }
 
 wxString wxFfmpegMediaEncoder::GetBackendVersion() {
-	return wxString::Format(wxT("FFmpeg: libavformat %d.%d.%d, libavcodec %d.%d.%d, libavutil %d.%d.%d"),
+	return wxString::Format(wxT("libavformat %d.%d.%d, libavcodec %d.%d.%d, libavutil %d.%d.%d"),
 			LIBAVFORMAT_VERSION_INT >> 16, LIBAVFORMAT_VERSION_INT >> 8 & 0xFF, LIBAVFORMAT_VERSION_INT & 0xFF,
 			LIBAVCODEC_VERSION_INT >> 16, LIBAVCODEC_VERSION_INT >> 8 & 0xFF, LIBAVCODEC_VERSION_INT & 0xFF,
 			LIBAVUTIL_VERSION_INT >> 16, LIBAVUTIL_VERSION_INT >> 8 & 0xFF, LIBAVUTIL_VERSION_INT & 0xFF);
@@ -71,7 +76,7 @@ bool wxFfmpegMediaEncoder::BeginEncode(const wxString& fileName, VideoFormat vid
 	EndEncode();
 	AVOutputFormat* outputFormat = av_guess_format("dvd", NULL, NULL);
 	if (audioFormat == afNONE)
-		outputFormat = av_guess_format(NULL, fileName.mb_str(), NULL);
+		outputFormat = av_guess_format(NULL, (const char*) fileName.ToUTF8(), NULL);
 	if (!outputFormat) {
 		wxLogError(wxT("Cannot open output format"));
 		return false;
@@ -85,14 +90,14 @@ bool wxFfmpegMediaEncoder::BeginEncode(const wxString& fileName, VideoFormat vid
 		outputFormat->audio_codec = CODEC_ID_MP2;
 	
 	m_outputCtx = avformat_alloc_context();
+	m_outputCtx->pb = NULL;
 	if (!m_outputCtx) {
-		wxLogError(wxT("memory error"));
+		wxLogError(wxT("memory allocation error"));
 		return false;
 	}
 
 	m_outputCtx->oformat = outputFormat;
-	snprintf(m_outputCtx->filename, sizeof(m_outputCtx->filename), "%s", (const char*) fileName.fn_str());
-	
+	av_strlcpy(m_outputCtx->filename, (const char*) fileName.ToUTF8(), sizeof(m_outputCtx->filename));
 	
 	// add video and audio streams
 	if (!addVideoStream(outputFormat->video_codec, videoFormat, aspectRatio, videoBitrate))
@@ -100,7 +105,7 @@ bool wxFfmpegMediaEncoder::BeginEncode(const wxString& fileName, VideoFormat vid
 	if (!addAudioStream(outputFormat->audio_codec))
 		return false;
 
-	av_dump_format(m_outputCtx, 0, (const char*) fileName.fn_str(), 1);
+	av_dump_format(m_outputCtx, 0, (const char*) fileName.ToUTF8(), 1);
 	m_outputCtx->packet_size = 2048;
 	
 	
@@ -111,7 +116,7 @@ bool wxFfmpegMediaEncoder::BeginEncode(const wxString& fileName, VideoFormat vid
 		return false;
 
 	// open the output file
-	if (avio_open2(&m_outputCtx->pb, fileName.mb_str(), AVIO_FLAG_WRITE, NULL, NULL) < 0) {
+	if (avio_open2(&m_outputCtx->pb, (const char*) fileName.ToUTF8(), AVIO_FLAG_WRITE, NULL, NULL) < 0) {
 		wxLogError(wxT("Could not open '%s'"), fileName.c_str());
 		return false;
 	}
@@ -184,7 +189,7 @@ bool wxFfmpegMediaEncoder::addAudioStream(int codecId) {
 	c->codec_type = AVMEDIA_TYPE_AUDIO;
 	c->bit_rate = 64000;
 	c->sample_rate = 48000;
-	c->sample_fmt = codecId == CODEC_ID_AC3 ? AV_SAMPLE_FMT_FLTP : AV_SAMPLE_FMT_S16;
+	c->sample_fmt = AV_SAMPLE_FMT_S16;
 	c->channels = 2;
 	// some formats want stream headers to be separate
 	if(m_outputCtx->oformat->flags & AVFMT_GLOBALHEADER)
@@ -193,11 +198,37 @@ bool wxFfmpegMediaEncoder::addAudioStream(int codecId) {
 	return true;
 }
 
+bool hasSampleFmt(AVCodec* codec, AVSampleFormat sample_fmt) {
+	if (codec != NULL && codec->sample_fmts != NULL) {
+		int fIdx = 0;
+		while (codec->sample_fmts[fIdx] >= 0) {
+			if (codec->sample_fmts[fIdx] == sample_fmt)
+				return true;
+			fIdx++;
+		}
+	}
+	return false;
+}
+
 bool wxFfmpegMediaEncoder::OpenAudioEncoder() {
 	AVCodecContext* c = m_audioStm->codec;
 	
 	// find the audio encoder and open it
-	AVCodec* codec = avcodec_find_encoder(c->codec_id);
+	AVCodec* codec = NULL;
+	if (c->codec_id == CODEC_ID_AC3) {
+		// There are 2 ac3 encoders (float and integer). Depending on libav implementation/version/fork,
+		// one or the other may work. So we try both.
+		codec = avcodec_find_encoder_by_name("ac3_fixed");
+		if (!hasSampleFmt(codec, c->sample_fmt)) {
+			// Try the encoding from float format
+			c->sample_fmt = AV_SAMPLE_FMT_FLTP;
+			codec = avcodec_find_encoder(c->codec_id);
+		}
+	} else {
+ 		c->sample_fmt = AV_SAMPLE_FMT_S16;
+ 		codec = avcodec_find_encoder(c->codec_id);
+	}
+
 	if (!codec) {
 		wxLogError(wxT("Audio codec not found"));
 		return false;
@@ -289,7 +320,8 @@ bool wxFfmpegMediaEncoder::EncodeImage(wxImage image, int frames, bool* canceled
 		return false;
 	AVCodecContext *c = m_videoStm->codec;
 	if (image.GetWidth() != c->width || image.GetHeight() != c->height) {
-		wxLogError(wxT("Image size doesn't match frame size."));
+		wxLogError(wxT("Image size (%dx%d) doesn't match frame size (%dx%d)."),
+				image.GetWidth(), image.GetHeight(), c->width, c->height);
 		return false;
 	}
 	// convert wxImage to the codec pixel format
@@ -434,7 +466,8 @@ void wxFfmpegMediaEncoder::CloseEncoder() {
 	}
 
 	// close the output file
-	avio_close(m_outputCtx->pb);
+	if (m_outputCtx->pb != NULL)
+		avio_close(m_outputCtx->pb);
 	
 	// free the stream
 	av_freep(&m_outputCtx);
