@@ -3,7 +3,7 @@
 // Purpose:     FFMPEG Media Transcoder
 // Author:      Alex Thuering
 // Created:     26.04.2008
-// RCS-ID:      $Id: mediatrc_ffmpeg.h,v 1.29 2012/11/05 21:10:32 ntalex Exp $
+// RCS-ID:      $Id: mediatrc_ffmpeg.h,v 1.33 2013/03/17 18:51:00 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -23,17 +23,16 @@ public:
 	static void Init();
 	
 	/** Adds input file. */
-	bool AddInputFile(const wxString& fileName, bool disableVideo = false, bool disableAudio = false,
-			bool disableSubtitle = false, long tsOffset = 0);
+	bool AddInputFile(const wxString& fileName, const wxString& format = wxT(""), long tsOffset = 0);
 	
 	/** Sets output file and video/audio/subtitle formats. */
 	bool SetOutputFile(const wxString& fileName, VideoFormat videoFormat, bool ntscFilm, AudioFormat audioFormat,
 			SubtitleFormat subtitleFormat, int videoBitrate = 6000, bool vbr = false, int audioBitrate = 224,
-			int mapStreamIdx = -1);
+			int mapFileIdx = -1, int mapStreamIdx = -1);
 	/** Sets output file and video/audio/subtitle formats. */
 	bool SetOutputFile(const wxString& fileName, VideoFormat videoFormat, bool ntscFilm, wxArrayInt audioFormats,
 			wxArrayInt subtitleFormats, int videoBitrate = 6000, bool vbr = false, int audioBitrate = 224,
-			int mapStreamIdx = -1);
+			int mapFileIdx = -1, int mapStreamIdx = -1);
 	/** Sets output format (optional). Call it before SetOutputFile() */
 	void SetOutputFormat(wxString outputFormat) { m_outputFormat = outputFormat; }
 	/** Sets interlaced encoding flag */
@@ -58,8 +57,8 @@ public:
 	
 	const wxString& GetCmd() const { return m_cmd; }
 private:
-	int m_threadCount;
-	int m_inputFileCount;
+	unsigned int m_threadCount;
+	unsigned int m_inputFileCount;
 	wxString m_cmd;
 	wxString m_outputFormat;
 	wxString m_videoFilters;
@@ -68,6 +67,7 @@ private:
     void AddOption(const wxString& name, const wxString& value);
     void AddAudioOption(const wxString& name, int streamIdx, const wxString& value);
     void AddVideoOption(const wxString& name, int streamIdx, const wxString& value);
+    void AddSubtitleOption(const wxString& name, int streamIdx, const wxString& value);
 };
 
 #endif // WX_FFMPEG_MEDIA_TRANSCODER_H
