@@ -3,7 +3,7 @@
 // Purpose:     Pipe execute
 // Author:      Alex Thuering
 // Created:     23.08.2004
-// RCS-ID:      $Id: PipeExecute.cpp,v 1.9 2011/11/20 22:54:25 ntalex Exp $
+// RCS-ID:      $Id: PipeExecute.cpp,v 1.10 2012/06/24 22:34:33 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -51,18 +51,17 @@ class wxPipeOutputStream: public wxOutputStream
 
     DECLARE_NO_COPY_CLASS(wxPipeOutputStream)
 };
-class wxOutputStreamUnblocker: public wxPipeOutputStream
-{
-  public:
+class wxOutputStreamUnblocker: public wxPipeOutputStream {
+public:
     wxOutputStreamUnblocker(HANDLE hOutput) : wxPipeOutputStream(hOutput) {}
     
-	void SetBlock(bool block = true)
-	{
-      DWORD mode = PIPE_READMODE_BYTE | PIPE_NOWAIT;
-	  if (block)
-		mode -= PIPE_NOWAIT;
-      if (!SetNamedPipeHandleState(m_hOutput, &mode, NULL, NULL))
-       wxLogLastError(_T("SetNamedPipeHandleState(PIPE_NOWAIT)"));
+	void SetBlock(bool block = true) {
+		DWORD mode = PIPE_READMODE_BYTE | PIPE_NOWAIT;
+		if (block)
+			mode -= PIPE_NOWAIT;
+		if (!SetNamedPipeHandleState(m_hOutput, &mode, NULL, NULL)) {
+			wxLogLastError(_T("SetNamedPipeHandleState(PIPE_NOWAIT)"));
+		}
 	}
 };
 
@@ -226,15 +225,18 @@ protected:
 
 bool wxPipeExecute::Execute(wxString command, wxString inputFile, wxString outputFile) {
 	wxArrayString cmds;
-	while (cmds.Count() < MAX_PROCESSES) {
-		int pos = command.find(wxT('|'));
-		if (pos < 0) {
-			cmds.Add(command.Strip(wxString::both));
-			break;
+	if (command.Find(wxT("\"concat:")) == -1) {
+		while (cmds.Count() < MAX_PROCESSES) {
+			int pos = command.find(wxT('|'));
+			if (pos < 0) {
+				cmds.Add(command.Strip(wxString::both));
+				break;
+			}
+			cmds.Add(command.Mid(0, pos).Strip(wxString::both));
+			command.Remove(0, pos + 1);
 		}
-		cmds.Add(command.Mid(0, pos).Strip(wxString::both));
-		command.Remove(0, pos + 1);
-	}
+	} else
+		cmds.Add(command);
 	int cnt = cmds.Count();
 	
 	wxFileInputStream* input = NULL;
