@@ -3,7 +3,7 @@
 // Purpose:     Properties dialog (base class for all properties dialogs)
 // Author:      Alex Thuering
 // Created:     18.11.2003
-// RCS-ID:      $Id: PropDlg.cpp,v 1.38 2012/10/14 13:15:14 ntalex Exp $
+// RCS-ID:      $Id: PropDlg.cpp,v 1.43 2013/06/04 19:23:35 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -17,6 +17,10 @@
 #include <wx/spinctrl.h>
 #include <wx/statline.h>
 #include <wx/bmpcbox.h>
+#include <wx/tglbtn.h>
+#if !wxCHECK_VERSION(2,9,0)
+#define wxBitmapToggleButton wxToggleBitmapButton
+#endif
 
 #include <wx/arrimpl.cpp>
 WX_DEFINE_OBJARRAY(BitmapArray);
@@ -25,56 +29,45 @@ WX_DEFINE_OBJARRAY(BitmapArray);
 //////////////////////////// ColourPanel ////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-class ColourPanel: public wxPanel {
-public:
-	ColourPanel(wxWindow* parent, wxWindowID id) :
-		wxPanel(parent, id, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER|wxTAB_TRAVERSAL) {
-		m_bgColour = GetBackgroundColour();
+ColourPanel::ColourPanel(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size,
+		long style, const wxString& name): wxPanel(parent, id, pos, size, style, name) {
+	m_bgColour = GetBackgroundColour();
+}
+
+void ColourPanel::SetColour(wxColour colour) {
+	m_colour = colour;
+	if (colour.Ok())
+		SetBackgroundColour(colour);
+	else
+		SetBackgroundColour(m_bgColour);
+	Refresh();
+}
+
+wxColour ColourPanel::GetColour() {
+	return m_colour;
+}
+
+void ColourPanel::OnPaint(wxPaintEvent &event) {
+	wxPaintDC dc(this);
+	PrepareDC(dc);
+	if (!m_colour.Ok()) {
+		dc.SetPen(*wxBLACK_PEN);
+		dc.SetBrush(*wxTRANSPARENT_BRUSH);
+		int w = GetClientSize().GetWidth();
+		int h = GetClientSize().GetHeight();
+		dc.DrawLine(0, 0, w, h);
+		dc.DrawLine(w, 0, 0, h);
 	}
+}
 
-	inline void SetColour(wxColour colour) {
-		m_colour = colour;
-		if (colour.Ok())
-			SetBackgroundColour(colour);
-		else
-			SetBackgroundColour(m_bgColour);
-		Refresh();
-	}
-
-	inline wxColour GetColour() {
-		return m_colour;
-	}
-
-protected:
-	wxColour m_colour;
-	wxColour m_oldColour;
-	wxColour m_bgColour;
-
-	void OnPaint(wxPaintEvent &event) {
-		wxPaintDC dc(this);
-		PrepareDC(dc);
-		if (!m_colour.Ok()) {
-			dc.SetPen(*wxBLACK_PEN);
-			dc.SetBrush(*wxTRANSPARENT_BRUSH);
-			int w = GetClientSize().GetWidth();
-			int h = GetClientSize().GetHeight();
-			dc.DrawLine(0, 0, w, h);
-			dc.DrawLine(w, 0, 0, h);
-		}
-	}
-
-	void OnClick(wxMouseEvent &event) {
-		if (m_colour.Ok()) {
-			m_oldColour = GetColour();
-			SetColour(wxColour());
-		} else
-			SetColour(m_oldColour);
-		Refresh();
-	}
-
-private:
-	DECLARE_EVENT_TABLE()
-};
+void ColourPanel::OnClick(wxMouseEvent &event) {
+	if (m_colour.Ok()) {
+		m_oldColour = GetColour();
+		SetColour(wxColour());
+	} else
+		SetColour(m_oldColour);
+	Refresh();
+}
 
 BEGIN_EVENT_TABLE(ColourPanel, wxPanel)
   EVT_PAINT(ColourPanel::OnPaint)
@@ -115,6 +108,7 @@ enum PropertyType {
   propTEXT = 0,
   propSTAT_TEXT,
   propSPIN,
+  propSPIN_DOUBLE,
   propCOMBO,
   propBITMAP_COMBO,
   propCHOICE,
@@ -123,7 +117,8 @@ enum PropertyType {
   propRADIO_GROUP,
   propGRID,
   propCOLOUR,
-  propFONT
+  propFONT,
+  propTOGGLE_BUTTON
 };
 
 wxColourData wxPropDlg::m_colourData;
@@ -296,7 +291,7 @@ wxSizer* wxPropDlg::AddSpinProp(wxSizer* sizer, const wxString& label, int value
 		pane = new wxBoxSizer(wxHORIZONTAL);
 		pane->Add(ctrl, 0, wxALIGN_CENTER_VERTICAL, 0);
 		if (label2.length() > 0) {
-			pane->AddSpacer(4);
+			pane->AddSpacer(2);
 			AddText(pane, label2);
 		}
 		if (addSpacer)
@@ -310,6 +305,49 @@ wxSizer* wxPropDlg::AddSpinProp(wxSizer* sizer, const wxString& label, int value
 	return pane;
 }
 
+wxSizer* wxPropDlg::AddSpinDoubleProp(wxSizer* sizer, const wxString& label, double value,
+		double min, double max, int width, const wxString& label2, bool addSpacer) {
+	if (!sizer) { // only update value
+#if wxCHECK_VERSION(2,9,3)
+		wxSpinCtrlDouble* ctrl = (wxSpinCtrlDouble*) m_controls[m_updateIndex];
+		ctrl->SetValue(value);
+#else
+		wxTextCtrl* ctrl = (wxTextCtrl*) m_controls[m_updateIndex];
+		ctrl->SetValue(wxString::Format(wxT("%g"), value));
+#endif
+		m_updateIndex++;
+		return NULL;
+	}
+	// add text control
+	if (label.length())
+		sizer->Add(new wxStaticText(propWindow, -1, label), 0, wxALIGN_CENTER_VERTICAL);
+	wxSize size = width > 0 ? wxSize(width, -1) : wxDefaultSize;
+#if wxCHECK_VERSION(2,9,3)
+	wxSpinCtrlDouble* ctrl = new wxSpinCtrlDouble(propWindow, -1, wxEmptyString, wxDefaultPosition, size,
+			wxSP_ARROW_KEYS, min, max);
+	ctrl->SetValue(value);
+#else
+	wxTextCtrl* ctrl = new wxTextCtrl(propWindow, -1, wxString::Format(wxT("%g"), value), wxDefaultPosition, size);
+#endif
+	wxBoxSizer* pane = NULL;
+	if (width > 0) {
+		pane = new wxBoxSizer(wxHORIZONTAL);
+		pane->Add(ctrl, 0, wxALIGN_CENTER_VERTICAL, 0);
+		if (label2.length() > 0) {
+			pane->AddSpacer(4);
+			AddText(pane, label2);
+		}
+		if (addSpacer)
+			pane->Add(0, 0, 1, wxEXPAND);
+		sizer->Add(pane, 1, wxEXPAND, 0);
+	} else
+		sizer->Add(ctrl, 1, wxEXPAND, 0);
+	m_types.Add(propSPIN_DOUBLE);
+	m_controls.Add(ctrl);
+	m_groupIds.Add(m_currGroupId);
+	return pane;
+}
+
 void wxPropDlg::AddCheckProp(wxSizer* sizer, const wxString& label, bool value, bool readonly, int id) {
   if (!sizer) { // only update value
 	wxCheckBox* ctrl = (wxCheckBox*)m_controls[m_updateIndex];
@@ -793,6 +831,22 @@ void wxPropDlg::AddButton(wxSizer* sizer, const wxString& label, const long id,
 	sizer->Add(bt);
 }
 
+void wxPropDlg::AddBitmapToggleButton(wxSizer* sizer, bool value, const long id, const wxBitmap& bitmap,
+		const wxSize& size) {
+	if (!sizer) { // only update value
+		wxBitmapToggleButton* ctrl = (wxBitmapToggleButton*) m_controls[m_updateIndex];
+		ctrl->SetValue(value);
+		m_updateIndex++;
+		return;
+	}
+	wxBitmapToggleButton* ctrl = new wxBitmapToggleButton(this, id, bitmap, wxDefaultPosition, size);
+	ctrl->SetValue(value);
+	sizer->Add(ctrl);
+	m_types.Add(propTOGGLE_BUTTON);
+	m_controls.Add(ctrl);
+	m_groupIds.Add(m_currGroupId);
+}
+
 ////////////////////////////// Group /////////////////////////////////////////
 
 wxSizer* wxPropDlg::BeginGroup(wxSizer* sizer, wxString title, wxString checkTitle, bool value, bool readonly,
@@ -870,59 +924,68 @@ int wxPropDlg::GetLastControlIndex() {
 
 ///////////////////////// Get Values /////////////////////////////////////////
 
-wxString wxPropDlg::GetString(int index)
-{
-  switch(m_types[index])
-  {
-    case propTEXT:
-      return ((wxTextCtrl*)m_controls[index])->GetValue();
-    case propSTAT_TEXT:
-	  return ((wxStaticText*)m_controls[index])->GetLabel();
-    case propCOMBO:
-	  return ((wxComboBox*)m_controls[index])->GetValue();
-    case propCHOICE:
-	  return ((wxChoice*)m_controls[index])->GetStringSelection();
-  }
-  return wxEmptyString;
-}
-
-int wxPropDlg::GetInt(int index)
-{
-  switch(m_types[index])
-  {
-	case propSPIN:
-      return ((wxSpinCtrl*)m_controls[index])->GetValue();
-    case propCOMBO:
-      return ((wxComboBox*)m_controls[index])->GetSelection();
-    case propBITMAP_COMBO:
-      return ((wxBitmapComboBox*)m_controls[index])->GetSelection();
+wxString wxPropDlg::GetString(int index) {
+	switch (m_types[index]) {
+	case propTEXT:
+		return ((wxTextCtrl*) m_controls[index])->GetValue();
+	case propSTAT_TEXT:
+		return ((wxStaticText*) m_controls[index])->GetLabel();
+	case propCOMBO:
+		return ((wxComboBox*) m_controls[index])->GetValue();
 	case propCHOICE:
-      return ((wxChoice*)m_controls[index])->GetSelection();
-    case propRADIO_GROUP:
-    {
-      wxArrayPtrVoid* radioControls = (wxArrayPtrVoid*) m_controls[index];
-  	  for (int i=0; i<(int)radioControls->GetCount(); i++)
-  	  {
-	    wxRadioButton* ctrl = (wxRadioButton*)(*radioControls)[i];
-	    if (ctrl->GetValue())
-	    	return i;
-  	  }
-  	  return -1;
-    }
-  }
-  return -1;
+		return ((wxChoice*) m_controls[index])->GetStringSelection();
+	}
+	return wxEmptyString;
 }
 
-bool wxPropDlg::GetBool(int index)
-{
-  switch(m_types[index])
-  {
-    case propCHECK:
-      return ((wxCheckBox*)m_controls[index])->GetValue();
+int wxPropDlg::GetInt(int index) {
+	switch (m_types[index]) {
+	case propSPIN:
+		return ((wxSpinCtrl*) m_controls[index])->GetValue();
+	case propCOMBO:
+		return ((wxComboBox*) m_controls[index])->GetSelection();
+	case propBITMAP_COMBO:
+		return ((wxBitmapComboBox*) m_controls[index])->GetSelection();
+	case propCHOICE:
+		return ((wxChoice*) m_controls[index])->GetSelection();
+	case propRADIO_GROUP: {
+		wxArrayPtrVoid* radioControls = (wxArrayPtrVoid*) m_controls[index];
+		for (int i = 0; i < (int) radioControls->GetCount(); i++) {
+			wxRadioButton* ctrl = (wxRadioButton*) (*radioControls)[i];
+			if (ctrl->GetValue())
+				return i;
+		}
+		return -1;
+	}
+	}
+	return -1;
+}
+
+bool wxPropDlg::GetBool(int index) {
+	switch (m_types[index]) {
+	case propCHECK:
+		return ((wxCheckBox*) m_controls[index])->GetValue();
 	case propRADIO:
-      return ((wxRadioButton*)m_controls[index])->GetValue();
-  }
-  return true;
+		return ((wxRadioButton*) m_controls[index])->GetValue();
+	case propTOGGLE_BUTTON:
+		return ((wxBitmapToggleButton*) m_controls[index])->GetValue();
+	}
+	return true;
+}
+
+double wxPropDlg::GetDouble(int index) {
+	switch (m_types[index]) {
+	case propSPIN_DOUBLE:
+#if wxCHECK_VERSION(2,9,3)
+		return ((wxSpinCtrlDouble*) m_controls[index])->GetValue();
+#else
+		{
+			double val;
+			return ((wxTextCtrl*) m_controls[index])->GetValue().ToDouble(&val) ? val : -1;
+		}
+#endif
+	}
+	return -1;
 }
 
 void* wxPropDlg::GetClientData(int index) {
