@@ -3,7 +3,7 @@
 // Purpose:     Base class for property dialogs
 // Author:      Alex Thuering
 // Created:     18.11.2003
-// RCS-ID:      $Id: PropDlg.h,v 1.27 2012/03/29 20:43:10 ntalex Exp $
+// RCS-ID:      $Id: PropDlg.h,v 1.31 2013/04/02 06:42:33 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -24,6 +24,28 @@
 
 WX_DECLARE_OBJARRAY(wxBitmap, BitmapArray);
 
+class ColourPanel: public wxPanel {
+public:
+	ColourPanel(wxWindow* parent, wxWindowID id, const wxPoint& pos = wxDefaultPosition,
+			const wxSize& size = wxSize(20, 20), long style = wxTAB_TRAVERSAL | wxSUNKEN_BORDER,
+			const wxString& name = wxPanelNameStr);
+	void SetColour(wxColour colour);
+
+	wxColour GetColour();
+
+protected:
+	wxColour m_colour;
+	wxColour m_oldColour;
+	wxColour m_bgColour;
+	
+	void OnPaint(wxPaintEvent &event);
+	void OnClick(wxMouseEvent &event);
+	
+private:
+	DECLARE_EVENT_TABLE()
+};
+
+
 /** Base class for property dialogs.
   * Allow you to simply create properties dialogs without any GUI designer.
   * Using this class, you can also create dynamic property dialog.
@@ -94,14 +116,27 @@ protected:
 	 * Creates label and spin control.
 	 * @returns subSizer if width > 0, null otherwise
 	 */
-	wxSizer* AddSpinProp(wxSizer* sizer, const wxString& label, int value, int min = 0,
-	  int max = 100, int width = -1, const wxString& label2 = wxT(""), bool addSpacer = true);
-	void AddCheckProp(wxSizer* sizer, const wxString& label, bool value,
-	  bool readonly = false, int id = -1);
-	void AddRadioProp(wxSizer* sizer, const wxString& label, bool value,
-	  long style = wxRB_SINGLE, bool readonly = false, int id = -1);
-	void AddRadioGroupProp(wxSizer* sizer, const wxArrayString& text,
-	  int value, bool readonly = false);
+	wxSizer* AddSpinProp(wxSizer* sizer, const wxString& label, int value, int min = 0, int max = 100,
+			int width = -1, const wxString& label2 = wxT(""), bool addSpacer = true);
+	/**
+	 * Creates label and spin double control.
+	 * @returns subSizer if width > 0, null otherwise
+	 */
+	wxSizer* AddSpinDoubleProp(wxSizer* sizer, const wxString& label, double value, double min  = 0, double max = 100,
+			int width = -1, const wxString& label2 = wxT(""), bool addSpacer = true);
+	/**
+	 * Creates label and check control
+	 */
+	void AddCheckProp(wxSizer* sizer, const wxString& label, bool value, bool readonly = false, int id = -1);
+	/**
+	 * Creates label and radio control
+	 */
+	void AddRadioProp(wxSizer* sizer, const wxString& label, bool value, long style = wxRB_SINGLE,
+			bool readonly = false, int id = -1);
+	/**
+	 * Creates label and radio group control
+	 */
+	void AddRadioGroupProp(wxSizer* sizer, const wxArrayString& text, int value, bool readonly = false);
 	/**
 	 * Creates label and combobox.
 	 * @returns subSizer if width > 0, null otherwise
@@ -147,6 +182,7 @@ protected:
 	  int dlgStyle = wxFD_OPEN, wxString caption = _T("..."), wxString wildcard = _T("*.*"), int id = -1);
 	void AddDirectoryProp(wxSizer* sizer, const wxString& label, const wxString& value, wxString caption = _T("..."));
 	void AddButton(wxSizer* sizer, const wxString& label, const long id, const wxString& buttonLabel = _T("..."));
+	void AddBitmapToggleButton(wxSizer* sizer, bool value, const long id, const wxBitmap& bitmap, const wxSize& size);
 
 	wxSizer* BeginGroup(wxSizer* sizer, wxString title = wxEmptyString, wxString checkTitle = wxEmptyString,
 			bool value = false, bool readonly = false, bool vertical = true, int proportion = 0);
@@ -170,6 +206,7 @@ protected:
 	wxString GetString(int index);
 	int GetInt(int index);
 	bool GetBool(int index);
+	double GetDouble(int index);
 	void* GetClientData(int index);
 	wxArrayPtrVoid GetGrid(int index);
 	wxFontData GetFont(int index);
