@@ -3,7 +3,7 @@
 // Purpose:     wxThumbnails class
 // Author:      Alex Thuering
 // Created:		2.02.2003
-// RCS-ID:      $Id: Thumbnails.cpp,v 1.38 2012/09/14 20:55:25 ntalex Exp $
+// RCS-ID:      $Id: Thumbnails.cpp,v 1.39 2013/02/12 09:31:59 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -202,7 +202,7 @@ void wxThumbnails::ShowDir(wxString dir, int filter) {
 			m_items.Add(new wxThumb(fname, caption));
 		fname = wxFindNextFile();
 	}
-	m_items.Sort(cmpthumb);
+	SortItems();
 	m_selectedArray.Clear();
 	UpdateProp();
 	Refresh();
@@ -380,6 +380,14 @@ void wxThumbnails::RemoveItemAt(int pos, int count) {
 	UpdateProp();
 }
 
+int cmpthumb(wxThumb** first, wxThumb** second) {
+  return (*first)->GetFilename().CmpNoCase((*second)->GetFilename());
+}
+
+void wxThumbnails::SortItems() {
+	m_items.Sort(cmpthumb);
+}
+
 wxRect wxThumbnails::GetPaintRect() {
 	wxSize size = GetClientSize();
 	wxRect paintRect(0, 0, size.GetWidth(), size.GetHeight());
