@@ -3,7 +3,7 @@
 // Purpose:     wxThumbnails class
 // Author:      Alex Thuering
 // Created:	    2.02.2003
-// RCS-ID:      $Id: Thumbnails.h,v 1.18 2011/08/28 09:54:28 ntalex Exp $
+// RCS-ID:      $Id: Thumbnails.h,v 1.19 2013/02/12 09:31:59 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -65,25 +65,14 @@ class wxThumb
 
 WX_DEFINE_ARRAY(wxThumb*, wxThumbArray);
 
-inline int cmpthumb(wxThumb** first, wxThumb** second)
-{
-  if ((*first)->GetFilename() < (*second)->GetFilename())
-	return -1;
-  else if ((*first)->GetFilename() == (*second)->GetFilename())
-	return (*first)->GetId() - (*second)->GetId();
-  return 1;
-}
-
-enum wxThumbOutline
-{
+enum wxThumbOutline {
   wxTHUMB_OUTLINE_NONE,
   wxTHUMB_OUTLINE_FULL,
   wxTHUMB_OUTLINE_RECT,
   wxTHUMB_OUTLINE_IMAGE
 };
 
-enum wxThumbFilter
-{
+enum wxThumbFilter {
   wxTHUMB_FILTER_IMAGES = 1,
   wxTHUMB_FILTER_VIDEOS = 2,
   wxTHUMB_FILTER_AUDIOS = 4,
@@ -92,8 +81,7 @@ enum wxThumbFilter
 };
 
 /** wxThumbnails style flags */
-enum
-{
+enum {
   wxTHUMB_HORIZONTAL = wxHORIZONTAL,
   wxTHUMB_VERTICAL = wxVERTICAL
 };
@@ -108,9 +96,8 @@ enum
   *   wxImage::InsertHandler(new wxJPGHandler);
   * @endcode
   */
-class wxThumbnails: public wxScrolledWindow
-{
-  public:
+class wxThumbnails: public wxScrolledWindow {
+public:
     wxThumbnails(wxWindow* parent, int id);
     virtual ~wxThumbnails();
 	
@@ -151,7 +138,7 @@ class wxThumbnails: public wxScrolledWindow
 	inline int GetItemCount() { return m_items.GetCount(); }
 	void InsertItem(wxThumb* thumb, int pos = -1);
 	void RemoveItemAt(int pos, int count = 1);
-	inline void SortItems() { m_items.Sort(cmpthumb); }
+	void SortItems();
     
 	/** Rereads directory. */
 	virtual void UpdateItems();
@@ -190,7 +177,8 @@ class wxThumbnails: public wxScrolledWindow
 	inline void SetThumbnailImageSelectedColor(const wxColour& colour) { m_tImageSelectedColour = colour; }
 	
 	virtual int GetItemIndex(int x, int y);
-  protected:
+	
+protected:
     /** Parameters of thumbnail */
     int m_tWidth;
     int m_tHeight;
@@ -248,7 +236,7 @@ class wxThumbnails: public wxScrolledWindow
     /* Rereads directory but don't update selection (use UpdateItems()) */
 	virtual void UpdateItemsInt();
     
-  private:
+private:
     DECLARE_EVENT_TABLE()
 };
 
