@@ -1,3 +1,5 @@
+#if !wxCHECK_VERSION(2,9,0)
+
 #ifndef _WX_IMAGJPG_H_
 #define _WX_IMAGJPG_H_
 
@@ -9,7 +11,7 @@
 
 #ifndef wxIMAGE_OPTION_MAX_WIDTH
 	#define wxIMAGE_OPTION_MAX_WIDTH wxT("max_width")
-	#define wxIMAGE_OPTION_MAX_HEIGHT wxT("max_width")
+	#define wxIMAGE_OPTION_MAX_HEIGHT wxT("max_height")
 #endif
 
 //-----------------------------------------------------------------------------
@@ -24,10 +26,6 @@ public:
     {
         m_name = wxT("JPEG file");
         m_extension = wxT("jpg");
-#if wxCHECK_VERSION(2,9,0)
-        m_altExtensions.Add(wxT("jpeg"));
-        m_altExtensions.Add(wxT("jpe"));
-#endif
         m_type = wxBITMAP_TYPE_JPEG;
         m_mime = wxT("image/jpeg");
     }
@@ -52,3 +50,4 @@ bool LoadImageFile(wxImage& img, const wxString& filename,
 
 #endif // _WX_IMAGJPG_H_
 
+#endif // !wxCHECK_VERSION(2,9,0)
